IF EXISTS (SELECT * FROM sysobjects WHERE type = 'TR' AND name = 'adftrDocumentDelete')
	BEGIN
		PRINT 'Dropping Trigger adftrDocumentDelete'
		DROP  Trigger adftrDocumentDelete
	END
GO

/******************************************************************************
**		File: 
**		Name: adftrDocumentDelete
**		Desc: 
**
**		This template can be customized:
**              
**
**		Auth: 
**		Date: 
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:		Description:
**		--------	--------	-------------------------------------------
**		28.03.15	SAP			 ,        
*******************************************************************************/

PRINT 'Creating Trigger adftrDocumentDelete'
GO
CREATE TRIGGER adftrDocumentDelete ON [Document] FOR DELETE
AS
	IF @@rowcount = 0 
		RETURN

	SET NOCOUNT ON

	DELETE [LastDocument]
	FROM
		[deleted]
	WHERE
		[LastDocument].[DocumentClass] = [deleted].[Class] AND
		[LastDocument].[DocumentID] = [deleted].[ID]
	
	
	DECLARE deletedDocuments CURSOR LOCAL FORWARD_ONLY READ_ONLY FOR
		SELECT 
			[deleted].[ID], 
			[deleted].[Class], 
			[deleted].[State]
		FROM 
			deleted
					
	DECLARE @ID TIdentifier, @Class TClass, @FromState TState, 
			@TransitionTemplateID TIdentifier, @RightID TIdentifier,
			@UserID TIdentifier, @result INT
			
	SET @UserID = dbo.adfGetCurrentUserID()
	
	OPEN deletedDocuments
	FETCH NEXT FROM deletedDocuments INTO @ID, @Class, @FromState
	WHILE @@FETCH_STATUS = 0
	BEGIN
		SET @TransitionTemplateID = NULL
		SELECT
			@TransitionTemplateID = [TransitionTemplate].[ID],
			@RightID = [TransitionTemplate].[RightID]
		FROM
			[TransitionTemplate]
		WHERE
			[FromState] = @FromState AND [ToState] IS NULL AND [Class] = @Class
		
		IF @TransitionTemplateID IS NULL
		BEGIN	
			RAISERROR('#TransitionTemplateCouldNotBeFound', 16, -1)
			ROLLBACK TRANSACTION
			RETURN
		END
		
		EXEC @result = adfAccessRightCheckInternal @RightID, @UserID
		IF @result != 0
		BEGIN
			ROLLBACK TRANSACTION
			RETURN
		END
		
		FETCH NEXT FROM deletedDocuments INTO @ID, @Class, @FromState
	END
	
	CLOSE deletedDocuments
	DEALLOCATE deletedDocuments
  
	RETURN 
GO

