﻿if exists (select * from dbo.sysobjects where id = object_id(N'[exch].[MeetingRequestCreate]') and objectproperty(id, N'IsProcedure') = 1)
begin
	print 'Dropping procedure MeetingRequestCreate'
	drop procedure [exch].[MeetingRequestCreate]
end
go

print 'Creating procedure MeetingRequestCreate'
go

create procedure [exch].[MeetingRequestCreate] @UserID TIdentifier, @XData xml
with execute as 'pjmexchangesync'
as
begin
	set nocount on;

	declare	@FileAs TName, @Start TDateTime, @End TDateTime, @Comments TNotes, @EventTime TDateTime, @NextInterval int, @EmployeeID TIdentifier, @CompanyID TIdentifier,
			@OriginatorEmployeeID TIdentifier, @Duration TCount, @Location TName, @Email THref, @Priority TIdentifier, @MeetingRequestClass TClass, 
			@MeetingRequestID TIdentifier, @result int;
	
	set @MeetingRequestClass = dbo.adfGetClassByName('Pjm5.MeetingRequest')

	select
		@FileAs = T.C.value('@FileAs', 'TName'),
		@Start = T.C.value('@Start', 'TDateTime'),
		@End = T.C.value('@End', 'TDateTime'),
		@Priority = T.C.value('@Priority', 'TIdentifier'),
		@Email = T.C.value('@Email', 'THref'),
		@Location = T.C.value('@Location', 'TName'),
		@Comments = T.C.value('@Comments', 'TNotes'),
		@EventTime = T.C.value('(Reminder/@EventTime)[1]', 'TDateTime'),
		@NextInterval = T.C.value('(Reminder/@NextInterval)[1]', 'int')
	from
		@XData.nodes('MeetingRequest') T(C);

	set @Duration = datediff(minute, @Start, @End);

	select
		@EmployeeID = [Employee].[ID],
		@CompanyID = [Employee].[CompanyID]
	from 
		[Employee] 
	where 
		[Employee].[UserID] = @UserID 
		and
		[Employee].[State] = 1;

	select @OriginatorEmployeeID = [exch].[fnGetEmployeeByEmail](@Email, @CompanyID);

	if @OriginatorEmployeeID != @EmployeeID
	begin
		select cast(N'<MeetingRequest />' as xml);
		return -1;
	end
	
	if @FileAs is null
		set @FileAs = '(без темы)';


	begin transaction;

	insert into [dbo].[MeetingRequest]
		([Flag], [State], [FileAs], [OriginatorEmployeeID], [PriorityID], [StartTime], [Duration], [Location], [Comments])
	values
		(0, 1, @FileAs, @OriginatorEmployeeID, @Priority, @Start, @Duration, @Location, @Comments);
			
	if @@error != 0
	begin
		rollback transaction;
		select cast(N'<MeetingRequest />' as xml);
		return 1;
	end
	set @MeetingRequestID = scope_identity();

	insert into [dbo].[Attendee]
		([MeetingRequestID], [EmployeeID], [Required], [Present], [ResponseType])
	select 
		@MeetingRequestID,
		[exch].[fnGetEmployeeByEmail](T.C.value('@Email', 'THref'), null),
		T.C.value('@Required', 'TBool'),
		(case when isnull(T.C.value('@ResponseType', 'int'), 0) = 3 then 1 else 0 end),
		(case isnull(T.C.value('@ResponseType', 'int'), 0) when 2 then 'Tentative' when 3 then 'Accept' when 4 then 'Decline' else null end)
	from
		@XData.nodes('MeetingRequest/Attendee') T(C)
	where
		[exch].[fnGetEmployeeByEmail](T.C.value('@Email', 'THref'), null) is not null
	and
		[exch].[fnGetEmployeeByEmail](T.C.value('@Email', 'THref'), null) != @EmployeeID;
	if @@error != 0
	begin
		rollback transaction;
		select cast(N'<MeetingRequest />' as xml);
		return 1;
	end

	update [MeetingRequest]
	set
		[MeetingRequest].[State] = 2,
		[MeetingRequest].[Modified] = DEFAULT,
		[MeetingRequest].[ModifiedBy] = DEFAULT
	where
		[MeetingRequest].[ID] = @MeetingRequestID;
	if @@error != 0
	begin
		rollback transaction;
		select cast(N'<MeetingRequest />' as xml);
		return 1;
	end

	exec [exch].[ReminderUpdate] @UserID, @MeetingRequestClass, @MeetingRequestID, @EventTime, @NextInterval;
	if @result = 1 or @@error != 0
	begin
		rollback transaction;
		select cast(N'<MeetingRequest />' as xml);
		return 1;
	end

	commit transaction;

	exec [dbo].[pjm5PostDocumentChangeNotificationEvent] 'MeetingRequestAppointed', 'Pjm5.MeetingRequest', @MeetingRequestID, NULL

	exec [exch].[MeetingRequestGet] @UserID, @MeetingRequestID;

	return 0;
end

go


grant execute on [exch].[MeetingRequestCreate] to [projectmateservice];
go
