﻿SET ANSI_PADDING ON

IF NOT EXISTS (SELECT * FROM sys.schemas WHERE name = N'exch')
begin
	EXEC sys.sp_executesql N'create schema [exch]';
end
go

if not exists (select * from sys.database_principals where name = N'projectmateservice' and type = 'R')
begin
	create role [projectmateservice];
end
go


if not exists (select * from sys.database_principals where name = N'pjmexchangesync')
begin
	EXEC sys.sp_executesql N'create user [pjmexchangesync] without login with default_schema=[dbo]';
	EXEC sys.sp_executesql N'EXEC sp_addrolemember [projectmateservice], [pjmexchangesync]';
end
go

if not exists (select * from sys.objects where object_id = object_id(N'[exch].[ExchangeLink]') and type in (N'U'))
begin
	create table [exch].[ExchangeLink]
	(
		[UserID]			[dbo].[TIdentifier] NOT NULL,
		[DocumentID]		[dbo].[TIdentifier] NOT NULL,
		[DocumentClass]		[dbo].[TClass] NOT NULL,
		[ExchangeID]		[varchar](max) NOT NULL,
		[Data]				[xml] NULL,
		[SyncTime]			[datetime] NOT NULL,
		[RowVersion]		[bigint] NULL,
		constraint [PK_ExchangeLink] primary key ([UserID],	[DocumentID], [DocumentClass])
	)
end
else
begin
	if not exists (select * from syscolumns where [name] = 'RowVersion' AND objectproperty(id, N'IsUserTable') = 1 and object_name(id)='ExchangeLink' and object_schema_name(id) = 'exch')
	begin
		alter table [exch].[ExchangeLink] add
			[RowVersion] [bigint] null;

		exec sp_executesql N'update [exch].[ExchangeLink]
set
	[RowVersion] = [T].[RowVersion]
from
	[exch].[ExchangeLink] as [L] inner join
		(select
			[UserID],
			[DocumentID],
			[DocumentClass],
			[Data].value(''(/Contact/@ID)[1]'', ''int'') as [ID],
			[Data].value(''(/Contact/@RowVersion)[1]'', ''bigint'') as [RowVersion]
		from
			[exch].[ExchangeLink]) as [T]
			on ([L].[UserID] = [T].[UserID] and [L].[DocumentID] = [T].[DocumentID] and [L].[DocumentClass] = [T].[DocumentClass])';
	end
end
go



if not exists (select * from sys.objects where object_id = object_id(N'[exch].[SyncState]') and type in (N'U'))
begin
	create table [exch].[SyncState]
	(
		[UserID] [dbo].[TIdentifier] NOT NULL,
		[TypeName] [varchar](10) NOT NULL,
		[MseSyncState] [varchar](max) NULL,
		[PjmSyncState] [bigint] NULL,
		constraint [PK_SyncState] primary key ([UserID], [TypeName])
	)
end
else
begin
	if not exists (select * from syscolumns where [name] = 'TypeName' AND objectproperty(id, N'IsUserTable') = 1 and object_name(id)='SyncState' and object_schema_name(id) = 'exch')
	begin
		alter table [exch].[SyncState] add
			[TypeName] varchar(10) not null constraint [DF_SyncState_TypeName] default 'Calendar'
	end
end
go

alter table [exch].[SyncState] drop constraint [PK_SyncState];
go

alter table [exch].[SyncState] add constraint [PK_SyncState] primary key (UserID, TypeName);
go


if not exists (select * from syscolumns where [name] = 'Timestamp' AND objectproperty(id, N'IsUserTable') = 1 and object_name(id)='UserReminder' and object_schema_name(id) = 'dbo')
begin
	alter table [dbo].[UserReminder] add 
		[Timestamp] [timestamp] not null;
end
go