IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].fnPjm6GetBudgetPeriodName') AND xtype IN (N'FN', N'IF', N'TF'))
	BEGIN
		PRINT 'Dropping function fnPjm6GetBudgetPeriodName'
		DROP FUNCTION [dbo].fnPjm6GetBudgetPeriodName
	END

GO

PRINT 'Creating function fnPjm6GetBudgetPeriodName'
GO
/******************************************************************************
**		File:	fnPjm6GetBudgetPeriodName.sql
**		Name: 	fnPjm6GetBudgetPeriodName
**		Desc:	
*******************************************************************************
**		Date:		Author:		Description:
**		-----		-------		-------------
**    	16.03.11		MAN		first version
*******************************************************************************/

CREATE FUNCTION fnPjm6GetBudgetPeriodName(
	@PeriodStart datetime,
	@PeriodEnd datetime,
	@BudgetType TIdentifier,
	@LangCode TCode3,
	@AmericanStyle TBool)
RETURNS	 varchar(64)
BEGIN
	DECLARE
		@YearL varchar(16),
		@HalfYearL varchar(16),
		--@ProjectBudgetL varchar(16),
		@Error varchar(16),
		@QuarterL varchar(16),
		@MonthL varchar(16),
		@Month tinyint,
		@DateDif int,
		@StartDay tinyint,
		@IsLeapYear tinyint,
		@SysLang nvarchar(32),
		@Result varchar(64)

	--SET @SysLang = @@LANGUAGE	-- remember default language code

	IF(@LangCode IS NULL OR @LangCode NOT IN ('en', 'ru'))
		SET @LangCode = 'ru'	-- set to russian language as default

	SET @DateDif = DATEDIFF(day, @PeriodStart, @PeriodEnd)
	SET @Month = DATEPART(month, @PeriodStart)
	SET @StartDay = DATEPART(day, @PeriodStart)
	IF DATEPART(year, @PeriodStart) % 4 = 0
		SET @IsLeapYear = 1
	ELSE
		SET @IsLeapYear = 0

	IF(@LangCode = 'en')
	BEGIN
		SET @YearL = 'Year'
		SET @QuarterL = 'Quarter'
		SET @HalfYearL = 'HalfYear'
		--SET @ProjectBudgetL = 'Project budget'
		SET @Error = 'Error'
		--SET LANGUAGE ENGLISH
		
		SET @MonthL = CASE MONTH(@PeriodStart)
						WHEN 1 THEN 'January'
						WHEN 2 THEN 'February'
						WHEN 3 THEN 'March'
						WHEN 4 THEN 'April'
						WHEN 5 THEN 'May'
						WHEN 6 THEN 'June'
						WHEN 7 THEN 'July'
						WHEN 8 THEN 'August'
						WHEN 9 THEN 'September'
						WHEN 10 THEN 'October'
						WHEN 11 THEN 'November'
						WHEN 12 THEN 'December'
					END
	END
	ELSE IF(@LangCode = 'ru')
	BEGIN
		SET @YearL = ''
		SET @QuarterL = ''
		SET @HalfYearL = ''
		--SET @ProjectBudgetL = '  '
		SET @Error = ''
		--SET LANGUAGE RUSSIAN
		SET @MonthL = CASE MONTH(@PeriodStart)
						WHEN 1 THEN ''
						WHEN 2 THEN ''
						WHEN 3 THEN ''
						WHEN 4 THEN ''
						WHEN 5 THEN ''
						WHEN 6 THEN ''
						WHEN 7 THEN ''
						WHEN 8 THEN ''
						WHEN 9 THEN ''
						WHEN 10 THEN ''
						WHEN 11 THEN ''
						WHEN 12 THEN ''
					END
	END

	--SET LANGUAGE @SysLang	-- set back default language code
	IF @BudgetType != 1
	BEGIN
		IF @StartDay = 1
		BEGIN
			IF	-- months with 30 days
				( @DateDif = 29 AND @Month in (4, 6, 9, 11))
				OR	-- months with 31 days
				( @DateDif = 30 AND @Month in (1, 3, 5, 7, 8, 10, 12))
				OR	-- february leap year
				( @DateDif = 28 AND @Month = 2 AND @IsLeapYear = 1)
				OR	-- february
				( @DateDif = 27 AND @Month = 2 AND @IsLeapYear = 0)
				SET @Result = 
					CASE @AmericanStyle 
						WHEN 'false' THEN @MonthL + ', ' + DATENAME(year, @PeriodStart)
						ELSE DATENAME(year, @PeriodStart) + ', ' + @MonthL 
					END
			-- by quarters
			ELSE IF	-- 1st quarter
				( @DateDif = 89 AND @Month = 1 AND @IsLeapYear = 0)
				OR -- 1st quarter leap year
				( @DateDif = 90 AND @Month = 1 AND @IsLeapYear = 1)
				OR	-- 2nd quarter
				( @DateDif = 90 AND @Month = 4)
				OR	-- 3rd and 4th quarters
				( @DateDif = 91 AND @Month in (7, 10))
				SET @Result = 
					CASE @AmericanStyle 
						WHEN 'false' 
							THEN CAST(DATEPART(quarter, @PeriodStart) AS VARCHAR(2)) + ' '	+ @QuarterL + ', ' + DATENAME(year, @PeriodStart)
						ELSE DATENAME(year, @PeriodStart) + ', ' + CAST(DATEPART(quarter, @PeriodStart) AS VARCHAR(2)) + ' '	+ @QuarterL
					END
			ELSE IF 
				( @DateDif = 180 AND @IsLeapYear = 0 )
				OR
				( @DateDif = 181 AND @IsLeapYear = 1)
				SET @Result = 
					CASE @AmericanStyle 
						WHEN 'false' 
							THEN '1' + ' '	+ @HalfYearL + ', ' + DATENAME(year, @PeriodStart)
						ELSE DATENAME(year, @PeriodStart) + ', ' + '1' + ' '	+ @HalfYearL
					END
			ELSE IF
				( @DateDif = 183)
				SET @Result = 
					CASE @AmericanStyle 
						WHEN 'false' 
							THEN '2' + ' '	+ @HalfYearL + ', ' + DATENAME(year, @PeriodStart)
						ELSE DATENAME(year, @PeriodStart) + ', ' + '2' + ' '	+ @HalfYearL
					END
			-- by years			
			ELSE IF
				 ( @DateDif = 364 AND @Month = 1 AND @IsLeapYear = 0)
				 OR -- leap year
				 ( @DateDif = 365 AND @Month = 1 AND @IsLeapYear = 1)
				SET @Result = DATENAME(year, @Periodstart) + ' ' + @YearL
				
			ELSE
			--    
				SET @Result = @Error
		END
		ELSE
		BEGIN
			SET @Result = @Error
		END
	END
	ELSE
	BEGIN
		SET @Result = ''
	END
	
	RETURN @Result
END
GO

