﻿IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[fnReportTimeSellAnalysisByEmployeesGetRealValuesList]') AND xtype IN (N'FN', N'IF', N'TF'))
	BEGIN
		PRINT 'Dropping function fnReportTimeSellAnalysisByEmployeesGetRealValuesList'
		DROP FUNCTION [dbo].[fnReportTimeSellAnalysisByEmployeesGetRealValuesList]
	END
GO

IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'ReportTimeSellAnalysisByEmployeesGetRealValuesList')
	BEGIN
		PRINT 'Dropping Procedure ReportTimeSellAnalysisByEmployeesGetRealValuesList'
		DROP  Procedure  ReportTimeSellAnalysisByEmployeesGetRealValuesList
	END
GO

PRINT 'Creating Procedure ReportTimeSellAnalysisByEmployeesGetRealValuesList'
GO
/******************************************************************************
**		File: ReportTimeSellAnalysisByEmployeesGetRealValuesList.sql
**		Name: ReportTimeSellAnalysisByEmployeesGetRealValuesList
**
**              
**		Return values:
**			Фактические значения утилизации, реализации и выручки по
**			сотруднику
**		Called by:   
**              ReportTimeSellAnalysisByEmployees
**		Parameters:
**		Input							Output
**      ----------						-----------
**		
**		
**		Auth: Sergey Pelevin
**		Date: 28.07.14 
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**		26.01.15	VDV				Увеличена точность расчета дисконта в отчете
**		29.06.15	SAP				Исправлен расчет процента дисконта для ЗОВ из калькуляций
*******************************************************************************/
CREATE PROCEDURE ReportTimeSellAnalysisByEmployeesGetRealValuesList
(
	@EmployeeID	int, 
	@PeriodStart date, -- Начало периода
	@PeriodEnd date, --Конец периода
	@IncludingSentToApprove bit, -- Включать отправленное на утверждение (0 - не включать, 1 - включать)	
	@StateOfFinanceDocuments int, -- Состояние фин. документов (0 - калькуляции учтены, 
									--1 - только утвержденные, 2 - включая черновики)
	@CurrencySelector int, --Валюта отчета (0 - национальная, 1 - учетная)
	@StandardEfficiency decimal(18,2),

	@UtilizationReal decimal(18,2) OUTPUT,
	@UtilizationAverageMonth decimal(18,2) OUTPUT,
	@UtilizationAverageDay decimal(18,2) OUTPUT,
	@RealizationReal decimal(18,2) OUTPUT,
	@RealizationPositiveDeviation decimal(18,2) OUTPUT,
	@RealizationNegativeDeviation decimal(18,2) OUTPUT,
	@RealizationAverageMonth decimal(18,2) OUTPUT,
	@RealizationAverageDay decimal(18,2) OUTPUT,
	@RevenueReal decimal(18,2) OUTPUT,
	@RevenuePositiveDeviation decimal(18,2) OUTPUT,
	@RevenueNegativeDeviation decimal(18,2) OUTPUT,
	@EfficiencyPercent decimal(18,2) OUTPUT,
	@EfficiencyDeviation decimal(18,2) OUTPUT,
	@AverageRate decimal(18,2) OUTPUT
)

AS
BEGIN 
	DECLARE		
		@WorkingDays int,
		@CalculationClass TClass,
		@InvoiceClass TClass,
		@StatementClass TClass,
		@BaseCurrency TCode3,
        @NationalCurrency TCode3

	SET	@CalculationClass = dbo.adfGetClassByName('Pjm5.Calculation')
	SET	@StatementClass = dbo.adfGetClassByName('Pjm5.Statement')
	SET	@InvoiceClass = dbo.adfGetClassByName('Pjm5.Invoice')

	  
	SET @BaseCurrency = [dbo].[fnPjm5GetBaseCurrency]()	 
	SET @NationalCurrency = [dbo].[fnPjm5GetNationalCurrency]()


	DECLARE @TimeEntriesUtilization TABLE
	(
		[MonthName] TName,		
		[Duration] decimal(18,4)
	)

	--Таблица с ЗОВ, включенными в финансовые документы
	DECLARE @TimeEntriesInFinance TABLE
	(
		[TimeEntryID]			TIdentifier,
		[FinanceDocumentClass]	TClass, 
		[FinanceDocumentID]		TIdentifier, 
		[FinanceDocumentState]	TState, 		
		[TimeEntryIsThroughCalculation]	TFlag
	)

	DECLARE @TimeEntriesRealization TABLE
	(
		[MonthName] TName,			
		[Duration] decimal(18,4),
		[PositiveDurationDeviation] decimal(18,4),
		[NegativeDurationDeviation] decimal(18,4),				
		[Cost] decimal(18,2),
		[PositiveCostDeviation] decimal(18,2),
		[NegativeCostDeviation] decimal(18,2)
	)

	DECLARE @RealizationAggregateTable TABLE
	(
		[MonthName] TName,
		[RealizationHours] decimal(18,4),
		[PositiveRealizationDeviation] decimal(18,4),
		[NegativeRealizationDeviation] decimal(18,4),	
		[Cost] decimal(18,2),
		[PositiveCostDeviation] decimal(18,2),
		[NegativeCostDeviation] decimal(18,2)
	)


	--////////////////////////////// Разбивка периода времени на месяцы
	
	DECLARE	@PeriodNames TABLE
	(
		PeriodStartDate date,
		PeriodEndDate date,
		PeriodName TName,
		WorkingDays int
	)

	INSERT INTO @PeriodNames
	SELECT 
		[M].[PeriodStartDate],
		[M].[PeriodEndDate],
		[M].[PeriodName],
		dbo.fnPjm5GetWorkingDays([M].[PeriodStartDate],[M].[PeriodEndDate])
	FROM
		[dbo].[fnReportSplitPeriodOnMonths](@PeriodStart,DATEADD(DAY,-1,@PeriodEnd),'ru',0,1) as [M]



	

	--////////////////////////////// Утилизация		

	INSERT INTO @TimeEntriesUtilization
	SELECT
		[PeriodNames].[PeriodName],						
		SUM(ROUND([TimeEntry].[RoundedDuration]/60.0,4))
	FROM
		[TimeEntry]
		INNER JOIN [Employee]
			ON [Employee].[ID] = [TimeEntry].[EmployeeID]		
		INNER JOIN [Project]
			ON [Project].[ID] = [TimeEntry].[ProjectID]
		LEFT JOIN @PeriodNames as [PeriodNames]
			ON 	CAST([TimeEntry].[StartTime] AS date) >= [PeriodNames].[PeriodStartDate]
			AND CAST([TimeEntry].[StartTime] AS date) <= [PeriodNames].[PeriodEndDate]		
	WHERE
		--Коммерческие проекты
		[Project].[ProjectTypeID] = 1
		AND -- ЗОВ в состоянии "Утверждена" или "Включена в фин. документ"	
		(	-- ...и "Отправлена на утверждение"?
			(@IncludingSentToApprove = 0 AND [TimeEntry].[State] IN (3,6)) 	
			OR 	
			(@IncludingSentToApprove = 1 AND [TimeEntry].[State] IN (2,3,6))
		)	
		AND 
		(
			[TimeEntry].[StartTime] >= @PeriodStart 
			AND 
			[TimeEntry].[StartTime] <= @PeriodEnd
		)
		AND
		[Employee].[ID] = @EmployeeID
	GROUP BY 
		[PeriodNames].[PeriodName]

		
		
	--SELECT * FROM @TimeEntriesUtilization --ORDER BY [MonthName]

	SELECT
		@UtilizationReal = ROUND(SUM([U].[Duration]),2),
		@UtilizationAverageMonth = SUM([U].[Duration])/COUNT([U].[Duration]),				
		@UtilizationAverageDay=
		SUM([U].[Duration])
		/
		(
			SELECT 
				SUM([PN].[WorkingDays]) 
			FROM 
				@TimeEntriesUtilization AS [TEU] 
				INNER JOIN @PeriodNames AS [PN]
					ON [PN].[PeriodName] = [TEU].[MonthName] 					
		)
	FROM
		@TimeEntriesUtilization AS [U]


	--////////////////////////////// Реализация + выручка			
	INSERT INTO @TimeEntriesInFinance ([TimeEntryID], [FinanceDocumentClass], [FinanceDocumentID], [FinanceDocumentState], [TimeEntryIsThroughCalculation])
	SELECT
		[F].[DocumentID],
		[F].[LinkClass],
		[F].[LinkDocumentID],
		[F].[State],
		[F].[ThroughCalculation]
	FROM fnReportGetTimeEntriesInFinance(@PeriodStart, @PeriodEnd, @EmployeeID) AS [F]

	--SELECT * FROM @TimeEntriesInFinance


	--Добавляем ЗОВ, включенные в любые фин. док-ты кроме калькуляций
	IF @StateOfFinanceDocuments <> 0
	BEGIN 
		INSERT INTO @TimeEntriesRealization
		SELECT
			[PeriodNames].[PeriodName] AS [MonthName],	
			[EntryAmount].[Amount] AS [Duration],
			CASE  
				WHEN [EntryAmount].[Amount] - [TimeEntry].[RoundedDuration]/60.0 > 0 
				THEN [EntryAmount].[Amount] - [TimeEntry].[RoundedDuration]/60.0
				ELSE 0
			END AS [PositiveDurationDeviation],
			CASE 
				WHEN [EntryAmount].[Amount] - [TimeEntry].[RoundedDuration]/60.0 < 0 
				THEN ABS([EntryAmount].[Amount] - [TimeEntry].[RoundedDuration]/60.0)
				ELSE 0
			END AS [NegativeDurationDeviation],												
			[EntryAmount].[Amount]
			*	
			[EntryAmount].[Price]
			*   
			(
				1 -	CASE [Project].[RatesWithVAT]
						WHEN 1 THEN [TimeEntry].[VATRate]/(1 + [TimeEntry].[VATRate])
						ELSE 0 
					END
			)
			*
			CASE @CurrencySelector
				WHEN 0 THEN
					CASE [Project].[CurrencyCode]
						WHEN @BaseCurrency THEN 1 
						ELSE dbo.pjm6fnCurrencyGetRate([Project].[CurrencyCode], [TimeEntry].[StartTime], @BaseCurrency) 
					END
				ELSE
					CASE [Project].[CurrencyCode]
						WHEN @NationalCurrency THEN 1 
						ELSE dbo.pjm6fnCurrencyGetRate([Project].[CurrencyCode], [TimeEntry].[StartTime], @NationalCurrency) 
					END
			END AS [Cost],
		CASE 
			WHEN [EntryAmount].[Amount] * [EntryAmount].[Price] - [TimeEntry].[RoundedDuration]/60.0 * [TimeEntry].[Rate] > 0 
			THEN
			ROUND((
				[EntryAmount].[Amount] * [EntryAmount].[Price] --Время и ставка из фин. документа
				- 
				[TimeEntry].[RoundedDuration]/60.0 * [TimeEntry].[Rate] --Время и ставка до включения в фин. док-т
			)	
			*
			(
				1 -	CASE [Project].[RatesWithVAT]
						WHEN 1 THEN [TimeEntry].[VATRate]/(1 + [TimeEntry].[VATRate])
						ELSE 0 
					END
			)
			*			
			CASE @CurrencySelector
				WHEN 0 THEN
					CASE [Project].[CurrencyCode]
						WHEN @BaseCurrency THEN 1 
						ELSE dbo.pjm6fnCurrencyGetRate([Project].[CurrencyCode], [TimeEntry].[StartTime], @BaseCurrency) 
					END
				ELSE
					CASE [Project].[CurrencyCode]
						WHEN @NationalCurrency THEN 1 
						ELSE dbo.pjm6fnCurrencyGetRate([Project].[CurrencyCode], [TimeEntry].[StartTime], @NationalCurrency) 
					END
			END,2)
			ELSE 0
		END AS [PositiveCostDeviation],
		CASE 
			WHEN [EntryAmount].[Amount] * [EntryAmount].[Price] - [TimeEntry].[RoundedDuration]/60.0 * [TimeEntry].[Rate] < 0 
			THEN
			ROUND(ABS(
				[EntryAmount].[Amount] * [EntryAmount].[Price] --Время и ставка из фин. документа
				- 
				[TimeEntry].[RoundedDuration]/60.0 * [TimeEntry].[Rate] --Время и ставка до включения в фин. док-т
			)	
			*
			(
				1 -	CASE [Project].[RatesWithVAT]
						WHEN 1 THEN [TimeEntry].[VATRate]/(1 + [TimeEntry].[VATRate])
						ELSE 0 
					END
			)
			*			
			CASE @CurrencySelector
				WHEN 0 THEN
					CASE [Project].[CurrencyCode]
						WHEN @BaseCurrency THEN 1 
						ELSE dbo.pjm6fnCurrencyGetRate([Project].[CurrencyCode], [TimeEntry].[StartTime], @BaseCurrency) 
					END
				ELSE
					CASE [Project].[CurrencyCode]
						WHEN @NationalCurrency THEN 1 
						ELSE dbo.pjm6fnCurrencyGetRate([Project].[CurrencyCode], [TimeEntry].[StartTime], @NationalCurrency) 
					END
			END,2)
			ELSE 0
		END AS [NegativeCostDeviation]			
		FROM
			[TimeEntry]
			INNER JOIN [Employee]
				ON [Employee].[ID] = [TimeEntry].[EmployeeID]
			INNER JOIN [EntryAmount]
				ON [EntryAmount].[ID] = [TimeEntry].[ID]
			INNER JOIN [Project]
				ON [Project].[ID] = [TimeEntry].[ProjectID]
			INNER JOIN	@TimeEntriesInFinance AS [TimeEntriesInFinance] 	
				ON [TimeEntriesInFinance].[TimeEntryID] = [TimeEntry].[ID]
			LEFT JOIN @PeriodNames as [PeriodNames]
				ON 	CAST([TimeEntry].[StartTime] AS date) >= [PeriodNames].[PeriodStartDate]
				AND CAST([TimeEntry].[StartTime] AS date) <= [PeriodNames].[PeriodEndDate]			
		WHERE
			-- ЗОВ в состоянии "Включена в фин. документ"		
			(	-- ...и "Отправлена на утверждение"?
				(@IncludingSentToApprove = 0 AND [TimeEntry].[State] = 6) 	
				OR 	
				(@IncludingSentToApprove = 1 AND [TimeEntry].[State] IN (2,6))
			)
			AND -- Включая черновики или только утвержденные фин. документы
			(
				@StateOfFinanceDocuments = 2 
				OR 
				(
					[TimeEntriesInFinance].[FinanceDocumentState] = 2 
					OR 
					(
						@InvoiceClass = [TimeEntriesInFinance].[FinanceDocumentClass] AND [TimeEntriesInFinance].[FinanceDocumentState] = 5
					) 
					OR
					(
						@InvoiceClass != [TimeEntriesInFinance].[FinanceDocumentClass] AND [TimeEntriesInFinance].[FinanceDocumentState] = 3
					)
				)
			)
			AND 
			--Фин. документы кроме калькуляций
			[TimeEntriesInFinance].[FinanceDocumentClass] <> @CalculationClass
	END
	--SELECT * FROM @TimeEntriesRealization

	--Добавляем ЗОВ, включенные в калькуляции
	INSERT INTO @TimeEntriesRealization
	SELECT
		[PeriodNames].[PeriodName] AS [MonthName],					
		[EntryAmount].[Amount] AS [Duration],
		CASE 
			WHEN [EntryAmount].[Amount] - [TimeEntry].[RoundedDuration]/60.0 > 0 
			THEN [EntryAmount].[Amount] - [TimeEntry].[RoundedDuration]/60.0
			ELSE 0
		END AS [PositiveDurationDeviation],
		CASE 
			WHEN [EntryAmount].[Amount] - [TimeEntry].[RoundedDuration]/60.0 < 0 
			THEN ABS([EntryAmount].[Amount] - [TimeEntry].[RoundedDuration]/60.0)
			ELSE 0
		END AS [NegativeDurationDeviation],				
		ROUND(						
				CASE [Project].[RatesWithVAT] 
					WHEN 1 THEN [EntryAmount].[Amount] * [EntryAmount].[Price] / (1 + [TimeEntry].[VATRate]) 
					ELSE [EntryAmount].[Amount] * [EntryAmount].[Price]
				END	
				*
				[dbo].[fnGetCalculationDiscountPercent]([Calculation].[TotalWithoutDiscountAndAdvanced],
					[Calculation].[TotalWithVATWithoutDiscountAndAdvanced],
					[Calculation].[Discount],
					[Calculation].[RatesWithVAT],
					[Calculation].[DiscountType])
				*
				CASE @CurrencySelector
					WHEN 0 THEN
						CASE [Project].[CurrencyCode]
							WHEN @BaseCurrency THEN 1 
							ELSE dbo.pjm6fnCurrencyGetRate([Project].[CurrencyCode], [TimeEntry].[StartTime], @BaseCurrency) 
						END
					ELSE
						CASE [Project].[CurrencyCode]
							WHEN @NationalCurrency THEN 1 
							ELSE dbo.pjm6fnCurrencyGetRate([Project].[CurrencyCode], [TimeEntry].[StartTime], @NationalCurrency) 
						END
				END
		,2) AS [Cost],
		CASE 
			WHEN ([EntryAmount].[Amount] * [EntryAmount].[Price] - [TimeEntry].[RoundedDuration]/60.0 * [TimeEntry].[Rate]) > 0 
			THEN
				ROUND(
				CASE [Project].[RatesWithVAT] 
					WHEN 1 THEN ([EntryAmount].[Amount] * [EntryAmount].[Price] - [TimeEntry].[RoundedDuration]/60.0 * [TimeEntry].[Rate]) / (1 + [TimeEntry].[VATRate]) 
					ELSE ([EntryAmount].[Amount] * [EntryAmount].[Price] - [TimeEntry].[RoundedDuration]/60.0 * [TimeEntry].[Rate]) 
				END
				*	
				CASE @CurrencySelector
					WHEN 0 THEN
						CASE [Project].[CurrencyCode]
							WHEN @BaseCurrency THEN 1 
							ELSE dbo.pjm6fnCurrencyGetRate([Project].[CurrencyCode], [TimeEntry].[StartTime], @BaseCurrency) 
						END
					ELSE
						CASE [Project].[CurrencyCode]
							WHEN @NationalCurrency THEN 1 
							ELSE dbo.pjm6fnCurrencyGetRate([Project].[CurrencyCode], [TimeEntry].[StartTime], @NationalCurrency) 
						END
				END,2)
			ELSE 0
		END AS [PositiveCostDeviation],
		CASE 
			WHEN ([EntryAmount].[Amount] * [EntryAmount].[Price] - [TimeEntry].[RoundedDuration]/60.0 * [TimeEntry].[Rate]) < 0 
			THEN
				ROUND(
				CASE [Project].[RatesWithVAT] 
					WHEN 1  THEN ABS([EntryAmount].[Amount] * [EntryAmount].[Price] - [TimeEntry].[RoundedDuration]/60.0 * [TimeEntry].[Rate]) / (1 + [TimeEntry].[VATRate]) 
					ELSE ABS([EntryAmount].[Amount] * [EntryAmount].[Price] - [TimeEntry].[RoundedDuration]/60.0 * [TimeEntry].[Rate])
				END
				*
				CASE @CurrencySelector
					WHEN 0 THEN
						CASE [Project].[CurrencyCode]
							WHEN @BaseCurrency THEN 1 
							ELSE dbo.pjm6fnCurrencyGetRate([Project].[CurrencyCode], [TimeEntry].[StartTime], @BaseCurrency) 
						END
					ELSE
						CASE [Project].[CurrencyCode]
							WHEN @NationalCurrency THEN 1 
							ELSE dbo.pjm6fnCurrencyGetRate([Project].[CurrencyCode], [TimeEntry].[StartTime], @NationalCurrency) 
						END
				END,2)
			ELSE 0
		END AS [NegativeCostDeviation]
	FROM
		[TimeEntry]
		INNER JOIN [Employee]
			ON [Employee].[ID] = [TimeEntry].[EmployeeID]
		INNER JOIN [EntryAmount]
			ON [EntryAmount].[ID] = [TimeEntry].[ID]
		INNER JOIN [Project]
			ON [Project].[ID] = [TimeEntry].[ProjectID]
		INNER JOIN	@TimeEntriesInFinance AS [TimeEntriesInFinance] 	
			ON [TimeEntriesInFinance].[TimeEntryID] = [TimeEntry].[ID]
		INNER JOIN [Calculation]
			ON [Calculation].[ID] = [TimeEntriesInFinance].[FinanceDocumentID]		
		LEFT JOIN @PeriodNames as [PeriodNames]
			ON 	CAST([TimeEntry].[StartTime] AS date) >= [PeriodNames].[PeriodStartDate]
			AND CAST([TimeEntry].[StartTime] AS date) <= [PeriodNames].[PeriodEndDate]	
	WHERE
		-- ЗОВ в состоянии "Включена в фин. документ"
		(	-- ...и "Отправлена на утверждение"?
			(@IncludingSentToApprove = 0 AND [TimeEntry].[State] = 6) 	
			OR 	
			(@IncludingSentToApprove = 1 AND [TimeEntry].[State] IN (2,6))
		)
		AND -- Калькуляции учтены (3), Только утвержденные (2) фин. документы или Включая черновики (1)
		(
			(@StateOfFinanceDocuments = 0 AND [TimeEntriesInFinance].[FinanceDocumentState] = 3) 	
			OR 
			(@StateOfFinanceDocuments = 1 AND [TimeEntriesInFinance].[FinanceDocumentState] IN (2,3)) 
			OR
			(@StateOfFinanceDocuments = 2 AND [TimeEntriesInFinance].[FinanceDocumentState] IN (1,2,3)) 
		)
		AND --Фин. документы - калькуляции
		[TimeEntriesInFinance].[FinanceDocumentClass] = @CalculationClass
	
	--SELECT * FROM @TimeEntriesRealization


	INSERT INTO @RealizationAggregateTable
	SELECT
		[MonthName],
		SUM([R].[Duration]) AS [RealizationHours],
		SUM([R].[PositiveDurationDeviation]),
		SUM([R].[NegativeDurationDeviation]),
		SUM([R].[Cost]) AS [Cost],
		SUM([R].[PositiveCostDeviation]),
		SUM([R].[NegativeCostDeviation])
	FROM
		@TimeEntriesRealization AS [R]
	GROUP BY
		[MonthName]
	
	--Вычисление эффективности
	DECLARE @EfficiencyTable TABLE
	(
		[MonthName] TName,
		[Utilization] decimal(18,2),
		[Realization] decimal(18,2),
		[PositiveRealizationDeviation] decimal(18,2),
		[Efficiency] decimal(18,2),
		[EfficiencyDeviation] decimal(18,2),		
		[AverageRate] decimal(18,2)
	)
	INSERT INTO @EfficiencyTable
	SELECT
		ISNULL([R].[MonthName],[U].[MonthName]),
		SUM(ISNULL([U].[Duration],0)),
		[R].[RealizationHours],
		[R].[PositiveRealizationDeviation],
		NULL,
		NULL,		
		CASE
			WHEN SUM(ISNULL([U].[Duration],0)) IS NOT NULL AND [R].[Cost] IS NOT NULL THEN
				CASE
					WHEN SUM(ISNULL([U].[Duration],0)) <> 0 THEN [R].[Cost]/SUM(ISNULL([U].[Duration],0))
					ELSE 0 
				END
			ELSE NULL
		END
	FROM
		@RealizationAggregateTable AS [R]
		LEFT JOIN @TimeEntriesUtilization AS [U]
			ON [R].[MonthName] = [U].[MonthName]
	GROUP BY
		[U].[MonthName],
		[R].[MonthName],
		[R].[RealizationHours],
		[R].[PositiveRealizationDeviation],
		[R].[Cost]

	UPDATE @EfficiencyTable
	SET [Efficiency] = 
	CASE 
		WHEN [Utilization] IS NOT NULL THEN 
			CASE
				WHEN [Utilization] <> 0 THEN (([Realization] - [PositiveRealizationDeviation])/[Utilization])*100
				ELSE 0
			END 
		ELSE NULL 
	END,
	[EfficiencyDeviation] = 
	CASE
		WHEN [Utilization] IS NOT NULL AND [Realization] IS NOT NULL THEN
			CASE 
				WHEN ROUND([Utilization],2) <> 0 AND ROUND([Realization] - [PositiveRealizationDeviation],2) <> 0 
				THEN (([Realization] - [PositiveRealizationDeviation])/[Utilization])*100 - @StandardEfficiency
				ELSE 0
			END
		ELSE NULL									 
	END
	
	
	SELECT
		@EfficiencyPercent = SUM(ROUND([Efficiency],0))/(SELECT COUNT([Efficiency]) FROM @EfficiencyTable WHERE [Efficiency] IS NOT NULL),
		@EfficiencyDeviation = 
		CASE 
			WHEN ROUND(SUM([Efficiency])/(SELECT COUNT([Efficiency]) FROM @EfficiencyTable WHERE [Efficiency] IS NOT NULL),0) <> 0 
			THEN SUM(ROUND([Efficiency],0))/(SELECT COUNT([Efficiency]) FROM @EfficiencyTable WHERE [Efficiency] IS NOT NULL) - @StandardEfficiency
			ELSE 0 
		END,
		@AverageRate = SUM([AverageRate])/(SELECT COUNT([AverageRate]) FROM @EfficiencyTable WHERE [AverageRate] IS NOT NULL)
	FROM
		@EfficiencyTable

	IF @EfficiencyPercent IS NULL
		SET @EfficiencyDeviation = NULL
			
		
	SELECT
		@RealizationReal = ROUND(SUM([RAT].[RealizationHours]),2),
		@RealizationPositiveDeviation = SUM([RAT].[PositiveRealizationDeviation]),
		@RealizationNegativeDeviation = SUM([RAT].[NegativeRealizationDeviation]), 
		@RealizationAverageMonth = SUM([RAT].[RealizationHours])/COUNT([RAT].[RealizationHours]),
		@RealizationAverageDay = SUM([RAT].[RealizationHours])
		/
		(
			SELECT 
				SUM([PN].[WorkingDays]) 
			FROM 
				@RealizationAggregateTable 
				INNER JOIN @PeriodNames AS [PN]
					ON [PN].[PeriodName] = [@RealizationAggregateTable].[MonthName] 					
		),
		@RevenueReal = ROUND(SUM([RAT].[Cost]),2),
		@RevenuePositiveDeviation = SUM([RAT].[PositiveCostDeviation]),
		@RevenueNegativeDeviation = SUM([RAT].[NegativeCostDeviation]) 
	FROM
		@RealizationAggregateTable AS [RAT]		
	
	RETURN 0
END

GO

GRANT EXEC ON ReportTimeSellAnalysisByEmployeesGetRealValuesList TO PUBLIC

GO
