﻿IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[fnReportEmployeesWithTimeInBillableProjectsInPeriod]') AND xtype IN (N'FN', N'IF', N'TF'))
	BEGIN
		PRINT 'Dropping function fnReportEmployeesWithTimeInBillableProjectsInPeriod'
		DROP FUNCTION [dbo].[fnReportEmployeesWithTimeInBillableProjectsInPeriod]
	END
GO

PRINT 'Creating function fnReportEmployeesWithTimeInBillableProjectsInPeriod'
GO

/******************************************************************************
**		File: fnReportEmployeesWithTimeInBillableProjectsInPeriod.sql
**		Name: fnReportEmployeesWithTimeInBillableProjectsInPeriod
**
**              
**		Return values:
**		Функция возвращает список сотрудников собственной компании (или всех с.к.), имеющих
**		утвержденные (или + отправленные на утверждение) ЗОВ в коммерческих проектах 
**		за указанный период с учетом фильтров по подразделению и квалификации
**
**		Called by:   
**              fnReportTimeSellAnalysisByEmployeesGetEmployeesList
**		Parameters:
**		Input							Output
**      ----------						-----------
**		
**		
**		Auth: Sergey Pelevin
**		Date: 25.07.14 
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:		Description:
**		--------	--------	-------------------------------------------
**		14.08.14	SAP			Доработка условий
**		12.09.14	SAP			Доработка фильтров по квалификации и подразделению
*******************************************************************************/
CREATE FUNCTION dbo.fnReportEmployeesWithTimeInBillableProjectsInPeriod
(
	@OwnCompanyID int, --ID собственной компании (NULL-все)
	@DivisionSelector int, --Подразделение (0 - не важно, 2 - из списка)	
	@DivisionID int, --ID подразделения (NULL - не указано)
	@QualificationSelector int, --Квалификация (0 - не важно, 2 - из списка)	
	@QualificationID int, --ID квалификации (NULL - не указана)
	@PeriodStart date, -- Начало периода
	@PeriodEnd date, --Конец периода
	@IncludingSentToApprove bit -- Включать отправленное на утверждение (0 - не включать, 1 - включать)
)
RETURNS @EmployeesWithTimeList TABLE 
(
	[ID] Tidentifier	
)
AS
BEGIN
	INSERT INTO @EmployeesWithTimeList
	SELECT DISTINCT
		[E].[ID]
	FROM
		[Company] AS [C]
		INNER JOIN [Employee] AS [E]
			ON [C].[ID] = [E].[CompanyID]
		INNER JOIN [TimeEntry] AS [TE]
			ON [E].[ID] = [TE].[EmployeeID]
		INNER JOIN [Project] AS [P]
			ON [TE].[ProjectID] = [P].[ID]
	WHERE
		--Собственная компания
		(
			@OwnCompanyID IS NULL
			OR
			[C].[ID] = @OwnCompanyID AND [C].[Own] = 1
		)
		AND
		--Подразделение
		(
			@DivisionSelector = 0
			OR
			(@DivisionID IS NULL AND [E].[DivisionID] IS NULL)
			OR
			[E].[DivisionID] = @DivisionID
		)
		AND
		--Квалификация
		(
			@QualificationSelector = 0
			OR
			(@QualificationID IS NULL AND [E].[QualificationID] IS NULL)
			OR
			[E].[QualificationID] = @QualificationID
		)
		AND
		--Период
		(
			[TE].[StartTime] >= @PeriodStart
			AND
			[TE].[StartTime] < @PeriodEnd
		)
		AND
		--Коммерческие проекты
		(
			[P].[ProjectTypeID] = 1
		)
		AND
		--Состояния ЗОВ
		(
			@IncludingSentToApprove = 0 AND [TE].[State] IN(3,6)
			OR
			@IncludingSentToApprove = 1 AND [TE].[State] IN(2,3,6)
		)
	RETURN
END

GO
