IF EXISTS (SELECT * FROM sysobjects WHERE type = 'TR' AND name = 'pjm5trAssignmentEntryUpdate')
	BEGIN
		PRINT 'Dropping Trigger pjm5trAssignmentEntryUpdate'
		DROP  Trigger pjm5trAssignmentEntryUpdate
	END
GO

/******************************************************************************
**		File: 
**		Name: pjm5trAssignmentEntryUpdate
**		Desc: 
**
**		This template can be customized:
**              
**
**		Auth: 
**		Date: 
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:				Description:
**		--------		--------				-------------------------------------------
**    
*******************************************************************************/

PRINT 'Creating Trigger pjm5trAssignmentEntryUpdate'
GO
CREATE Trigger pjm5trAssignmentEntryUpdate 
ON [AssignmentEntry] FOR UPDATE
AS
BEGIN
	IF @@ROWCOUNT != 1 RETURN

	DECLARE 
		@prev int,
		@new int,
		@assignmentID int,
		@rv int
	SELECT
		@assignmentID = inserted.[AssignmentID],
		@new = inserted.[EmployeeID],
		@prev = deleted.[EmployeeID]
	FROM
		inserted 
		INNER JOIN deleted
			ON inserted.[ID] = deleted.[ID]
	IF @prev != @new AND (@prev IS NOT NULL OR @new IS NOT NULL)
	BEGIN
		EXEC @rv = pjm5AssignmentChangeBooking @assignmentID
		IF @rv != 0
		BEGIN
			RAISERROR('#cannotchangeassignmentemployee', 18, -1)
			ROLLBACK TRANSACTION
			RETURN
		END
	END
END

GO

IF EXISTS (SELECT * FROM sysobjects WHERE type = 'TR' AND name = 'pjm5trAssignmentEntryInsert')
	BEGIN
		PRINT 'Dropping Trigger pjm5trAssignmentEntryInsert'
		DROP  Trigger pjm5trAssignmentEntryInsert
	END
GO

/******************************************************************************
**		File: 
**		Name: pjm5trAssignmentEntryInsert
**		Desc: 
**
**		This template can be customized:
**              
**
**		Auth: 
**		Date: 
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:				Description:
**		--------		--------				-------------------------------------------
**    
*******************************************************************************/

PRINT 'Creating Trigger pjm5trAssignmentEntryInsert'
GO
CREATE Trigger pjm5trAssignmentEntryInsert 
ON [AssignmentEntry] FOR INSERT
AS
BEGIN
	IF @@ROWCOUNT != 1 RETURN

	DECLARE 
		@new int,
		@assignmentID int,
		@rv int
	SELECT
		@assignmentID = inserted.[AssignmentID],
		@new = inserted.[EmployeeID]
	FROM
		inserted
		
	EXEC @rv = pjm5AssignmentChangeBooking @assignmentID
	IF @rv != 0
	BEGIN
		RAISERROR('#cannotsetassignmentemployee', 18, -1)
		ROLLBACK TRANSACTION
		RETURN
	END
END

GO

IF EXISTS (SELECT * FROM sysobjects WHERE type = 'TR' AND name = 'pjm5trAssignmentEntryDelete')
	BEGIN
		PRINT 'Dropping Trigger pjm5trAssignmentEntryDelete'
		DROP  Trigger pjm5trAssignmentEntryDelete
	END
GO

/******************************************************************************
**		File: 
**		Name: pjm5trAssignmentEntryDelete
**		Desc: 
**
**		This template can be customized:
**              
**
**		Auth: 
**		Date: 
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:				Description:
**		--------		--------				-------------------------------------------
**    
*******************************************************************************/

PRINT 'Creating Trigger pjm5trAssignmentEntryDelete'
GO
CREATE Trigger pjm5trAssignmentEntryDelete 
ON [AssignmentEntry] FOR DELETE
AS
BEGIN
	IF @@ROWCOUNT != 1
	BEGIN
		DELETE [BusyEntry] 
		FROM
			[BusyEntry]
			INNER JOIN [deleted]
				ON [deleted].[ID] = [BusyEntry].[AssignmentID]
		IF @@ERROR != 0
		BEGIN
			ROLLBACK TRANSACTION
			RETURN
		END
		RETURN
	END
	
	DECLARE 
		@prev int,
		@assignmentID int,
		@rv int
	SELECT
		@assignmentID = deleted.[AssignmentID],
		@prev = deleted.[EmployeeID]
	FROM
		deleted 
	EXEC @rv = pjm5AssignmentChangeBooking @assignmentID
	IF @rv != 0
	BEGIN
		RAISERROR('#cannotremoveassignmentemployee', 18, -1)
		ROLLBACK TRANSACTION
		RETURN
	END
END

GO
