IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'TaskBookingInfoUpdate')
	BEGIN
		PRINT 'Dropping Procedure TaskBookingInfoUpdate'
		DROP  Procedure  TaskBookingInfoUpdate
	END

GO

PRINT 'Creating Procedure TaskBookingInfoUpdate'
GO
/******************************************************************************
**		File: 
**		Name: TaskBookingInfoUpdate
**		Desc: 
**
**		This template can be customized:
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: 
**		Date: 
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**		06.10.09	SYV				  pjm6AssignmentCheckBudgetOverdraft
**		07.03.13	SOV				 OpenXml  Xml
*******************************************************************************/
CREATE Procedure TaskBookingInfoUpdate
	@Xml XML
AS
	DECLARE @TaskID INT, @ProjectID INT, @State TState, @rv int
	
	SET NOCOUNT ON

	SELECT @TaskID = [Task].[ID], @ProjectID = [Task].[ProjectID], @State = [Task].[State]
	FROM
		@Xml.nodes('/Task') AS List(XmlTable)
		INNER JOIN [Task]
			ON [Task].[ID] = [XmlTable].value('ID[1]', 'int')
	
	BEGIN TRANSACTION
	
	IF EXISTS (
		SELECT * FROM [Project] WHERE [ID] = @ProjectID AND [MsProjectID] IS NULL)
	BEGIN
		DELETE [BusyEntry] WHERE [TaskID] = @TaskID
		IF @@error != 0
		BEGIN
			ROLLBACK TRANSACTION
			RETURN 1
		END;	

		WITH [ActualTime] ([AssignmentID], [EmployeeID], [Date], [ActualWork], [ActualOverTimeWork]) AS
		(
			SELECT 
				[TimeEntry].[AssignmentID] as [AssignmentID],
				[TimeEntry].[EmployeeID],
				CONVERT(varchar(8), [TimeEntry].[StartTime], 112) as [Date],
				(CASE [TimeEntry].[Overtime] WHEN 0 THEN SUM([TimeEntry].[Duration]) ELSE 0 END) as [ActualWork],
				(CASE [TimeEntry].[Overtime] WHEN 1 THEN SUM([TimeEntry].[Duration]) ELSE 0 END) as [ActualOvertimeWork]
			FROM 
				[TimeEntry]
			WHERE
				[TimeEntry].[TaskID] = @TaskID AND
				[TimeEntry].[State] IN (2, 3, 6)
			GROUP BY
				[TimeEntry].[AssignmentID], 
				[TimeEntry].[EmployeeID],
				[TimeEntry].[Overtime],
				CONVERT(varchar(8), [TimeEntry].[StartTime], 112)
		)
		INSERT INTO [BusyEntry] ([AssignmentID], [ProjectID], [TaskID], [Date], [EmployeeID], [Planned], [Committed], [ActualWork], [ActualOverTimeWork])
		SELECT
			ISNULL([XmlTable].value('../../AssignmentID[1]', 'int'), [ActualTime].[AssignmentID]),
			@ProjectID,
			@TaskID,
			CAST(ISNULL([XmlTable].value('Date[1]', 'varchar(19)'), [ActualTime].[Date])  AS datetime),
			ISNULL([AssignmentEntry].[EmployeeID], [ActualTime].[EmployeeID]),
			ISNULL([XmlTable].value('WorkMinutes[1]', 'int'), 0),
			ISNULL((CASE [XmlTable].value('Committed[1]', 'varchar(5)') WHEN 'false' THEN 0 ELSE 1 END), 0),
			ISNULL([ActualTime].[ActualWork], 0),
			ISNULL([ActualTime].[ActualOvertimeWork], 0)
		FROM
			@Xml.nodes('/Task/TaskAssignments/TaskAssignment/WorkList/WorkEntry') AS List(XmlTable)
			INNER JOIN [AssignmentEntry]
				ON [AssignmentEntry].[AssignmentID] = [XmlTable].value('../../AssignmentID[1]', 'int')
			FULL OUTER JOIN [ActualTime]
				ON [ActualTime].[AssignmentID] = [XmlTable].value('../../AssignmentID[1]', 'int')
				AND CAST([ActualTime].[Date] As DateTime) = CAST([XmlTable].value('Date[1]', 'varchar(19)') As DateTime)
		IF @@error != 0
		BEGIN
			ROLLBACK TRANSACTION
			RETURN 1
		END
	END	
	
	UPDATE 
		[TaskAssignment]
	SET
		[Work] = CAST([XmlTable].value('Work[1]', 'decimal(18, 4)') * 60 as INT),
		[Units] = [XmlTable].value('Units[1]', 'decimal(18, 4)'),
		[RemainingWork] = [XmlTable].value('RemainingWork[1]', 'decimal(18, 4)'),
		[RemainingOvertimeWork] = [XmlTable].value('RemainingOvertimeWork[1]', 'decimal(18, 4)'),
		[State] = [XmlTable].value('State[1]', 'int')
	FROM
		[TaskAssignment]
		INNER JOIN @Xml.nodes('/Task/TaskAssignments/TaskAssignment') AS List(XmlTable)
			ON ([XmlTable].value('../../ID[1]', 'int') = [TaskAssignment].[TaskID] AND 
				[XmlTable].value('AssignmentID[1]', 'int') = [TaskAssignment].[AssignmentID])
	IF @@error != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN 1
	END
	
	DECLARE @DueDate TDateTime, @TaskClass TClass
	SET @TaskClass = dbo.adfGetClassByName('Pjm5.Task')

	DECLARE @Budget TMoney
	SELECT
		@Budget = SUM([XmlTable].value('Work[1]', 'decimal(18, 4)') * [Assignment].[StandardRate])
	FROM
		@Xml.nodes('/Task/TaskAssignments/TaskAssignment') AS List(XmlTable)
		INNER JOIN [Assignment]
			ON [XmlTable].value('AssignmentID[1]', 'int') = [Assignment].[ID]
	
	UPDATE 
		[Task]
	SET
		[StartDate] = [XmlTable].value('StartDate[1]', 'varchar(19)'),
		[DueDate] = [XmlTable].value('DueDate[1]', 'varchar(19)'),
		@DueDate = [XmlTable].value('DueDate[1]', 'varchar(19)'),
		[Duration] = [XmlTable].value('Duration[1]', 'decimal(18, 4)'),
		[ManHour] = CAST([XmlTable].value('Work[1]', 'decimal(18, 4)') * 60 as INT),
		[Budget] = @Budget
	FROM
		@Xml.nodes('/Task') AS List(XmlTable)	
		INNER JOIN [Task]
			ON ([XmlTable].value('ID[1]', 'int') = [Task].[ID])

	IF @@error != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN 1
	END
	
	IF EXISTS (
		SELECT * FROM [Reminder]
		WHERE [DocumentClass] = @TaskClass AND [DocumentID] = @TaskID AND
			[Subtype] = 'TD'
	)
	BEGIN
		UPDATE [Reminder] SET [EventTime] = @DueDate
		WHERE [DocumentClass] = @TaskClass AND [DocumentID] = @TaskID AND
			[Subtype] = 'TD'
		IF @@error != 0
		BEGIN
			ROLLBACK TRANSACTION
			RETURN 1
		END
	END
	
	exec @rv = pjm6TaskPercentUpdate @TaskID
	IF @rv != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN 1
	END
		
	COMMIT TRANSACTION
	
	RETURN 0
GO

GRANT EXEC ON TaskBookingInfoUpdate TO PUBLIC
GO
