IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm5CalculationCreate]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure pjm5CalculationCreate'
		DROP PROCEDURE [dbo].[pjm5CalculationCreate]
	END
GO

PRINT 'Creating procedure pjm5CalculationCreate'
GO

/******************************************************************************
**		File: pjm5CalculationCreate.sql
**		Name: pjm5CalculationCreate
**		Desc: this procedure automatically generated by Avicom.Adf.Generator
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: Andrew.Maklakov
**		Date: 05/03/2005 11:14:48
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:		Description:
**		--------	--------	-------------------------------------------
**		30.03.11	SYV			  RatesWithVAT   
**		18.04.11	SYV			    
**		04.03.13	SOV			 OpenXml  Xml
**		28.05.13	SOV			      
**								    
**		29.06.15	SAP			  TotalWithoutDiscountAndAdvanced*
*******************************************************************************/
CREATE PROCEDURE [pjm5CalculationCreate]
	@Xml XML
AS
	DECLARE 	
			@Date TDate,
			@Number TCode,
			@FileAs TName,
			@ProjectID TIdentifier,
			@DocumentClass TClass,
			@PeriodStart TDate,
			@PeriodEnd TDate,
			@ServiceTypeID TIdentifier,
			@Description TNotes,
			@Comments TNotes,
			@State TState,
			@ID TIdentifier,
			@CurrencyCode TCode,
			@VATRate TPercent,
			@ProjectType TIdentifier,
			@doc int,
			@Scale TCount,
			@RatesWithVAT TBool,
			@Discount TAmount,
			@DiscountPC TAmount,
			@DiscountPercent TPercent,
			@DiscountView TBool,
			@DiscountType TIdentifier,
			@timeClass TClass

	SET NOCOUNT ON

	SET @State = dbo.adfwfGetInitialState('72390edf-0691-4bca-8972-77424b455803')
	IF @State IS NULL
	BEGIN
		RAISERROR('#accessdenied', 18, -1)
		RETURN 1
	END

	SELECT
		@Date = CAST([XmlTable].value('Date[1]', 'nvarchar(19)') AS datetime),
		@Number = [XmlTable].value('Number[1]', 'varchar(32)'),
		@FileAs = [XmlTable].value('FileAs[1]', 'nvarchar(512)'),
		@ProjectID = [XmlTable].value('ProjectID[1]', 'int'),
		@DocumentClass = [XmlTable].value('DocumentClass[1]', 'int'),
		@PeriodStart = CAST([XmlTable].value('PeriodStart[1]', 'nvarchar(19)') AS datetime),
		@PeriodEnd = CAST([XmlTable].value('PeriodEnd[1]', 'nvarchar(19)') AS datetime),
		@ServiceTypeID = [XmlTable].value('ServiceTypeID[1]', 'int'),
		@CurrencyCode = [XmlTable].value('CurrencyCode[1]', 'varchar(32)'),
		@Description = [XmlTable].value('Description[1]', 'nvarchar(max)'),
		@Comments = [XmlTable].value('Comments[1]', 'nvarchar(max)'),
		@ProjectType = [Project].[ProjectTypeID],
		@Scale = [XmlTable].value('Scale[1]', 'int'),
		@Discount = [XmlTable].value('Discount[1]', 'decimal(18,4)'),
		@DiscountPC = [XmlTable].value('DiscountPC[1]', 'decimal(18,4)'),
		@DiscountPercent = [XmlTable].value('DiscountPercent[1]', 'decimal(18,4)'),
		@DiscountView = [XmlTable].value('DiscountView[1]', 'bit'),
		@DiscountType = [XmlTable].value('DiscountType[1]', 'int')
	FROM
		@Xml.nodes('/pjm5CalculationGet/Calculation') AS List(XmlTable)
		INNER JOIN [Project]
			ON [Project].[ID] = [XmlTable].value('ProjectID[1]', 'int')
	
	DECLARE @EmployeeID TIdentifier
	SET @EmployeeID = dbo.adfGetCurrentEmployeeID()
	IF dbo.adfHasAccessRight(dbo.adfGetRightID('ManageAllCalculations')) = 0 AND
		dbo.fnPjm5HasFinansDataAccess(@ProjectID, @EmployeeID, NULL, NULL) = 0
	BEGIN
		RAISERROR('#accessdenied', 18, -1)
		RETURN 1
	END

	IF @ProjectType NOT IN (1, 2)
	BEGIN
		RAISERROR('#wrongprojecttype', 18, -1)
		RETURN 1
	END
	
	DECLARE @ApplyVAT TBool
	SET @VATRate = 0
	
	SET @timeClass = dbo.adfGetClassByName('Pjm5.TimeEntry')

	SELECT 
		@ApplyVAT = [ApplyVAT],
		@RatesWithVAT = CASE WHEN @DocumentClass = @timeClass THEN [RatesWithVAT] ELSE 0 END
	FROM
		[Project] 
	WHERE 
		[Project].[ID] = @ProjectID

	IF @ApplyVAT = 1
	BEGIN
		SET @VATRate = dbo.fnPjm5GetVATRate()
	END

	--      
	DECLARE @Cost TMoney = 0,
			@CostPC TMoney = 0,
			@Total TMoney,
			@TotalWithVAT TMoney,
			@TotalPC TMoney,
			@TotalWithVATPC TMoney

	SET @Cost = dbo.fnPjm6GetCalculationTotal(@DiscountType, @DiscountView, @DiscountPercent, @Discount, @Cost)
	SET @CostPC = dbo.fnPjm6GetCalculationTotal(@DiscountType, @DiscountView, @DiscountPercent, @DiscountPC, @CostPC)

	SET @Total = (1 - @RatesWithVAT) * @Cost + @RatesWithVAT * @Cost / (1 + @VATRate)
	SET @TotalWithVAT = @RatesWithVAT * @Cost + (1 - @RatesWithVAT) * @Cost * (1 + @VATRate)
	SET @TotalPC = (1 - @RatesWithVAT) * @CostPC + @RatesWithVAT * @CostPC / (1 + @VATRate)
	SET @TotalWithVATPC = @RatesWithVAT * @CostPC + (1 - @RatesWithVAT) * @CostPC * (1 + @VATRate)
	
	BEGIN TRANSACTION
	INSERT INTO [Calculation]
		([Flag], [State], [Date], [Number], [FileAs], [ProjectID], [DocumentClass], [CurrencyCode], [PeriodStart], [PeriodEnd], [ServiceTypeID],
		[VATRate], [Comments],
		[TotalPC], [TotalWithVATPC], [Description],
		[Scale], [RatesWithVAT], [Discount], [DiscountPC], [DiscountPercent], [DiscountView], [DiscountType],
		[Total], [TotalWithVAT], [TotalWithoutDiscountAndAdvanced],
		[TotalWithVATWithoutDiscountAndAdvanced], 
		[TotalWithoutDiscountAndAdvancedPC], [TotalWithVATWithoutDiscountAndAdvancedPC])
	VALUES
		(0, @State, @Date, @Number, @FileAs, @ProjectID, @DocumentClass, @CurrencyCode, @PeriodStart, @PeriodEnd, @ServiceTypeID,
		@VATRate, @Comments,
		@TotalPC, @TotalWithVATPC, @Description,
		@Scale, @RatesWithVAT, @Discount, @DiscountPC, @DiscountPercent, @DiscountView, @DiscountType,
		@Total, @TotalWithVAT,0,0,0,0)
	IF @@ERROR != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN 1
	END
	SET @ID = SCOPE_IDENTITY()
	COMMIT TRANSACTION
	EXEC pjm5CalculationGet @ID

	RETURN 0
GO

GRANT EXECUTE ON pjm5CalculationCreate TO PUBLIC
GO
