IF EXISTS (SELECT * FROM sysobjects WHERE type = 'TR' AND name = 'pjm5trCalculationLineInsert')
	BEGIN
		PRINT 'Dropping Trigger pjm5trCalculationLineInsert'
		DROP  Trigger pjm5trCalculationLineInsert
	END
GO

/******************************************************************************
**		File: 
**		Name: pjm5trCalculationLineInsert
**		Desc: 
**
**		This template can be customized:
**              
**
**		Auth: 
**		Date: 
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:				Description:
**		--------		--------				-------------------------------------------
**    
*******************************************************************************/

PRINT 'Creating Trigger pjm5trCalculationLineInsert'
GO
CREATE Trigger pjm5trCalculationLineInsert 
ON [CalculationLine] FOR INSERT
AS
BEGIN
	IF @@ROWCOUNT = 0
		RETURN
	INSERT INTO [Attachment]
		(
		[DocumentClass], [DocumentID], [Name],
		[LinkDocumentClass], [LinkDocumentID], [AttachmentTypeID]
		)
	SELECT
		[inserted].[DocumentClass], [inserted].[DocumentID], '',
		[Calculation].[Class], [Calculation].[ID], 3
	FROM
		[inserted]
		INNER JOIN [Calculation]
			ON [Calculation].[ID] = [inserted].[CalculationID]
	WHERE
		[inserted].[DocumentID] IS NOT NULL
	IF @@ERROR != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN
	END
	
	UPDATE
		[TimeEntry]
	SET
		[TimeEntry].[DivisionID] = [Employee].[DivisionID],
		[TimeEntry].[State] = 3,
		[TimeEntry].[Modified] = DEFAULT,
		[TimeEntry].[ModifiedBy] = DEFAULT
	FROM
		[TimeEntry]
		INNER JOIN [Employee]
			ON [Employee].[ID] = [TimeEntry].[EmployeeID]
		INNER JOIN [inserted]
			ON [TimeEntry].[Class] = [inserted].[DocumentClass] AND 
				[TimeEntry].[ID] = [inserted].[DocumentID] AND
				[TimeEntry].[State] = 2
	IF @@error != 0
	BEGIN
		RAISERROR('#CannotApproveCalculationTimeEntry', 18, -1)
		ROLLBACK TRANSACTION
		RETURN
	END

	UPDATE
		[Expense]
	SET
		[Expense].[DivisionID] = [Employee].[DivisionID],
		[Expense].[State] = 3,
		[Expense].[Modified] = DEFAULT,
		[Expense].[ModifiedBy] = DEFAULT
	FROM
		[Expense]
		INNER JOIN [Employee]
			ON [Employee].[ID] = [Expense].[EmployeeID]
		INNER JOIN [inserted]
			ON [Expense].[Class] = [inserted].[DocumentClass] AND 
				[Expense].[ID] = [inserted].[DocumentID] AND
				[Expense].[State] = 2
	IF @@error != 0
	BEGIN
		RAISERROR('#CannotApproveCalculationExpense', 18, -1)
		ROLLBACK TRANSACTION
		RETURN
	END
	
	UPDATE
		[ServiceRequest]
	SET
		[ServiceRequest].[DivisionID] = [Employee].[DivisionID],
		[ServiceRequest].[State] = 4,
		[ServiceRequest].[Modified] = DEFAULT,
		[ServiceRequest].[ModifiedBy] = DEFAULT
	FROM
		[ServiceRequest]
		INNER JOIN [Employee]
			ON [Employee].[ID] = [ServiceRequest].[EmployeeID]
		INNER JOIN [inserted]
			ON [ServiceRequest].[Class] = [inserted].[DocumentClass] AND 
				[ServiceRequest].[ID] = [inserted].[DocumentID] AND
				[ServiceRequest].[State] = 3
	IF @@error != 0
	BEGIN
		RAISERROR('#CannotApproveCalculationServiceRequest', 18, -1)
		ROLLBACK TRANSACTION
		RETURN
	END

	UPDATE
		[TimeEntry]
	SET
		[TimeEntry].[State] = 6,
		[TimeEntry].[Modified] = DEFAULT,
		[TimeEntry].[ModifiedBy] = DEFAULT
	FROM
		[TimeEntry]
		INNER JOIN [inserted]
			ON [TimeEntry].[Class] = [inserted].[DocumentClass] AND 
				[TimeEntry].[ID] = [inserted].[DocumentID]
	IF @@error != 0
	BEGIN
		RAISERROR('#CannotApproveCalculationTimeEntry', 18, -1)
		ROLLBACK TRANSACTION
		RETURN
	END
	
	UPDATE
		[Expense]
	SET
		[Expense].[State] = 6,
		[Expense].[Modified] = DEFAULT,
		[Expense].[ModifiedBy] = DEFAULT
	FROM
		[Expense]
		INNER JOIN [inserted]
			ON [Expense].[Class] = [inserted].[DocumentClass] AND 
				[Expense].[ID] = [inserted].[DocumentID]
	IF @@error != 0
	BEGIN
		RAISERROR('#CannotApproveCalculationExpense', 18, -1)
		ROLLBACK TRANSACTION
		RETURN
	END

	UPDATE
		[ServiceRequest]
	SET
		[ServiceRequest].[State] = 5,
		[ServiceRequest].[Modified] = DEFAULT,
		[ServiceRequest].[ModifiedBy] = DEFAULT
	FROM
		[ServiceRequest]
		INNER JOIN [inserted]
			ON [ServiceRequest].[Class] = [inserted].[DocumentClass] AND 
				[ServiceRequest].[ID] = [inserted].[DocumentID]
	IF @@error != 0
	BEGIN
		RAISERROR('#CannotApproveCalculationServiceRequest', 18, -1)
		ROLLBACK TRANSACTION
		RETURN
	END

END

GO

IF EXISTS (SELECT * FROM sysobjects WHERE type = 'TR' AND name = 'pjm5trCalculationLineDelete')
	BEGIN
		PRINT 'Dropping Trigger pjm5trCalculationLineDelete'
		DROP  Trigger pjm5trCalculationLineDelete
	END
GO

/******************************************************************************
**		File: 
**		Name: pjm5trCalculationLineDelete
**		Desc: 
**
**		This template can be customized:
**              
**
**		Auth: 
**		Date: 
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:				Description:
**		--------	--------			-------------------------------------------
**		18.03.13	SAP					   Amount  
**										 AmountBeforeFinanceDocumentInsert
**		10.07.13	SOV					   " "  EntryAmount
**		31.07.13	SAP					   " "  EntryAmount
**		27.08.13	SOV					          
*******************************************************************************/

PRINT 'Creating Trigger pjm5trCalculationLineDelete'
GO
CREATE Trigger pjm5trCalculationLineDelete 
ON [CalculationLine] FOR DELETE
AS
BEGIN
	IF @@ROWCOUNT = 0
		RETURN

	DELETE [Attachment]
	FROM
		[Attachment]
		INNER JOIN [deleted]
			ON ([deleted].[DocumentClass] = [Attachment].[DocumentClass] AND 
				[deleted].[DocumentID] = [Attachment].[DocumentID])
		INNER JOIN [Calculation]
			ON ([Calculation].[ID] = [deleted].[CalculationID] AND
				[Calculation].[Class] = [Attachment].[LinkDocumentClass] AND 
				[Calculation].[ID] = [Attachment].[LinkDocumentID])
	WHERE
		[Attachment].[AttachmentTypeID] = 3
	IF @@ERROR != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN
	END

	UPDATE
		[EntryAmount]
	SET
		[Amount] = [AmountBeforeFinanceDocumentInsert],
		[ModifiedInFinance] = NULL,
		[ModifiedByInFinance] = NULL,
		[Price] = ISNULL([TimeEntry].[Rate], 0)
	FROM 
		[EntryAmount]
		INNER JOIN [deleted]
			ON [deleted].[DocumentID] = [EntryAmount].[ID]
		INNER JOIN [TimeEntry]
			ON [TimeEntry].[ID] = [deleted].[DocumentID] AND
				[deleted].[DocumentClass] = [TimeEntry].[Class]
	WHERE
		[TimeEntry].[State] != 3
	IF @@ERROR != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN
	END			

	UPDATE
		[TimeEntry]
	SET
		[TimeEntry].[State] = 3,
		[TimeEntry].[Modified] = DEFAULT,
		[TimeEntry].[ModifiedBy] = DEFAULT
	FROM
		[TimeEntry]
		INNER JOIN [deleted]
			ON [TimeEntry].[Class] = [deleted].[DocumentClass] AND 
				[TimeEntry].[ID] = [deleted].[DocumentID]
	WHERE
		[TimeEntry].[State] = 6
	IF @@error != 0
	BEGIN
		RAISERROR('#CannotRecommitCalculationTimeEntry', 18, -1)
		ROLLBACK TRANSACTION
		RETURN
	END
	
	UPDATE
		[Expense]
	SET
		[Expense].[State] = 3,
		[Expense].[Modified] = DEFAULT,
		[Expense].[ModifiedBy] = DEFAULT
	FROM
		[Expense]
		INNER JOIN [deleted]
			ON [Expense].[Class] = [deleted].[DocumentClass] AND 
				[Expense].[ID] = [deleted].[DocumentID]
	WHERE
		[Expense].[State] = 6
	IF @@error != 0
	BEGIN
		RAISERROR('#CannotRecommitCalculationExpense', 18, -1)
		ROLLBACK TRANSACTION
		RETURN
	END

	UPDATE
		[ServiceRequest]
	SET
		[ServiceRequest].[State] = 4,
		[ServiceRequest].[Modified] = DEFAULT,
		[ServiceRequest].[ModifiedBy] = DEFAULT
	FROM
		[ServiceRequest]
		INNER JOIN [deleted]
			ON [ServiceRequest].[Class] = [deleted].[DocumentClass] AND 
				[ServiceRequest].[ID] = [deleted].[DocumentID]
	WHERE
		[ServiceRequest].[State] = 5
	IF @@error != 0
	BEGIN
		RAISERROR('#CannotRecommitCalculationServiceRequest', 18, -1)
		ROLLBACK TRANSACTION
		RETURN
	END
END

GO


IF EXISTS (SELECT * FROM sysobjects WHERE type = 'TR' AND name = 'pjm5trCalculationLineUpdate')
	BEGIN
		PRINT 'Dropping Trigger pjm5trCalculationLineUpdate'
		DROP  Trigger pjm5trCalculationLineUpdate
	END
GO

/******************************************************************************
**		File: 
**		Name: pjm5trCalculationLineUpdate
**		Desc: 
**
**		This template can be customized:
**              
**
**		Auth: 
**		Date: 
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:				Description:
**		--------	--------			-------------------------------------------
**		18.03.11	SYV					     
**		30.03.11	SYV					    "  "  
**		15.01.13	SAP					   
*******************************************************************************/

PRINT 'Creating Trigger pjm5trCalculationLineUpdate'
GO
CREATE Trigger pjm5trCalculationLineUpdate 
ON [CalculationLine] FOR INSERT, UPDATE, DELETE
AS
BEGIN
	IF @@ROWCOUNT = 0
		RETURN
	DECLARE
		@timeClass TClass,
		@serviceRequestClass TClass

	SET @timeClass = dbo.adfGetClassByName('Pjm5.TimeEntry')
	SET @serviceRequestClass = dbo.adfGetClassByName('Pjm5.ServiceRequest')

	UPDATE
		[EntryAmount]
	SET
		[Amount] = [inserted].[Amount],
		[Price] = ISNULL([inserted].[Price], 0)
	FROM 
		[EntryAmount]
		INNER JOIN [inserted]
			ON [inserted].[DocumentClass] = @timeClass AND
				[inserted].[DocumentID] = [EntryAmount].[ID]
	WHERE
		[EntryAmount].[Amount] != [inserted].[Amount] OR
		[EntryAmount].[Price] != [inserted].[Price]
	IF @@ERROR != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN
	END

	DECLARE @changed TABLE 
	(
		[ID] int, 
		[DocumentClass] smallint, 
		[VATRate] decimal(18,4), 
		[RatesWithVAT] bit,
		[ProjectCurrencyCode] nvarchar(3),
		[DiscountView] bit,
		[DiscountType] int,
		[DiscountPercent] TPercent,
		[Discount] TAmount,
		[DiscountPC] TAmount,
		[EditedInProjectCurrency] TBool,
		[CurrencyCode] TCode
	)
	INSERT INTO @changed 
	(
		[ID], 
		[DocumentClass], 
		[VATRate],
		[RatesWithVAT], 
		[ProjectCurrencyCode],
		[DiscountView],
		[DiscountType],
		[DiscountPercent],
		[Discount],
		[DiscountPC],
		[EditedInProjectCurrency],
		[CurrencyCode]
	)
	SELECT DISTINCT
		ISNULL([inserted].[CalculationID], [deleted].[CalculationID]),
		[Calculation].[DocumentClass],
		[Calculation].[VATRate],
		[Calculation].[RatesWithVAT],
		[Project].[CurrencyCode],
		[Calculation].[DiscountView],
		[Calculation].[DiscountType],
		[Calculation].[DiscountPercent],
		[Calculation].[Discount],
		[Calculation].[DiscountPC],
		[Calculation].[EditedInProjectCurrency],
		[Calculation].[CurrencyCode]
	FROM
		[inserted]
		FULL OUTER JOIN [deleted]
			ON [inserted].[ID] = [deleted].[ID]
		INNER JOIN [Calculation]
			ON 	[Calculation].[ID] = ISNULL([inserted].[CalculationID], [deleted].[CalculationID])
		LEFT OUTER JOIN [Project]
			ON [Calculation].[ProjectID] = [Project].[ID]
	WHERE
		[Calculation].[State] != 4

	DECLARE @ID int, @DocumentClass smallint, @VATRate decimal(18,4), @RatesWithVAT bit, @ProjectCurrencyCode nvarchar(3)
	DECLARE 
		@Cost TMoney,
		@CostPC TMoney,
		@TotalAdvanced TMoney, 
		@TotalWithVATAdvanced TMoney, 
		@VATAdvanced TMoney,
		@TotalWithoutDiscount TMoney, 
		@TotalWithVATWithoutDiscount TMoney, 
		@TotalWithoutDiscountPC TMoney, 
		@TotalWithVATWithoutDiscountPC TMoney,
		@Total TMoney, 
		@TotalWithVAT TMoney, 
		@TotalPC TMoney, 
		@TotalWithVATPC TMoney,
		@DiscountView TBool,
		@DiscountType TIdentifier,
		@DiscountPercent TPercent,
		@Discount TAmount,
		@DiscountPC TAmount,
		@EditedInProjectCurrency TBool,
		@CurrencyCode TCode
	DECLARE @totals TABLE 
	(
		[ID] int, 
		[DocumentClass] smallint, 
		[VATRate] decimal(18,4), 
		[RatesWithVAT] bit, 
		[ProjectCurrencyCode] nvarchar(3),
		[TotalWithoutDiscountAndAdvanced] TMoney, 
		[TotalWithVATWithoutDiscountAndAdvanced] TMoney, 
		[TotalWithoutDiscountAndAdvancedPC] TMoney, 
		[TotalWithVATWithoutDiscountAndAdvancedPC] TMoney, 
		[TotalWithoutDiscount] TMoney, 
		[TotalWithVATWithoutDiscount] TMoney, 
		[TotalWithoutDiscountPC] TMoney null, 
		[TotalWithVATWithoutDiscountPC] TMoney null,
		[Total] TMoney, 
		[TotalWithVAT] TMoney, 
		[TotalPC] TMoney null, 
		[TotalWithVATPC] TMoney null
	)
	DECLARE calculations CURSOR FAST_FORWARD FOR 
		SELECT 
			[ID], 
			[DocumentClass], 
			[VATRate], 
			[RatesWithVAT], 
			[ProjectCurrencyCode],
			[DiscountView],
			[DiscountType],
			[DiscountPercent],
			[Discount],
			[DiscountPC],
			[EditedInProjectCurrency],
			[CurrencyCode]
		FROM @changed
	
	OPEN calculations
	FETCH NEXT FROM calculations INTO 
		@ID, 
		@DocumentClass, 
		@VATRate, 
		@RatesWithVAT, 
		@ProjectCurrencyCode,
		@DiscountView,
		@DiscountType,
		@DiscountPercent,
		@Discount,
		@DiscountPC,
		@EditedInProjectCurrency,
		@CurrencyCode	
	WHILE @@FETCH_STATUS = 0
	BEGIN
		IF @DocumentClass = @timeClass
		BEGIN
			SELECT
				@TotalWithoutDiscount = ISNULL(SUM(
					[CalculationLine].[Amount] * [CalculationLine].[Price] - @RatesWithVAT * [CalculationLine].[VAT]), 0),
				@TotalWithVATWithoutDiscount = ISNULL(SUM(
					[CalculationLine].[Amount] * [CalculationLine].[Price] - (@RatesWithVAT - 1) * [CalculationLine].[VAT]), 0)
			FROM
				[Calculation]
				INNER JOIN [CalculationLine]
					ON [CalculationLine].[CalculationID] = [Calculation].[ID]
			WHERE
				[Calculation].[ID] = @ID

			SELECT 
				@TotalAdvanced = ISNULL(SUM([Calculation].[TotalPC]), 0),
				@VATAdvanced = ISNULL(SUM([Calculation].[VATPC]), 0),
				@TotalWithVATAdvanced = ISNULL(SUM([Calculation].[TotalWithVATPC]), 0)
			FROM
				[CalculationAdvance]
				INNER JOIN [Calculation]
					ON [CalculationAdvance].[AdvanceCalculationID] = [Calculation].[ID]
			WHERE 
				[CalculationAdvance].[CalculationID] = @ID
		END
		ELSE
		BEGIN
			SELECT
				@TotalWithoutDiscount = ISNULL(SUM(
					CASE 
						WHEN [CalculationLine].[VATIsIncluded] = 0
							THEN [CalculationLine].[Amount] * [CalculationLine].[Price]
						ELSE [CalculationLine].[Amount] * [CalculationLine].[Price] / (1 + @VATRate)
					END), 0),		
				@TotalWithVATWithoutDiscount = ISNULL(SUM(
					CASE 
						WHEN [CalculationLine].[VATIsIncluded] = 0
							THEN [CalculationLine].[Amount] * [CalculationLine].[Price] + [CalculationLine].[VAT]
						ELSE [CalculationLine].[Amount] * [CalculationLine].[Price]
					END), 0),
				@TotalWithoutDiscountPC = SUM([Expense].[TotalPC]),
				@TotalWithVATWithoutDiscountPC = SUM(
					CASE
						WHEN [Expense].[VATRate] = @VATRate
							THEN [Expense].[TotalWithVATPC]
						ELSE ([Expense].[TotalWithVATPC] - [Expense].[VATPC]) * (1 + @VATRate)
					END)
			FROM
				[Calculation]
				INNER JOIN [CalculationLine]
					ON [CalculationLine].[CalculationID] = [Calculation].[ID]
				LEFT OUTER JOIN [Expense]
					ON [Expense].[Class] = [CalculationLine].[DocumentClass] AND
						[Expense].[ID] = [CalculationLine].[DocumentID]
			WHERE
				[Calculation].[ID] = @ID

			IF @DocumentClass = @serviceRequestClass
			BEGIN
				SELECT 
					@TotalAdvanced = ISNULL(SUM([Calculation].[TotalPC]), 0),
					@VATAdvanced = ISNULL(SUM([Calculation].[VATPC]), 0),
					@TotalWithVATAdvanced = ISNULL(SUM([Calculation].[TotalWithVATPC]), 0)
				FROM
					[CalculationAdvance]
					INNER JOIN [Calculation]
						ON [CalculationAdvance].[AdvanceCalculationID] = [Calculation].[ID]
				WHERE 
					[CalculationAdvance].[CalculationID] = @ID
			END
		END


		SET @TotalWithoutDiscount = ISNULL(@TotalWithoutDiscount, 0)
		SET @TotalWithVATWithoutDiscount = ISNULL(@TotalWithVATWithoutDiscount, 0)
		SET @TotalWithVATAdvanced = ISNULL(@TotalWithVATAdvanced, 0)
		SET @VATAdvanced = ISNULL(@VATAdvanced, 0)
		SET @TotalAdvanced = ISNULL(@TotalAdvanced, 0)
		--   
		IF @DiscountType != 0 
		BEGIN
			--     
			SET @Cost = @TotalWithoutDiscount * (1 - @RatesWithVAT) + @TotalWithVATWithoutDiscount * @RatesWithVAT
			SET @CostPC = ISNULL(@TotalWithoutDiscountPC, @TotalWithoutDiscount) * (1 - @RatesWithVAT) + ISNULL(@TotalWithVATWithoutDiscountPC, @TotalWithVATWithoutDiscount) * @RatesWithVAT
		
			--   
			SET @Discount = CASE WHEN @DiscountView = 0
								THEN @Cost * @DiscountPercent
							ELSE CASE WHEN @CurrencyCode = @ProjectCurrencyCode OR @EditedInProjectCurrency = 0
										THEN @Discount
									ELSE CASE WHEN @CostPC = 0
												THEN 0
											ELSE (@DiscountPC / @CostPC) * @Cost
										END
								END
						END
			SET @DiscountPC = CASE WHEN @DiscountView = 0
								THEN @CostPC * @DiscountPercent
							ELSE CASE WHEN @CurrencyCode = @ProjectCurrencyCode OR @EditedInProjectCurrency = 1
										THEN @DiscountPC
									ELSE CASE WHEN @Cost = 0
												THEN 0
											ELSE (@Discount / @Cost) * @CostPC
										END
								END
						END
			SET @DiscountPercent = CASE WHEN @DiscountView = 0
										THEN @DiscountPercent
									ELSE CASE WHEN @EditedInProjectCurrency = 1
												THEN CASE WHEN @CostPC = 0
															THEN 0
														ELSE @DiscountPC / @CostPC
													END
											ELSE CASE WHEN @Cost = 0
															THEN 0
														ELSE @Discount / @Cost
													END
										END
								END

			SET @Cost = dbo.fnPjm6GetCalculationTotal(@DiscountType, @DiscountView, @DiscountPercent, @Discount, @Cost)
			SET @CostPC = dbo.fnPjm6GetCalculationTotal(@DiscountType, @DiscountView, @DiscountPercent, @DiscountPC, @CostPC)

			SET @Total = (1 - @RatesWithVAT) * @Cost + @RatesWithVAT * @Cost / (1 + @VATRate) + (@TotalWithVATAdvanced - @VATAdvanced)
			SET @TotalWithVAT = @RatesWithVAT * @Cost + (1 - @RatesWithVAT) * @Cost * (1 + @VATRate) + (@TotalWithVATAdvanced - @VATAdvanced) * (1 + @VATRate)
			SET @TotalPC = (1 - @RatesWithVAT) * @CostPC + @RatesWithVAT * @CostPC / (1 + @VATRate) + (@TotalWithVATAdvanced - @VATAdvanced)
			SET @TotalWithVATPC = @RatesWithVAT * @CostPC + (1 - @RatesWithVAT) * @CostPC * (1 + @VATRate) + (@TotalWithVATAdvanced - @VATAdvanced) * (1 + @VATRate)
		END
		ELSE
		BEGIN
			SET @Total = @TotalWithoutDiscount + @TotalAdvanced
			SET @TotalWithVAT = @TotalWithVATWithoutDiscount + @TotalWithVATAdvanced
			SET @TotalPC = ISNULL(@TotalWithoutDiscountPC, @TotalWithoutDiscount + @TotalAdvanced)
			SET @TotalWithVATPC = ISNULL(@TotalWithVATWithoutDiscountPC, @TotalWithVATWithoutDiscount + @TotalWithVATAdvanced)
		END

		INSERT INTO @totals 
		(
			[ID], 
			[DocumentClass], 
			[VATRate], 
			[RatesWithVAT], 
			[ProjectCurrencyCode],
			[TotalWithoutDiscountAndAdvanced], 
			[TotalWithVATWithoutDiscountAndAdvanced], 
			[TotalWithoutDiscountAndAdvancedPC], 
			[TotalWithVATWithoutDiscountAndAdvancedPC], 
			[TotalWithoutDiscount], 
			[TotalWithVATWithoutDiscount], 
			[TotalWithoutDiscountPC], 
			[TotalWithVATWithoutDiscountPC],
			[Total] , 
			[TotalWithVAT], 
			[TotalPC], 
			[TotalWithVATPC]
		)
		VALUES 
		(
			@ID,
			@DocumentClass, 
			@VATRate, 
			@RatesWithVAT, 
			@ProjectCurrencyCode,
			ROUND(@TotalWithoutDiscount,2),
			ROUND(@TotalWithVATWithoutDiscount,2),
			ROUND(ISNULL(@TotalWithoutDiscountPC, @TotalWithoutDiscount),2), 
			ROUND(ISNULL(@TotalWithVATWithoutDiscountPC, @TotalWithVATWithoutDiscount),2),
			ROUND(@TotalWithoutDiscount + @TotalAdvanced,2), 
			ROUND(@TotalWithVATWithoutDiscount + @TotalWithVATAdvanced,2), 
			ROUND(ISNULL(@TotalWithoutDiscountPC, @TotalWithoutDiscount + @TotalAdvanced),2), 
			ROUND(ISNULL(@TotalWithVATWithoutDiscountPC, @TotalWithVATWithoutDiscount + @TotalWithVATAdvanced),2),
			ROUND(@Total,2),
			ROUND(@TotalWithVAT,2),
			ROUND(@TotalPC,2),
			ROUND(@TotalWithVATPC,2)
		)
		FETCH NEXT FROM calculations INTO 
				@ID, 
				@DocumentClass, 
				@VATRate, 
				@RatesWithVAT, 
				@ProjectCurrencyCode,
				@DiscountView,
				@DiscountType,
				@DiscountPercent,
				@Discount,
				@DiscountPC,
				@EditedInProjectCurrency,
				@CurrencyCode
	END
	CLOSE calculations
	DEALLOCATE calculations
	
	UPDATE
		[Calculation]
	SET
		[Calculation].[TotalWithoutDiscountAndAdvanced] = ISNULL([Total].[TotalWithoutDiscountAndAdvanced], 0),
		[Calculation].[TotalWithVATWithoutDiscountAndAdvanced] = ISNULL([Total].[TotalWithVATWithoutDiscountAndAdvanced], 0),
		[Calculation].[TotalWithoutDiscountAndAdvancedPC] = ISNULL([Total].[TotalWithoutDiscountAndAdvancedPC], 0),
		[Calculation].[TotalWithVATWithoutDiscountAndAdvancedPC] = ISNULL([Total].[TotalWithVATWithoutDiscountAndAdvancedPC], 0),
		[Calculation].[TotalWithoutDiscount] = ISNULL([Total].[TotalWithoutDiscount], 0),
		[Calculation].[TotalWithVATWithoutDiscount] = ISNULL([Total].[TotalWithVATWithoutDiscount], 0),
		[Calculation].[TotalWithoutDiscountPC] = ISNULL([Total].[TotalWithoutDiscountPC], 0),
		[Calculation].[TotalWithVATWithoutDiscountPC] = ISNULL([Total].[TotalWithVATWithoutDiscountPC], 0),
		[Calculation].[Total] = ISNULL([Total].[Total], 0),
		[Calculation].[TotalWithVAT] = ISNULL([Total].[TotalWithVAT], 0),
		[Calculation].[TotalPC] = ISNULL([Total].[TotalPC], 0),
		[Calculation].[TotalWithVATPC] = ISNULL([Total].[TotalWithVATPC], 0),
		[Calculation].[Modified] = DEFAULT,
		[Calculation].[ModifiedBy] = DEFAULT,

		[Discount] = @Discount,
			[DiscountPC] = @DiscountPC,
			[DiscountPercent] = @DiscountPercent

	FROM
		[Calculation]
		INNER JOIN @totals AS [Total]
			ON 	[Calculation].[ID] = [Total].[ID]
	WHERE
		[Calculation].[State] != 4

	IF @@ERROR != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN
	END
END

GO
