IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm5CreditMemoUpdate]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure pjm5CreditMemoUpdate'
		DROP PROCEDURE [dbo].[pjm5CreditMemoUpdate]
	END
GO

PRINT 'Creating procedure pjm5CreditMemoUpdate'
GO

/******************************************************************************
**		File: pjm5CreditMemoUpdate.sql
**		Name: pjm5CreditMemoUpdate
**		Desc: this procedure automatically generated by Avicom.Adf.Generator
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: vladislav.dremin
**		Date: 08/30/2005 12:32:19
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**		27.03.13	SAP				  OPENXML	
*******************************************************************************/
CREATE PROCEDURE pjm5CreditMemoUpdate
	@Xml XML
AS
	DECLARE
		@ID TIdentifier,
		@FileAs TName,
		@Date TDate,
		@Number TCode,
		@VAT TMoney,
		@PaymentTypeID TIdentifier,
		@PayeeCompanyID TIdentifier,
		@PayeeBankAccountID TIdentifier,
		@PayerCompanyID TIdentifier,
		@ProjectID	TIdentifier,
		@Value TMoney,
		@CurrencyCode TCode3,
		@ProjectCurrencyCode TCode3,
		@BaseCurrencyRate TMoney,
		@CurrencyRate TMoney,
		@Comments TNotes,
		@Reason TName,
		@Payer TName,		
		@val TVariant,
		@TotalPC TMoney,
		@TotalWithVATPC TMoney,
		@TotalBC TMoney,
		@TotalWithVATBC TMoney
	
	SET NOCOUNT ON
	
	SELECT
		@ID = T.c.value('ID[1]','int'),
		@FileAs = T.c.value('FileAs[1]','nvarchar(512)'),
		@Date = CAST(T.c.value('Date[1]','nvarchar(19)') as datetime),
		@Number = T.c.value('Number[1]','varchar(32)'),
		@VAT = T.c.value('VAT[1]','money'),
		@PaymentTypeID = T.c.value('PaymentTypeID[1]','int'),
		@PayeeCompanyID = T.c.value('SupplierCompanyID[1]','int'),
		@PayeeBankAccountID = T.c.value('PayeeBankAccountID[1]','int'),
		@PayerCompanyID = T.c.value('CustomerCompanyID[1]','int'),
		@ProjectID = T.c.value('ProjectID[1]','int'),
		@Value = T.c.value('Value[1]','money'),
		@CurrencyCode = T.c.value('CurrencyCode[1]','char(3)'),
		@ProjectCurrencyCode = [Project].[CurrencyCode],
		@CurrencyRate = T.c.value('CurrencyRate[1]','money'),
		@BaseCurrencyRate = T.c.value('BaseCurrencyRate[1]','money'),
		@Comments = T.c.value('Comments[1]','nvarchar(max)'),
		@Reason = T.c.value('Reason[1]','nvarchar(256)'),
		@Payer = T.c.value('Payer[1]','nvarchar(256)')
	FROM
		@Xml.nodes('/pjm5CreditMemoGet/CreditMemo') AS T(c)			
		LEFT JOIN [Project]
			ON [Project].[ID] = T.c.value('ProjectID[1]','int')
	
	DECLARE 
		@BaseCurrencyCode TCode3,
		@NationalCurrency TCode3
	EXEC adfParameterGet @Name='BaseCurrency', @Group='CommonBusiness', @Value = @val OUTPUT
	SET @BaseCurrencyCode = CAST(@val as varchar(3))

	EXEC adfParameterGet 'NationalCurrency', 'CommonBusiness', @val OUTPUT	
	SET @NationalCurrency = CAST(@val AS varchar(8))
	
	IF @BaseCurrencyCode = @CurrencyCode
	BEGIN
		SET @BaseCurrencyRate = 1.0
	END
	
	IF @ProjectCurrencyCode = @CurrencyCode
	BEGIN
		SET @CurrencyRate = 1.0
	END
	
	SET	@TotalPC = ROUND(CASE 
						WHEN @CurrencyCode = @NationalCurrency THEN (@Value - @VAT) / @CurrencyRate
						ELSE (@Value - @VAT) * @CurrencyRate
					END, 2)
	SET	@TotalWithVATPC = ROUND(CASE 
						WHEN @CurrencyCode = @NationalCurrency
							THEN @Value / @CurrencyRate
						ELSE @Value * @CurrencyRate
					END, 2)

	SET	@TotalBC = ROUND(CASE 
						WHEN @CurrencyCode = @NationalCurrency
							THEN (@Value - @VAT) / @BaseCurrencyRate
						ELSE (@Value - @VAT) * @BaseCurrencyRate
					END, 2)
	SET	@TotalWithVATBC= ROUND(CASE 
						WHEN @CurrencyCode = @NationalCurrency
							THEN @Value / @BaseCurrencyRate
						ELSE @Value * @BaseCurrencyRate
					END, 2)

	BEGIN TRANSACTION
	UPDATE 
		[CreditMemo]
	SET
		[CreditMemo].[FileAs] = @FileAs,
		[CreditMemo].[Date] = @Date,
		[CreditMemo].[Number] = @Number,
		[CreditMemo].[VAT] = @VAT,
		[CreditMemo].[PaymentTypeID] = @PaymentTypeID,		
		[CreditMemo].[PayeeCompanyID] = @PayeeCompanyID,
		[CreditMemo].[PayeeBankAccountID]= @PayeeBankAccountID,
		[CreditMemo].[PayerCompanyID] = @PayerCompanyID,
		[CreditMemo].[ProjectID] = @ProjectID,
		[CreditMemo].[Value] = @Value,
		[CreditMemo].[CurrencyCode] = @CurrencyCode,
		[CreditMemo].[CurrencyRate] = @CurrencyRate,
		[CreditMemo].[BaseCurrencyRate] = @BaseCurrencyRate,	
		[CreditMemo].[Reason] = @Reason,
		[CreditMemo].[Payer] = @Payer,
		[CreditMemo].[Comments] = @Comments,
		[CreditMemo].[Modified] = GETDATE(),
		[CreditMemo].[ModifiedBy] = dbo.adfGetCurrentUserID(),
		[CreditMemo].[TotalPC] = @TotalPC,
		[CreditMemo].[TotalWithVATPC] = @TotalWithVATPC,
		[CreditMemo].[TotalBC] = @TotalBC,
		[CreditMemo].[TotalWithVATBC] = @TotalWithVATBC
	WHERE
		[CreditMemo].[ID] = @ID

	IF @@ERROR != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN 1
	END
	COMMIT TRANSACTION

	EXEC pjm5CreditMemoGet @ID

	RETURN 0
GO

GRANT EXECUTE ON pjm5CreditMemoUpdate TO PUBLIC
GO
 