IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm5DocumentCardBrowseByFolder]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure pjm5DocumentCardBrowseByFolder'
		DROP PROCEDURE [dbo].[pjm5DocumentCardBrowseByFolder]
	END
GO

PRINT 'Creating procedure pjm5DocumentCardBrowseByFolder'
GO

/******************************************************************************
**		File: pjm5DocumentCardBrowseByFolder.sql
**		Name: pjm5DocumentCardBrowseByFolder
**		Desc: this procedure automatically generated by Avicom.Adf.Generator
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: vladislav.dremin
**		Date: 08/30/2005 12:32:19
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**	07.09.09		syv				  AnswerTo   
*******************************************************************************/
CREATE PROCEDURE [pjm5DocumentCardBrowseByFolder]
	@FolderID TIdentifier,
	@DocumentTypeSelector TIdentifier = 0,
	@CorrespondentSelector int = 0,
	@CorrespondentID TIdentifier = NULL,
	@ClassifierSelector int = 0,
	@ClassifierID TIdentifier = NULL,
	@StateSelector int = 0,
	@DateSelector int = 0,
	@PeriodStart TDate = NULL,
	@PeriodEnd TDate = NULL

AS
	SET NOCOUNT ON
	DECLARE 
		@UserID TIdentifier,
		@ReadItems TBool,
		@FolderPublication TBool
	IF @FolderID > 0
	BEGIN
		IF dbo.adfHasAccessRight(dbo.adfGetRightID('AccessToPublicFolders')) = 0
		BEGIN
			RAISERROR('#accessdenied', 18, -1)
			RETURN 1
		END
	END
		
	SET @UserID = dbo.adfGetCurrentUserID()
	SET @ReadItems = dbo.fnFolderHasRightAccess(@FolderID, @UserID, 'CreateItems') |
		dbo.fnFolderHasRightAccess(@FolderID, @UserID, 'ReadItems') |
		dbo.fnFolderHasRightAccess(@FolderID, @UserID, 'FolderOwner')
	SET @FolderPublication = dbo.fnFolderHasRightAccess(@FolderID, @UserID, 'FolderPublication')
	
	DECLARE @Date TDate, @q int
	SET @Date = CAST(CONVERT(varchar(8), GETDATE(), 112) AS DATETIME)
	SET	@q = CASE CAST(MONTH(@Date) % 3 as int)
			WHEN 1 THEN 0
			WHEN 2 THEN 1
			ELSE 2
		END
	IF @DateSelector = 2 
		SELECT
			@PeriodStart = DATEADD(day, 1 - DATEPART(day, @Date), @Date),
			@PeriodEnd = DATEADD(day, -1, DATEADD(month, 1, @Date))
	IF @DateSelector = 3
		SELECT
			@PeriodStart = DATEADD(month, 0 - @q, DATEADD(day, 1 - DATEPART(day, @Date), @Date)),
			@PeriodEnd = DATEADD(day, -1, DATEADD(month, 3, @PeriodStart))
	IF @DateSelector = 4
		SELECT
			@PeriodStart = DATEADD(month, 0 - @q - 3, DATEADD(day, 1 - DATEPART(day, @Date), @Date)),
			@PeriodEnd = DATEADD(day, -1, DATEADD(month, 3, @PeriodStart))

	SELECT
		[DocumentCard].[Class],
		[DocumentCard].[ID],
		[DocumentCard].[State],
		[DocumentCard].[Flag],
		[DocumentCard].[FileAs] ,
		[DocumentCard].[FolderID],
		[DocumentCard].[Number],
		[DocumentCard].[Date],
		[DocumentCard].[CompanyID],
		[DocumentCard].[ContactID],
		[DocumentCard].[CorrespondentCompanyID],
		[DocumentCard].[CorrespondentContactID],
		[DocumentCard].[CaseID],
		[DocumentCard].[DocumentSendTypeID],
		ISNULL([DocumentCard].[NumberIn], [DocumentCard].[NumberOut]) AS [CorrespondentNumber],
		ISNULL([DocumentCard].[DateIn], [DocumentCard].[DateOut]) AS [CorrespondentDate],

		[DocumentCard].[DocumentCardClassID],
		[DocumentCard].[ID] AS [DocumentCardID],
		[DocumentCard].[DivisionID],
		[DocumentCard].[CustodyPlaceID],
		[DocumentCard].[AppendixCount],
		[DocumentCard].[PageCount],
		[DocumentCard].[Package],
		[DocumentCard].[CardOwnerID],
		[DocumentCard].[Copy],
		[DocumentCard].[StorePeriod],

		[DocumentItem].[ID]		AS [DocumentItemID],
		[DocumentItem].[State]	AS [DocumentItemState],
		[DocumentItem].[Flag]	AS [DocumentItemFlag],
		[DocumentItem].[FileName],
		[DocumentItem].[Extension],
		[DocumentItem].[LatestVersion],
		[DocumentItem].[CheckedOutBy],
		[DocumentVersion].[DataLength],
		[Folder].[FileAs] AS [FolderFileAs],
		[DocumentCard].[Comments],
		[DocumentCard].[Created],
		[DocumentCard].[CreatedBy],
		[DocumentCard].[Modified],
		[DocumentCard].[ModifiedBy],
		[DocumentCard].[Timestamp],
		CAST('6cc877ce-4425-4e49-a3d5-76b01ae709ae' as uniqueidentifier) AS [Guid]
	FROM
		[DocumentCard]
		INNER JOIN [Folder]
			ON [DocumentCard].[FolderID] = [Folder].[ID]
		INNER JOIN [Case]
			ON [DocumentCard].[CaseID] = [Case].[ID]
		LEFT OUTER JOIN [DocumentItem]
			ON [DocumentItem].[DocumentCardID] = [DocumentCard].[ID]
		LEFT OUTER JOIN [DocumentVersion]
			ON [DocumentVersion].[DocumentItemID] = [DocumentItem].[ID] AND
				[DocumentVersion].[Version] = [DocumentItem].[LatestVersion]
	WHERE
		(
			@ReadItems != 0 OR 
			[Folder].[ID] = -1 AND [DocumentCard].[ModifiedBy] = @UserID
		) AND
		[DocumentCard].[FolderID] = @FolderID AND
		(@StateSelector = 0 OR [DocumentCard].[State] = @StateSelector) AND
		(
			@DocumentTypeSelector = 0 OR
			@DocumentTypeSelector = 2 AND [Case].[AllowInternal] = 1 OR
			@DocumentTypeSelector = 3 AND [Case].[AllowIncoming] = 1 OR
			@DocumentTypeSelector = 4 AND [Case].[AllowOutgoing] = 1
		) AND
		(
			@CorrespondentSelector = 0 OR
			@CorrespondentID IS NULL AND [DocumentCard].[CorrespondentCompanyID] IS NULL OR 
			[DocumentCard].[CorrespondentCompanyID] = @CorrespondentID
		) AND
		(
			@ClassifierSelector = 0 OR 
			@ClassifierID IS NULL AND [DocumentCard].[DocumentCardClassID] IS NULL OR 
			[DocumentCard].[DocumentCardClassID] = @ClassifierID
		) AND
		(
			@DateSelector = 0 OR
			@DateSelector = 1 AND [DocumentCard].[Date] IS NULL OR
			@DateSelector > 1 AND [DocumentCard].[Date] BETWEEN @PeriodStart AND @PeriodEnd
		)
	UNION
	SELECT
		[DocumentItem].[Class],
		[DocumentItem].[ID],
		[DocumentItem].[State],
		[DocumentItem].[Flag],
		[DocumentCard].[FileAs] ,
		[DocumentCard].[FolderID],
		[DocumentCard].[Number],
		NULL AS [Date],
		[DocumentCard].[CompanyID],
		[DocumentCard].[ContactID],
		[DocumentCard].[CorrespondentCompanyID],
		[DocumentCard].[CorrespondentContactID],
		[DocumentCard].[CaseID],
		[DocumentCard].[DocumentSendTypeID],
		NULL AS [CorrespondentNumber],
		NULL AS [CorrespondentDate],

		[DocumentCard].[DocumentCardClassID],
		[DocumentItem].[DocumentCardID],
		[DocumentCard].[DivisionID],
		[DocumentCard].[CustodyPlaceID],
		[DocumentCard].[AppendixCount],
		[DocumentCard].[PageCount],
		[DocumentCard].[Package],
		[DocumentCard].[CardOwnerID],
		[DocumentCard].[Copy],
		[DocumentCard].[StorePeriod],

		[DocumentItem].[ID]		AS [DocumentItemID],
		[DocumentItem].[State]	AS [DocumentItemState],
		[DocumentItem].[Flag]	AS [DocumentItemFlag],
		[DocumentItem].[FileName],
		[DocumentItem].[Extension],
		[DocumentItem].[LatestVersion],
		[DocumentItem].[CheckedOutBy],
		[DocumentVersion].[DataLength],
		[Folder].[FileAs] AS [FolderFileAs],
		[DocumentCard].[Comments],
		[DocumentCard].[Created],
		[DocumentCard].[CreatedBy],
		[DocumentCard].[Modified],
		[DocumentCard].[ModifiedBy],
		[DocumentCard].[Timestamp],
		CAST('acb865ab-ae3c-429e-af10-d14d6a46363b' as uniqueidentifier) AS [Guid]
	FROM
		[DocumentCard]
		INNER JOIN [Folder]
			ON [DocumentCard].[FolderID] = [Folder].[ID]
		INNER JOIN [DocumentItem]
			ON [DocumentItem].[DocumentCardID] = [DocumentCard].[ID]
		INNER JOIN [DocumentVersion]
			ON [DocumentVersion].[DocumentItemID] = [DocumentItem].[ID] AND
				[DocumentVersion].[Version] = [DocumentItem].[LatestVersion]
	WHERE
		(
			@ReadItems != 0 OR 
			[Folder].[ID] = -1 AND [DocumentCard].[ModifiedBy] = @UserID
		) AND

		[DocumentCard].[CaseID] IS NULL AND
		[DocumentCard].[FolderID] = @FolderID AND
		(
			@DocumentTypeSelector = 0 OR
			@DocumentTypeSelector = 1
		) AND
		(
			@FolderPublication = 1 OR
			[DocumentItem].[State] > 1 OR
			[DocumentItem].[CreatedBy] = @UserID OR
			[DocumentItem].[LatestVersion] > 1
		)AND
		(
			@DateSelector = 0 OR
			@DateSelector = 1 OR
			@DateSelector > 1 AND [DocumentCard].[Modified] BETWEEN @PeriodStart AND @PeriodEnd
		)
	RETURN 0
GO

GRANT EXECUTE ON [pjm5DocumentCardBrowseByFolder] TO PUBLIC
GO
 
IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm5DocumentCardBrowse]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure pjm5DocumentCardBrowse'
		DROP PROCEDURE [dbo].[pjm5DocumentCardBrowse]
	END
GO

PRINT 'Creating procedure pjm5DocumentCardBrowse'
GO

/******************************************************************************
**		File: pjm5DocumentCardBrowse.sql
**		Name: pjm5DocumentCardBrowse
**		Desc: this procedure automatically generated by Avicom.Adf.Generator
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: vladislav.dremin
**		Date: 08/30/2005 12:32:19
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**    07.09.09		syv				  AnswerTo  
*******************************************************************************/
CREATE PROCEDURE [pjm5DocumentCardBrowse]
	@CompanyID TIdentifier,
	@CorrespondentSelector int,
	@CorrespondentID TIdentifier,
	@ClassifierSelector int,
	@ClassifierID TIdentifier,
	@StateSelector int,
	@DateSelector int,
	@PeriodStart TDate,
	@PeriodEnd TDate
AS
	SET NOCOUNT ON
	IF dbo.adfHasAccessRight(dbo.adfGetRightID('AccessToPublicFolders')) = 0
	BEGIN
		RAISERROR('#accessdenied', 18, -1)
		RETURN 1
	END
	
	DECLARE @Date TDate, @q int
	SET @Date = CAST(CONVERT(varchar(8), GETDATE(), 112) AS DATETIME)
	SET	@q = CASE CAST(MONTH(@Date) % 3 as int)
			WHEN 1 THEN 0
			WHEN 2 THEN 1
			ELSE 2
		END
	IF @DateSelector = 2 
		SELECT
			@PeriodStart = DATEADD(day, 1 - DATEPART(day, @Date), @Date),
			@PeriodEnd = DATEADD(day, -1, DATEADD(month, 1, @Date))
	IF @DateSelector = 3
		SELECT
			@PeriodStart = DATEADD(month, 0 - @q, DATEADD(day, 1 - DATEPART(day, @Date), @Date)),
			@PeriodEnd = DATEADD(day, -1, DATEADD(month, 3, @PeriodStart))
	IF @DateSelector = 4
		SELECT
			@PeriodStart = DATEADD(month, 0 - @q - 3, DATEADD(day, 1 - DATEPART(day, @Date), @Date)),
			@PeriodEnd = DATEADD(day, -1, DATEADD(month, 3, @PeriodStart))
		
	SELECT
		[DocumentCard].[Class],
		[DocumentCard].[ID],
		[DocumentCard].[State],
		[DocumentCard].[Flag],
		[DocumentCard].[FileAs] ,
		[DocumentCard].[FolderID],
		[DocumentCard].[Number],
		[DocumentCard].[Date],
		[DocumentCard].[CompanyID],
		[DocumentCard].[ContactID],
		[DocumentCard].[CorrespondentCompanyID],
		[DocumentCard].[CorrespondentContactID],
		[DocumentCard].[CaseID],
		[DocumentCard].[DocumentSendTypeID],

		[DocumentCard].[DocumentCardClassID],
		[DocumentCard].[DivisionID],
		[DocumentCard].[CustodyPlaceID],
		[DocumentCard].[AppendixCount],
		[DocumentCard].[PageCount],
		[DocumentCard].[Package],
		[DocumentCard].[CardOwnerID],
		[DocumentCard].[Copy],
		[DocumentCard].[StorePeriod],

		[DocumentItem].[ID]		AS [DocumentItemID],
		[DocumentItem].[State]	AS [DocumentItemState],
		[DocumentItem].[Flag]	AS [DocumentItemFlag],
		[DocumentItem].[FileName],
		[DocumentItem].[Extension],
		[DocumentItem].[LatestVersion],
		[DocumentItem].[CheckedOutBy],
		[DocumentVersion].[DataLength],
		[Folder].[FileAs] AS [FolderFileAs],
		[DocumentCard].[Comments],
		[DocumentCard].[Created],
		[DocumentCard].[CreatedBy],
		[DocumentCard].[Modified],
		[DocumentCard].[ModifiedBy],
		[DocumentCard].[Timestamp],
		CAST('6cc877ce-4425-4e49-a3d5-76b01ae709ae' as uniqueidentifier) AS [Guid]
	FROM
		[DocumentCard]
		INNER JOIN [Folder]
			ON [DocumentCard].[FolderID] = [Folder].[ID]
		INNER JOIN [Case]
			ON [Case].[ID] = [DocumentCard].[CaseID]
		LEFT OUTER JOIN [DocumentItem]
			ON [DocumentItem].[DocumentCardID] = [DocumentCard].[ID]
		LEFT OUTER JOIN [DocumentVersion]
			ON [DocumentVersion].[DocumentItemID] = [DocumentItem].[ID] AND
				[DocumentVersion].[Version] = [DocumentItem].[LatestVersion]
	WHERE
		[Case].[AllowInternal] = 1 
		AND
		(@CompanyID IS NULL OR [DocumentCard].[CompanyID] = @CompanyID) AND
		(
			@CorrespondentSelector = 0 OR
			@CorrespondentID IS NULL AND [DocumentCard].[CorrespondentCompanyID] IS NULL OR 
			[DocumentCard].[CorrespondentCompanyID] = @CorrespondentID
		) AND
		(
			@ClassifierSelector = 0 OR 
			@ClassifierID IS NULL AND [DocumentCard].[DocumentCardClassID] IS NULL OR 
			[DocumentCard].[DocumentCardClassID] = @ClassifierID
		) AND
		(
			@StateSelector = 0 AND [DocumentCard].[State] != 100 OR 
			[DocumentCard].[State] = @StateSelector
		) AND
		(
			@DateSelector = 0 OR
			@DateSelector = 1 AND [DocumentCard].[Date] IS NULL OR
			@DateSelector > 1 AND [DocumentCard].[Date] BETWEEN @PeriodStart AND @PeriodEnd
		)
		
	RETURN 0
GO

GRANT EXECUTE ON [pjm5DocumentCardBrowse] TO PUBLIC
GO

IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm5IncomingDocumentBrowse]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure pjm5IncomingDocumentBrowse'
		DROP PROCEDURE [dbo].[pjm5IncomingDocumentBrowse]
	END
GO

PRINT 'Creating procedure pjm5IncomingDocumentBrowse'
GO

/******************************************************************************
**		File: pjm5IncomingDocumentBrowse.sql
**		Name: pjm5IncomingDocumentBrowse
**		Desc: this procedure automatically generated by Avicom.Adf.Generator
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: vladislav.dremin
**		Date: 08/30/2005 12:32:19
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**    07.09.09		syv				  AnswerTo  
*******************************************************************************/
CREATE PROCEDURE [pjm5IncomingDocumentBrowse]
	@CompanyID TIdentifier,
	@CorrespondentSelector int,
	@CorrespondentID TIdentifier,
	@ClassifierSelector int,
	@ClassifierID TIdentifier,
	@StateSelector int,
	@DateSelector int,
	@PeriodStart TDate,
	@PeriodEnd TDate
AS
	SET NOCOUNT ON
	IF dbo.adfHasAccessRight(dbo.adfGetRightID('AccessToPublicFolders')) = 0
	BEGIN
		RAISERROR('#accessdenied', 18, -1)
		RETURN 1
	END

	DECLARE @Date TDate, @q int
	SET @Date = CAST(CONVERT(varchar(8), GETDATE(), 112) AS DATETIME)
	SET	@q = CASE CAST(MONTH(@Date) % 3 as int)
			WHEN 1 THEN 0
			WHEN 2 THEN 1
			ELSE 2
		END
	IF @DateSelector = 2 
		SELECT
			@PeriodStart = DATEADD(day, 1 - DATEPART(day, @Date), @Date),
			@PeriodEnd = DATEADD(day, -1, DATEADD(month, 1, @Date))
	IF @DateSelector = 3
		SELECT
			@PeriodStart = DATEADD(month, 0 - @q, DATEADD(day, 1 - DATEPART(day, @Date), @Date)),
			@PeriodEnd = DATEADD(day, -1, DATEADD(month, 3, @PeriodStart))
	IF @DateSelector = 4
		SELECT
			@PeriodStart = DATEADD(month, 0 - @q - 3, DATEADD(day, 1 - DATEPART(day, @Date), @Date)),
			@PeriodEnd = DATEADD(day, -1, DATEADD(month, 3, @PeriodStart))
	/*ELSE 
		SET @PeriodEnd = DATEADD(day, 1, @PeriodEnd)*/
		
	SELECT
		[DocumentCard].[Class],
		[DocumentCard].[ID],
		[DocumentCard].[State],
		[DocumentCard].[Flag],
		[DocumentCard].[FileAs] ,
		[DocumentCard].[FolderID],
		[DocumentCard].[Number],
		[DocumentCard].[Date],
		[DocumentCard].[CompanyID],
		[DocumentCard].[ContactID],
		[DocumentCard].[CorrespondentCompanyID],
		[DocumentCard].[CorrespondentContactID],
		[DocumentCard].[CaseID],
		[DocumentCard].[DocumentSendTypeID],

		[DocumentCard].[DocumentCardClassID],
		[DocumentCard].[DivisionID],
		[DocumentCard].[CustodyPlaceID],
		[DocumentCard].[AppendixCount],
		[DocumentCard].[PageCount],
		[DocumentCard].[Package],
		[DocumentCard].[CardOwnerID],
		[DocumentCard].[Copy],
		[DocumentCard].[StorePeriod],

		[DocumentItem].[ID]		AS [DocumentItemID],
		[DocumentItem].[State]	AS [DocumentItemState],
		[DocumentItem].[Flag]	AS [DocumentItemFlag],
		[DocumentItem].[FileName],
		[DocumentItem].[Extension],
		[DocumentItem].[LatestVersion],
		[DocumentItem].[CheckedOutBy],
		[DocumentVersion].[DataLength],
		[Folder].[FileAs] AS [FolderFileAs],
		[DocumentCard].[Comments],
		[DocumentCard].[Created],
		[DocumentCard].[CreatedBy],
		[DocumentCard].[Modified],
		[DocumentCard].[ModifiedBy],
		[DocumentCard].[Timestamp],
		CAST('6cc877ce-4425-4e49-a3d5-76b01ae709ae' as uniqueidentifier) AS [Guid]
	FROM
		[DocumentCard]
		INNER JOIN [Folder]
			ON [DocumentCard].[FolderID] = [Folder].[ID]
		INNER JOIN [Case]
			ON [Case].[ID] = [DocumentCard].[CaseID]
		LEFT OUTER JOIN [DocumentItem]
			ON [DocumentItem].[DocumentCardID] = [DocumentCard].[ID]
		LEFT OUTER JOIN [DocumentVersion]
			ON [DocumentVersion].[DocumentItemID] = [DocumentItem].[ID] AND
				[DocumentVersion].[Version] = [DocumentItem].[LatestVersion]
	WHERE
		[Case].[AllowIncoming] = 1 
		AND
		(@CompanyID IS NULL OR [DocumentCard].[CompanyID] = @CompanyID) AND
		(
			@CorrespondentSelector = 0 OR
			@CorrespondentID IS NULL AND [DocumentCard].[CorrespondentCompanyID] IS NULL OR 
			[DocumentCard].[CorrespondentCompanyID] = @CorrespondentID
		) AND
		(
			@ClassifierSelector = 0 OR 
			@ClassifierID IS NULL AND [DocumentCard].[DocumentCardClassID] IS NULL OR 
			[DocumentCard].[DocumentCardClassID] = @ClassifierID
		) AND
		(
			@StateSelector = 0 AND [DocumentCard].[State] != 100 OR 
			[DocumentCard].[State] = @StateSelector
		) AND
		(
			@DateSelector = 0 OR
			@DateSelector = 1 AND [DocumentCard].[Date] IS NULL OR
			@DateSelector > 1 AND [DocumentCard].[Date] BETWEEN @PeriodStart AND @PeriodEnd
		)
		
	RETURN 0
GO

GRANT EXECUTE ON [pjm5IncomingDocumentBrowse] TO PUBLIC
GO

IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm5OutgoingDocumentBrowse]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure pjm5OutgoingDocumentBrowse'
		DROP PROCEDURE [dbo].[pjm5OutgoingDocumentBrowse]
	END
GO

PRINT 'Creating procedure pjm5OutgoingDocumentBrowse'
GO

/******************************************************************************
**		File: pjm5OutgoingDocumentBrowse.sql
**		Name: pjm5OutgoingDocumentBrowse
**		Desc: this procedure automatically generated by Avicom.Adf.Generator
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: vladislav.dremin
**		Date: 08/30/2005 12:32:19
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**    07.09.09		syv				  AnswerTo  
*******************************************************************************/
CREATE PROCEDURE [pjm5OutgoingDocumentBrowse]
	@CompanyID TIdentifier,
	@CorrespondentSelector int,
	@CorrespondentID TIdentifier,
	@ClassifierSelector int,
	@ClassifierID TIdentifier,
	@StateSelector int,
	@DateSelector int,
	@PeriodStart TDate,
	@PeriodEnd TDate
AS
	SET NOCOUNT ON
	IF dbo.adfHasAccessRight(dbo.adfGetRightID('AccessToPublicFolders')) = 0
	BEGIN
		RAISERROR('#accessdenied', 18, -1)
		RETURN 1
	END

	DECLARE @Date TDate, @q int
	SET @Date = CAST(CONVERT(varchar(8), GETDATE(), 112) AS DATETIME)
	SET	@q = CASE CAST(MONTH(@Date) % 3 as int)
			WHEN 1 THEN 0
			WHEN 2 THEN 1
			ELSE 2
		END
	IF @DateSelector = 2 
		SELECT
			@PeriodStart = DATEADD(day, 1 - DATEPART(day, @Date), @Date),
			@PeriodEnd = DATEADD(day, -1, DATEADD(month, 1, @Date))
	IF @DateSelector = 3
		SELECT
			@PeriodStart = DATEADD(month, 0 - @q, DATEADD(day, 1 - DATEPART(day, @Date), @Date)),
			@PeriodEnd = DATEADD(day, -1, DATEADD(month, 3, @PeriodStart))
	IF @DateSelector = 4
		SELECT
			@PeriodStart = DATEADD(month, 0 - @q - 3, DATEADD(day, 1 - DATEPART(day, @Date), @Date)),
			@PeriodEnd = DATEADD(day, -1, DATEADD(month, 3, @PeriodStart))
		
	SELECT
		[DocumentCard].[Class],
		[DocumentCard].[ID],
		[DocumentCard].[State],
		[DocumentCard].[Flag],
		[DocumentCard].[FileAs] ,
		[DocumentCard].[FolderID],
		[DocumentCard].[Number],
		[DocumentCard].[Date],
		[DocumentCard].[CompanyID],
		[DocumentCard].[ContactID],
		[DocumentCard].[CorrespondentCompanyID],
		[DocumentCard].[CorrespondentContactID],
		[DocumentCard].[CaseID],
		[DocumentCard].[DocumentSendTypeID],

		[DocumentCard].[DocumentCardClassID],
		[DocumentCard].[DivisionID],
		[DocumentCard].[CustodyPlaceID],
		[DocumentCard].[AppendixCount],
		[DocumentCard].[PageCount],
		[DocumentCard].[Package],
		[DocumentCard].[CardOwnerID],
		[DocumentCard].[Copy],
		[DocumentCard].[StorePeriod],

		[DocumentItem].[ID]		AS [DocumentItemID],
		[DocumentItem].[State]	AS [DocumentItemState],
		[DocumentItem].[Flag]	AS [DocumentItemFlag],
		[DocumentItem].[FileName],
		[DocumentItem].[Extension],
		[DocumentItem].[LatestVersion],
		[DocumentItem].[CheckedOutBy],
		[DocumentVersion].[DataLength],
		[Folder].[FileAs] AS [FolderFileAs],
		[DocumentCard].[Comments],
		[DocumentCard].[Created],
		[DocumentCard].[CreatedBy],
		[DocumentCard].[Modified],
		[DocumentCard].[ModifiedBy],
		[DocumentCard].[Timestamp],
		CAST('6cc877ce-4425-4e49-a3d5-76b01ae709ae' as uniqueidentifier) AS [Guid]
	FROM
		[DocumentCard]
		INNER JOIN [Folder]
			ON [DocumentCard].[FolderID] = [Folder].[ID]
		INNER JOIN [Case]
			ON [Case].[ID] = [DocumentCard].[CaseID]
		LEFT OUTER JOIN [DocumentItem]
			ON [DocumentItem].[DocumentCardID] = [DocumentCard].[ID]
		LEFT OUTER JOIN [DocumentVersion]
			ON [DocumentVersion].[DocumentItemID] = [DocumentItem].[ID] AND
				[DocumentVersion].[Version] = [DocumentItem].[LatestVersion]
	WHERE
		[Case].[AllowOutgoing] = 1 
		AND
		(@CompanyID IS NULL OR [DocumentCard].[CompanyID] = @CompanyID) AND
		(
			@CorrespondentSelector = 0 OR
			@CorrespondentID IS NULL AND [DocumentCard].[CorrespondentCompanyID] IS NULL OR 
			[DocumentCard].[CorrespondentCompanyID] = @CorrespondentID
		) AND
		(
			@ClassifierSelector = 0 OR 
			@ClassifierID IS NULL AND [DocumentCard].[DocumentCardClassID] IS NULL OR 
			[DocumentCard].[DocumentCardClassID] = @ClassifierID
		) AND
		(
			@StateSelector = 0 AND [DocumentCard].[State] != 100 OR 
			[DocumentCard].[State] = @StateSelector
		) AND
		(
			@DateSelector = 0 OR
			@DateSelector = 1 AND [DocumentCard].[Date] IS NULL OR
			@DateSelector > 1 AND [DocumentCard].[Date] BETWEEN @PeriodStart AND @PeriodEnd
		)
		
	RETURN 0
GO

GRANT EXECUTE ON [pjm5OutgoingDocumentBrowse] TO PUBLIC
GO
