﻿IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm7EmployeeNormCreate]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure pjm7EmployeeNormCreate'
		DROP PROCEDURE [dbo].[pjm7EmployeeNormCreate]
	END
GO

PRINT 'Creating procedure pjm7EmployeeNormCreate'
GO

/******************************************************************************
**		File: pjm7EmployeeNormCreate.sql
**		Name: pjm7EmployeeNormCreate
**		Desc: 
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: Nikita.Golyshev
**		Date: 08.07.14
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:		Description:
**		--------	--------	-------------------------------------------
**		21.07.14	SAP			Переработка процедуры (из-за создания документа "Норматив сотрудника")
**		24.07.14	GNV			Добавление значения по умолчанию для поля State и исправление ошибок
*******************************************************************************/
CREATE PROCEDURE [dbo].[pjm7EmployeeNormCreate]
	@Xml XML
AS
	SET NOCOUNT ON

	DECLARE
		@State TState,
		@FileAs TName,
		@EmployeeID TIdentifier,
		@StartDate TDate,
		@NormID TIdentifier,
		@Comments nvarchar(max)

	SELECT
		@EmployeeID = [XmlTable].value('EmployeeID[1]', 'int'),
		@StartDate = CAST([XmlTable].value('StartDate[1]', 'varchar(19)') as datetime),
		@NormID = [XmlTable].value('NormID[1]', 'int'),
		@Comments = [XmlTable].value('Comments[1]', 'nvarchar(max)')		
	FROM
		@Xml.nodes('/pjm7EmployeeNormGet/EmployeeNorm') AS List(XmlTable)
	
	SET @State = dbo.adfwfGetInitialState('747ADB3D-456E-47C9-9C6E-6382A4D20F37')
	IF @State IS NULL
	BEGIN
		RAISERROR('#accessdenied', 18, -1)
		RETURN 1
	END

	DECLARE 
		@EmployeeFileAs TName

	SELECT
		@EmployeeFileAs = [FileAs]
	FROM
		[Employee]
	WHERE
		[ID] = @EmployeeID

	SET @FileAs = 'Норма сотрудника ' + ISNULL(@EmployeeFileAs,'') + ' с ' + CAST(DATEPART(DAY, @StartDate) as nvarchar(2)) + '.' + 
	CAST(DATEPART(MONTH, @StartDate) as nvarchar(2)) + '.' + CAST(DATEPART(YEAR, @StartDate) as nvarchar(4))


	IF EXISTS (
		SELECT 1 
		FROM 
			[EmployeeNormEntry]
		WHERE 
			[StartDate] = @StartDate
			AND 
			[EmployeeID] = @EmployeeID
	)
	BEGIN
		RAISERROR('#EmployeeNormDateDublicate', 18, -1)
		RETURN 1
	END

	BEGIN TRANSACTION
	
	INSERT INTO [EmployeeNormEntry] ([State],[Flag], [FileAs], [EmployeeID], [StartDate], [NormID], [Comments])
	VALUES
		(@State, 0, @FileAs, @EmployeeID, @StartDate, @NormID, @Comments)

		IF @@ERROR != 0
		BEGIN
			ROLLBACK TRANSACTION
			RETURN 1
		END

	COMMIT TRANSACTION

	DECLARE 
		@ID int

	SET @ID = SCOPE_IDENTITY()

	EXEC pjm7EmployeeNormGet @ID

	RETURN 0
GO

GRANT EXECUTE ON [pjm7EmployeeNormCreate] TO PUBLIC
GO
