IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'pjm6ExportAnnualDocument')
	BEGIN
		PRINT 'Dropping Procedure pjm6ExportAnnualDocument'
		DROP  Procedure  pjm6ExportAnnualDocument
	END

GO

PRINT 'Creating Procedure pjm6ExportAnnualDocument'
GO

--------------------------------------------------------------------------------------
-- Copyright (c) 2010 by Avicom
--------------------------------------------------------------------------------------
-- $Archive: $
-- $Author: $
-- $Revision: $
-- $Modtime: $
-- $Date: $
--
-- Description: this stored procedure ...........
-- Input:	.........
-- Output:      0 - success, negative number - otherwise
--
-- Notes:       no
--
--
/* $Log: $ 
   $NoKeywords: $ 
**-------------------------------------------------------------------------------------
**	DATE		Author		Comments
**  ---------   ----------  -----------------------------------------------------------
**	24.08.10	SPV			 
--------------------------------------------------------------------------------------*/
CREATE Procedure pjm6ExportAnnualDocument
	@Class TClass,
	@ID TIdentifier
AS
	SET NOCOUNT ON
	
	DECLARE
		@FactureClass TClass,
		@InvoiceClass TClass,
		@StatementClass TClass
	
	SET @FactureClass = dbo.adfGetClassByName('Pjm5.Facture')
	SET @InvoiceClass = dbo.adfGetClassByName('Pjm5.Invoice')
	SET @StatementClass = dbo.adfGetClassByName('Pjm5.Statement')
	
	IF @FactureClass = @Class
	BEGIN
		SELECT
			GETDATE() as 'Period/@StartDate',
			GETDATE() as 'Period/@EndDate',
			0 as 'Period/@PeriodType',
			(
				SELECT
					[Company].[ID] as '@SupplierID',
					[Company].[FileAs] as '@Name',
					'' as '@SupplierType',
					[Company].[LegalName] as '@LegalName',
					dbo.fnPjm5AddressAsString([LegalAddress].[Street], [LegalAddress].[City],[LegalAddress].[Region],[LegalAddress].[PostalCode],[LegalAddress].[Country]) as '@LegalAddress',
					dbo.fnPjm5AddressAsString([PostalAddress].[Street], [PostalAddress].[City],[PostalAddress].[Region],[PostalAddress].[PostalCode],[PostalAddress].[Country]) as '@PostalAddress',
					[BasicPhone].[Phone] as '@BasePhone',
					[Fax].[Phone] as '@Fax',
					[Company].[LegalCode] as '@LegalCode',
					[Company].[KPP] as '@KPP',
					(
						SELECT 
							[Facture].[ID] as '@DocumentID',
							[Facture].[Number] as '@DocumentNumber',
							[Facture].[Date] as '@DocumentDate',
							MAX([T].[Created]) as '@Date'
						FROM
							[Facture]
							INNER JOIN [Transition] [T]
								ON [Facture].[Class] = [T].[Class] AND [Facture].[ID] = [T].[DocumentID]
							INNER JOIN [TransitionTemplate] [TT]
								ON [TT].[ID] = [T].[TransitionTemplateID]
									AND [TT].[ToState] IN (3)
						WHERE
							[Facture].[ID] = @ID
						GROUP BY
							[Facture].[ID],
							[Facture].[Number],
							[Facture].[Date]
						FOR XML PATH('Facture'), TYPE
					) as 'Removed'
		FROM
			[Facture]
			INNER JOIN [Project]
				ON [Facture].[ProjectID] = [Project].[ID] AND [Facture].[ID] = @ID
			INNER JOIN [Company] 
				ON [Company].[ID] = [Project].[SupplierCompanyID]
			LEFT OUTER JOIN [Address] as [LegalAddress]
				ON [LegalAddress].[BusinessCardID] = [Company].[ID] AND 
					[LegalAddress].[BusinessCardClass] = [Company].[Class] AND
					[LegalAddress].[AddressTypeID] = 1
			LEFT OUTER JOIN [Address] as [PostalAddress]
				ON [PostalAddress].[BusinessCardID] = [Company].[ID] AND 
					[PostalAddress].[BusinessCardClass] = [Company].[Class] AND
					[PostalAddress].[AddressTypeID] = 5
			LEFT OUTER JOIN [Phone] as [BasicPhone]
				ON [BasicPhone].[BusinessCardID] = [Company].[ID] AND 
					[BasicPhone].[BusinessCardClass] = [Company].[Class] AND
					[BasicPhone].[PhoneTypeID] = 11
			LEFT OUTER JOIN [Phone] as [Fax]
				ON [Fax].[BusinessCardID] = [Company].[ID] AND 
					[Fax].[BusinessCardClass] = [Company].[Class] AND
					[Fax].[PhoneTypeID] = 8
		FOR XML PATH('Supplier'), TYPE) as 'Suppliers'
		FOR XML PATH('Documents')
	END
	ELSE IF @StatementClass = @Class
	BEGIN
		SELECT
			GETDATE() as 'Period/@StartDate',
			GETDATE() as 'Period/@EndDate',
			0 as 'Period/@PeriodType',
			(
				SELECT
					[Company].[ID] as '@SupplierID',
					[Company].[FileAs] as '@Name',
					'' as '@SupplierType',
					[Company].[LegalName] as '@LegalName',
					dbo.fnPjm5AddressAsString([LegalAddress].[Street], [LegalAddress].[City],[LegalAddress].[Region],[LegalAddress].[PostalCode],[LegalAddress].[Country]) as '@LegalAddress',
					dbo.fnPjm5AddressAsString([PostalAddress].[Street], [PostalAddress].[City],[PostalAddress].[Region],[PostalAddress].[PostalCode],[PostalAddress].[Country]) as '@PostalAddress',
					[BasicPhone].[Phone] as '@BasePhone',
					[Fax].[Phone] as '@Fax',
					[Company].[LegalCode] as '@LegalCode',
					[Company].[KPP] as '@KPP',
					(
						SELECT 
							[Statement].[ID] as '@DocumentID',
							[Statement].[Number] as '@DocumentNumber',
							[Statement].[Date] as '@DocumentDate',
							MAX([T].[Created]) as '@Date'
						FROM
							[Statement]
							INNER JOIN [Transition] [T]
								ON [Statement].[Class] = [T].[Class] AND [Statement].[ID] = [T].[DocumentID]
							INNER JOIN [TransitionTemplate] [TT]
								ON [TT].[ID] = [T].[TransitionTemplateID]
									AND [TT].[ToState] IN (4) 
						WHERE
							[Statement].[ID] = @ID
						GROUP BY
							[Statement].[ID],
							[Statement].[Number],
							[Statement].[Date]
						FOR XML PATH('Statement'), TYPE
					) as 'Removed'
		FROM
			[Statement]
			INNER JOIN [Project]
				ON [Statement].[ProjectID] = [Project].[ID] AND [Statement].[ID] = @ID
			INNER JOIN [Company] 
				ON [Company].[ID] = [Project].[SupplierCompanyID]
			LEFT OUTER JOIN [Address] as [LegalAddress]
				ON [LegalAddress].[BusinessCardID] = [Company].[ID] AND 
					[LegalAddress].[BusinessCardClass] = [Company].[Class] AND
					[LegalAddress].[AddressTypeID] = 1
			LEFT OUTER JOIN [Address] as [PostalAddress]
				ON [PostalAddress].[BusinessCardID] = [Company].[ID] AND 
					[PostalAddress].[BusinessCardClass] = [Company].[Class] AND
					[PostalAddress].[AddressTypeID] = 5
			LEFT OUTER JOIN [Phone] as [BasicPhone]
				ON [BasicPhone].[BusinessCardID] = [Company].[ID] AND 
					[BasicPhone].[BusinessCardClass] = [Company].[Class] AND
					[BasicPhone].[PhoneTypeID] = 11
			LEFT OUTER JOIN [Phone] as [Fax]
				ON [Fax].[BusinessCardID] = [Company].[ID] AND 
					[Fax].[BusinessCardClass] = [Company].[Class] AND
					[Fax].[PhoneTypeID] = 8
		FOR XML PATH('Supplier'), TYPE) as 'Suppliers'
		FOR XML PATH('Documents')
	END
	ELSE IF @InvoiceCLass = @Class
	BEGIN
		SELECT
			GETDATE() as 'Period/@StartDate',
			GETDATE() as 'Period/@EndDate',
			0 as 'Period/@PeriodType',
			(
				SELECT
					[Company].[ID] as '@SupplierID',
					[Company].[FileAs] as '@Name',
					'' as '@SupplierType',
					[Company].[LegalName] as '@LegalName',
					dbo.fnPjm5AddressAsString([LegalAddress].[Street], [LegalAddress].[City],[LegalAddress].[Region],[LegalAddress].[PostalCode],[LegalAddress].[Country]) as '@LegalAddress',
					dbo.fnPjm5AddressAsString([PostalAddress].[Street], [PostalAddress].[City],[PostalAddress].[Region],[PostalAddress].[PostalCode],[PostalAddress].[Country]) as '@PostalAddress',
					[BasicPhone].[Phone] as '@BasePhone',
					[Fax].[Phone] as '@Fax',
					[Company].[LegalCode] as '@LegalCode',
					[Company].[KPP] as '@KPP',
					(
						SELECT 
							[Invoice].[ID] as '@DocumentID',
							[Invoice].[Number] as '@DocumentNumber',
							[Invoice].[Date] as '@DocumentDate',
							MAX([T].[Created]) as '@Date'
						FROM
							[Invoice]
							INNER JOIN [Transition] [T]
								ON [Invoice].[Class] = [T].[Class] AND [Invoice].[ID] = [T].[DocumentID]
							INNER JOIN [TransitionTemplate] [TT]
								ON [TT].[ID] = [T].[TransitionTemplateID]
									AND [TT].[ToState] IN (3)
						WHERE
							[Invoice].[ID] = @ID
						GROUP BY
							[Invoice].[ID],
							[Invoice].[Number],
							[Invoice].[Date]
						FOR XML PATH('Invoice'), TYPE
					) as 'Removed'
		FROM
			[Invoice]
			INNER JOIN [Project]
				ON [Invoice].[ProjectID] = [Project].[ID] AND [Invoice].[ID] = @ID
			INNER JOIN [Company] 
				ON [Company].[ID] = [Project].[SupplierCompanyID]
			LEFT OUTER JOIN [Address] as [LegalAddress]
				ON [LegalAddress].[BusinessCardID] = [Company].[ID] AND 
					[LegalAddress].[BusinessCardClass] = [Company].[Class] AND
					[LegalAddress].[AddressTypeID] = 1
			LEFT OUTER JOIN [Address] as [PostalAddress]
				ON [PostalAddress].[BusinessCardID] = [Company].[ID] AND 
					[PostalAddress].[BusinessCardClass] = [Company].[Class] AND
					[PostalAddress].[AddressTypeID] = 5
			LEFT OUTER JOIN [Phone] as [BasicPhone]
				ON [BasicPhone].[BusinessCardID] = [Company].[ID] AND 
					[BasicPhone].[BusinessCardClass] = [Company].[Class] AND
					[BasicPhone].[PhoneTypeID] = 11
			LEFT OUTER JOIN [Phone] as [Fax]
				ON [Fax].[BusinessCardID] = [Company].[ID] AND 
					[Fax].[BusinessCardClass] = [Company].[Class] AND
					[Fax].[PhoneTypeID] = 8
		FOR XML PATH('Supplier'), TYPE) as 'Suppliers'
		FOR XML PATH('Documents')
	END
	
	RETURN 0
GO

GRANT EXEC ON pjm6ExportAnnualDocument TO PUBLIC

GO