IF EXISTS (SELECT * FROM sysobjects WHERE type = 'TR' AND name = 'pjm5trInvoiceLineInsert')
	BEGIN
		PRINT 'Dropping Trigger pjm5trInvoiceLineInsert'
		DROP  Trigger pjm5trInvoiceLineInsert
	END
GO

/******************************************************************************
**		File: 
**		Name: pjm5trInvoiceLineInsert
**		Desc: 
**
**		This template can be customized:
**              
**
**		Auth: 
**		Date: 
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:				Description:
**		--------		--------				-------------------------------------------
**    
*******************************************************************************/

PRINT 'Creating Trigger pjm5trInvoiceLineInsert'
GO
CREATE Trigger pjm5trInvoiceLineInsert 
ON [InvoiceLine] FOR INSERT
AS
BEGIN
	DECLARE
		@CalculationClass TClass,
		@InvoiceClass TClass

	SET @CalculationClass = dbo.adfGetClassByName('Pjm5.Calculation')	
	SET @InvoiceClass = dbo.adfGetClassByName('Pjm5.Invoice')	
	IF EXISTS(
		SELECT * 
		FROM 
			[Attachment]
			INNER JOIN [inserted]
				ON ([inserted].[DocumentClass] = [Attachment].[DocumentClass] AND
					[inserted].[DocumentID] = [Attachment].[DocumentID] AND
					[Attachment].[AttachmentTypeID] = 3)
		WHERE
			[Attachment].[LinkDocumentClass] IN (@CalculationClass, @InvoiceClass)
		)
	BEGIN
		ROLLBACK TRANSACTION
		RAISERROR('#DocumentAlreadyLinked', 18, -1)
		RETURN
	END
	
	INSERT INTO [Attachment]
		(
		[DocumentClass], [DocumentID], [Name],
		[LinkDocumentClass], [LinkDocumentID], [AttachmentTypeID]
		)
	SELECT
		[inserted].[DocumentClass], [inserted].[DocumentID], '',
		[Invoice].[Class], [Invoice].[ID], 3
	FROM
		[inserted]
		INNER JOIN [Invoice]
			ON [Invoice].[ID] = [inserted].[InvoiceID]
	WHERE
		[inserted].[DocumentID] IS NOT NULL AND
		[inserted].[DocumentClass] != dbo.adfGetClassByName('Pjm5.ServiceAssignment')
	IF @@ERROR != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN
	END

	UPDATE
		[Calculation]
	SET
		[Calculation].[State] = CASE
			WHEN [Calculation].[State] = 2 THEN 3
			ELSE [Calculation].[State]
		END,
		[Calculation].[InvoiceApproved] = 1,
		[Calculation].[Modified] = DEFAULT,
		[Calculation].[ModifiedBy] = DEFAULT
	FROM
		[Calculation]
		INNER JOIN [inserted]
			ON [Calculation].[Class] = [inserted].[DocumentClass] AND 
				[Calculation].[ID] = [inserted].[DocumentID]
	WHERE
		[Calculation].[State] = 2 OR
		[Calculation].[State] = 3 AND [Calculation].[InvoiceApproved] = 0
	IF @@error != 0
	BEGIN
		RAISERROR('#CannotApproveInvoiceCalculation', 18, -1)
		ROLLBACK TRANSACTION
		RETURN
	END

	UPDATE
		[TimeEntry]
	SET
		[TimeEntry].[DivisionID] = [Employee].[DivisionID],
		[TimeEntry].[State] = 3,
		[TimeEntry].[Modified] = DEFAULT,
		[TimeEntry].[ModifiedBy] = DEFAULT
	FROM
		[TimeEntry]
		INNER JOIN [Employee]
			ON [Employee].[ID] = [TimeEntry].[EmployeeID]
		INNER JOIN [inserted]
			ON [TimeEntry].[Class] = [inserted].[DocumentClass] AND 
				[TimeEntry].[ID] = [inserted].[DocumentID] AND
				[TimeEntry].[State] = 2
	IF @@error != 0
	BEGIN
		RAISERROR('#CannotApproveInvoiceTimeEntry', 18, -1)
		ROLLBACK TRANSACTION
		RETURN
	END

	UPDATE
		[Expense]
	SET
		[Expense].[DivisionID] = [Employee].[DivisionID],
		[Expense].[State] = 3,
		[Expense].[Modified] = DEFAULT,
		[Expense].[ModifiedBy] = DEFAULT
	FROM
		[Expense]
		INNER JOIN [Employee]
			ON [Employee].[ID] = [Expense].[EmployeeID]
		INNER JOIN [inserted]
			ON [Expense].[Class] = [inserted].[DocumentClass] AND 
				[Expense].[ID] = [inserted].[DocumentID] AND
				[Expense].[State] = 2
	IF @@error != 0
	BEGIN
		RAISERROR('#CannotApproveInvoiceExpense', 18, -1)
		ROLLBACK TRANSACTION
		RETURN
	END
	
	UPDATE
		[ServiceRequest]
	SET
		[ServiceRequest].[DivisionID] = [Employee].[DivisionID],
		[ServiceRequest].[State] = 4,
		[ServiceRequest].[Modified] = DEFAULT,
		[ServiceRequest].[ModifiedBy] = DEFAULT
	FROM
		[ServiceRequest]
		INNER JOIN [Employee]
			ON [Employee].[ID] = [ServiceRequest].[EmployeeID]
		INNER JOIN [inserted]
			ON [ServiceRequest].[Class] = [inserted].[DocumentClass] AND 
				[ServiceRequest].[ID] = [inserted].[DocumentID] AND
				[ServiceRequest].[State] = 3
	IF @@error != 0
	BEGIN
		RAISERROR('#CannotApproveInvoiceServiceRequest', 18, -1)
		ROLLBACK TRANSACTION
		RETURN
	END

	UPDATE
		[TimeEntry]
	SET
		[TimeEntry].[State] = 6,
		[TimeEntry].[Modified] = DEFAULT,
		[TimeEntry].[ModifiedBy] = DEFAULT
	FROM
		[TimeEntry]
		INNER JOIN [inserted]
			ON [TimeEntry].[Class] = [inserted].[DocumentClass] AND 
				[TimeEntry].[ID] = [inserted].[DocumentID]
	WHERE
		[TimeEntry].[State] != 6
	IF @@error != 0
	BEGIN
		RAISERROR('#CannotApproveInvoiceTimeEntry', 18, -1)
		ROLLBACK TRANSACTION
		RETURN
	END
	
	UPDATE
		[Expense]
	SET
		[Expense].[State] = 6,
		[Expense].[Modified] = DEFAULT,
		[Expense].[ModifiedBy] = DEFAULT
	FROM
		[Expense]
		INNER JOIN [inserted]
			ON [Expense].[Class] = [inserted].[DocumentClass] AND 
				[Expense].[ID] = [inserted].[DocumentID]
	WHERE
		[Expense].[State] != 6
	IF @@error != 0
	BEGIN
		RAISERROR('#CannotApproveInvoiceExpense', 18, -1)
		ROLLBACK TRANSACTION
		RETURN
	END

	UPDATE
		[ServiceRequest]
	SET
		[ServiceRequest].[State] = 5,
		[ServiceRequest].[Modified] = DEFAULT,
		[ServiceRequest].[ModifiedBy] = DEFAULT
	FROM
		[ServiceRequest]
		INNER JOIN [inserted]
			ON [ServiceRequest].[Class] = [inserted].[DocumentClass] AND 
				[ServiceRequest].[ID] = [inserted].[DocumentID]
	WHERE
		[ServiceRequest].[State] != 5
	IF @@error != 0
	BEGIN
		RAISERROR('#CannotApproveInvoiceServiceRequest', 18, -1)
		ROLLBACK TRANSACTION
		RETURN
	END

END

GO

IF EXISTS (SELECT * FROM sysobjects WHERE type = 'TR' AND name = 'pjm5trInvoiceLineDelete')
	BEGIN
		PRINT 'Dropping Trigger pjm5trInvoiceLineDelete'
		DROP  Trigger pjm5trInvoiceLineDelete
	END
GO

/******************************************************************************
**		File: 
**		Name: pjm5trInvoiceLineDelete
**		Desc: 
**
**		This template can be customized:
**              
**
**		Auth: 
**		Date: 
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:		Description:
**		--------	--------	-------------------------------------------
**		18.03.13	SAP		   Amount  
**							 AmountBeforeFinanceDocumentInsert
**		10.07.13	SOV		   " "  EntryAmount
**		31.07.13	SAP		   " "  EntryAmount
**		27.08.13	SOV		          
**		11.09.14	SAP		    InvoiceApproved
*******************************************************************************/

PRINT 'Creating Trigger pjm5trInvoiceLineDelete'
GO
CREATE Trigger pjm5trInvoiceLineDelete 
ON [InvoiceLine] FOR DELETE
AS
BEGIN
	DELETE [Attachment]
	FROM
		[Attachment]
		INNER JOIN [deleted]
			ON ([deleted].[DocumentClass] = [Attachment].[DocumentClass] AND 
				[deleted].[DocumentID] = [Attachment].[DocumentID])
		INNER JOIN [Invoice]
			ON ([Invoice].[ID] = [deleted].[InvoiceID] AND
				[Invoice].[Class] = [Attachment].[LinkDocumentClass] AND 
				[Invoice].[ID] = [Attachment].[LinkDocumentID])
	WHERE
		[Attachment].[AttachmentTypeID] = 3
	IF @@ERROR != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN
	END

	UPDATE
		[Calculation]
	SET
		[Calculation].[InvoiceApproved] = 0,
		[Calculation].[Modified] = DEFAULT,
		[Calculation].[ModifiedBy] = DEFAULT
	FROM
		[Calculation]
		INNER JOIN [deleted]
			ON [Calculation].[Class] = [deleted].[DocumentClass] AND 
				[Calculation].[ID] = [deleted].[DocumentID]
	WHERE
		[Calculation].[State] = 3 AND
		NOT EXISTS(
			SELECT * 
			FROM [FactureLine] 
				INNER JOIN [Facture]
					ON [Facture].[ID] = [FactureLine].[FactureID]
			WHERE 
				[Facture].[State] IN (1, 2) AND
				[DocumentClass] = [Calculation].[Class] AND 
				[DocumentID] = [Calculation].[ID]
			) 		
	IF @@error != 0
	BEGIN
		RAISERROR('#CannotRecommitStatementCalculation', 18, -1)
		ROLLBACK TRANSACTION
		RETURN
	END

	UPDATE
		[Calculation]
	SET
		[Calculation].[State] = 2
	FROM
		[Calculation]
		INNER JOIN [deleted]
			ON [Calculation].[Class] = [deleted].[DocumentClass] AND 
				[Calculation].[ID] = [deleted].[DocumentID]
	WHERE
		[Calculation].[State] = 3 AND
		NOT EXISTS(
			SELECT * 
			FROM [FactureLine] 
				INNER JOIN [Facture]
					ON [Facture].[ID] = [FactureLine].[FactureID]
			WHERE 
				[Facture].[State] IN (1, 2) AND
				[DocumentClass] = [Calculation].[Class] AND 
				[DocumentID] = [Calculation].[ID]
			) AND
		NOT EXISTS(
			SELECT * 
			FROM [StatementLine] 
				INNER JOIN [Statement]
					ON [Statement].[ID] = [StatementLine].[StatementID]
			WHERE 
				[Statement].[State] IN (1, 2, 3) AND
				[DocumentClass] = [Calculation].[Class] AND 
				[DocumentID] = [Calculation].[ID]
			)
	IF @@error != 0
	BEGIN
		RAISERROR('#CannotRecommitStatementCalculation', 18, -1)
		ROLLBACK TRANSACTION
		RETURN
	END
	
	UPDATE
		[TimeEntry]
	SET
		[TimeEntry].[State] = 3,
		[TimeEntry].[Modified] = DEFAULT,
		[TimeEntry].[ModifiedBy] = DEFAULT
	FROM
		[TimeEntry]
		INNER JOIN [deleted]
			ON [TimeEntry].[Class] = [deleted].[DocumentClass] AND 
				[TimeEntry].[ID] = [deleted].[DocumentID]
	WHERE
		[TimeEntry].[State] = 6 AND
		NOT EXISTS(
			SELECT * 
			FROM [FactureLine] 
				INNER JOIN [Facture]
					ON [Facture].[ID] = [FactureLine].[FactureID]
			WHERE 
				[Facture].[State] IN (1, 2) AND
				[DocumentClass] = [TimeEntry].[Class] AND 
				[DocumentID] = [TimeEntry].[ID]
			) AND
		NOT EXISTS(
			SELECT * 
			FROM [StatementLine] 
				INNER JOIN [Statement]
					ON [Statement].[ID] = [StatementLine].[StatementID]
			WHERE 
				[Statement].[State] IN (1, 2, 3) AND
				[DocumentClass] = [TimeEntry].[Class] AND 
				[DocumentID] = [TimeEntry].[ID]
			)
	IF @@error != 0
	BEGIN
		RAISERROR('#CannotRecommitInvoiceTimeEntry', 18, -1)
		ROLLBACK TRANSACTION
		RETURN
	END
	
	UPDATE
		[Expense]
	SET
		[Expense].[State] = 3,
		[Expense].[Modified] = DEFAULT,
		[Expense].[ModifiedBy] = DEFAULT
	FROM
		[Expense]
		INNER JOIN [deleted]
			ON [Expense].[Class] = [deleted].[DocumentClass] AND 
				[Expense].[ID] = [deleted].[DocumentID]
	WHERE
		[Expense].[State] = 6 AND
		NOT EXISTS(
			SELECT * 
			FROM [FactureLine] 
				INNER JOIN [Facture]
					ON [Facture].[ID] = [FactureLine].[FactureID]
			WHERE 
				[Facture].[State] IN (1, 2) AND
				[DocumentClass] = [Expense].[Class] AND 
				[DocumentID] = [Expense].[ID]
			) AND
		NOT EXISTS(
			SELECT * 
			FROM [StatementLine] 
				INNER JOIN [Statement]
					ON [Statement].[ID] = [StatementLine].[StatementID]
			WHERE 
				[Statement].[State] IN (1, 2, 3) AND
				[DocumentClass] = [Expense].[Class] AND 
				[DocumentID] = [Expense].[ID]
			)
	IF @@error != 0
	BEGIN
		RAISERROR('#CannotRecommitInvoiceExpense', 18, -1)
		ROLLBACK TRANSACTION
		RETURN
	END

	UPDATE
		[ServiceRequest]
	SET
		[ServiceRequest].[State] = 4,
		[ServiceRequest].[Modified] = DEFAULT,
		[ServiceRequest].[ModifiedBy] = DEFAULT
	FROM
		[ServiceRequest]
		INNER JOIN [deleted]
			ON [ServiceRequest].[Class] = [deleted].[DocumentClass] AND 
				[ServiceRequest].[ID] = [deleted].[DocumentID]
	WHERE
		[ServiceRequest].[State] = 5 AND
		NOT EXISTS(
			SELECT * 
			FROM [FactureLine] 
				INNER JOIN [Facture]
					ON [Facture].[ID] = [FactureLine].[FactureID]
			WHERE 
				[Facture].[State] IN (1, 2) AND
				[DocumentClass] = [ServiceRequest].[Class] AND 
				[DocumentID] = [ServiceRequest].[ID]
			) AND
		NOT EXISTS(
			SELECT * 
			FROM [StatementLine] 
				INNER JOIN [Statement]
					ON [Statement].[ID] = [StatementLine].[StatementID]
			WHERE 
				[Statement].[State] IN (1, 2, 3) AND
				[DocumentClass] = [ServiceRequest].[Class] AND 
				[DocumentID] = [ServiceRequest].[ID]
			)
	IF @@error != 0
	BEGIN
		RAISERROR('#CannotRecommitInvoiceServiceRequest', 18, -1)
		ROLLBACK TRANSACTION
		RETURN
	END

	DECLARE @timeClass TClass
	SET @timeClass = dbo.adfGetClassByName('Pjm5.TimeEntry')
	UPDATE
		[EntryAmount]
	SET
		[Amount] = [AmountBeforeFinanceDocumentInsert],
		[ModifiedInFinance] = NULL,
		[ModifiedByInFinance] = NULL,
		[Price] = ISNULL([TimeEntry].[Rate], 0)
	FROM 
		[EntryAmount]
		INNER JOIN [deleted]
			ON [deleted].[DocumentID] = [EntryAmount].[ID]
		INNER JOIN [TimeEntry]
			ON [TimeEntry].[ID] = [deleted].[DocumentID] AND
				[deleted].[DocumentClass] = [TimeEntry].[Class]
		INNER JOIN [Invoice]
			ON [Invoice].[ID] = [deleted].[InvoiceID]
	WHERE
		[Invoice].[State] != 3 AND
		NOT EXISTS (
			SELECT *
			FROM
				[StatementLine]
				INNER JOIN [deleted]
					ON [StatementLine].[DocumentClass] = [deleted].[DocumentClass] AND
						[StatementLine].[DocumentID] = [deleted].[DocumentID]
				INNER JOIN [Statement]
					ON [Statement].[ID] = [StatementLine].[StatementID]
			WHERE
				[StatementLine].[DocumentClass] = @timeClass AND
				[Statement].[State] != 4
		) AND
		NOT EXISTS (
			SELECT *
			FROM
				[FactureLine]
				INNER JOIN [deleted]
					ON [FactureLine].[DocumentClass] = [deleted].[DocumentClass] AND
						[FactureLine].[DocumentID] = [deleted].[DocumentID]
				INNER JOIN [Facture]
					ON [Facture].[ID] = [FactureLine].[FactureID]
			WHERE
				[FactureLine].[DocumentClass] = @timeClass AND
				[Facture].[State] != 3
		)
	IF @@ERROR != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN
	END			
END

GO

IF EXISTS (SELECT * FROM sysobjects WHERE type = 'TR' AND name = 'pjm5trInvoiceLineUpdate')
	BEGIN
		PRINT 'Dropping Trigger pjm5trInvoiceLineUpdate'
		DROP  Trigger pjm5trInvoiceLineUpdate
	END
GO

/******************************************************************************
**		File: 
**		Name: pjm5trInvoiceLineUpdate
**		Desc: 
**
**		This template can be customized:
**              
**
**		Auth: 
**		Date: 
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**		25.02.14	SAP				       
**		08.03.14	SAP				   ,    != . 
**		29.04.14	SAP				        
*******************************************************************************/

PRINT 'Creating Trigger pjm5trInvoiceLineUpdate'
GO
CREATE Trigger pjm5trInvoiceLineUpdate 
ON [InvoiceLine] FOR INSERT, UPDATE, DELETE
AS
BEGIN
	IF @@ROWCOUNT = 0
		RETURN

    IF EXISTS (
		SELECT *
		FROM [inserted]
		WHERE 
			[inserted].[VATIsIncluded] = 1 AND 
			[inserted].[Price] * [inserted].[Amount] < [inserted].[VAT]
	)
	BEGIN
		RAISERROR('#wrongvatvalue', 18, -1)
		ROLLBACK TRANSACTION
		RETURN
	END

	DECLARE 
		@timeClass TClass,
		@value TVariant,
		@BaseCurrency TCode3,
		@NationalCurrency TCode3
		
	SET @timeClass = dbo.adfGetClassByName('Pjm5.TimeEntry')
	IF EXISTS(
		SELECT *
		FROM 
			[EntryAmount]
			INNER JOIN [inserted]
				ON [inserted].[DocumentClass] = @timeClass AND
					[inserted].[DocumentID] = [EntryAmount].[ID]
			INNER JOIN [deleted]
				ON [deleted].[DocumentClass] = [inserted].[DocumentClass] AND
					[deleted].[DocumentID] = [inserted].[DocumentID]
			INNER JOIN [StatementLine]
				ON [StatementLine].[DocumentClass] = @timeClass AND
					[StatementLine].[DocumentID] = [EntryAmount].[ID]
			INNER JOIN [Statement]
				ON [Statement].[ID] = [StatementLine].[StatementID]
		WHERE
			[Statement].[State] != 4 AND
			(
				[StatementLine].[Amount] != [inserted].[Amount] OR 
				[StatementLine].[PricePC] != [inserted].[PricePC]
			)
	)
	BEGIN
		RAISERROR('#CannotChangeEntryAmountOrPrice', 18, -1)
		ROLLBACK TRANSACTION
		RETURN
	END
		
	IF EXISTS(
		SELECT *
		FROM 
			[EntryAmount]
			INNER JOIN [inserted]
				ON [inserted].[DocumentClass] = @timeClass AND
					[inserted].[DocumentID] = [EntryAmount].[ID]
			INNER JOIN [deleted]
				ON [deleted].[DocumentClass] = [inserted].[DocumentClass] AND
					[deleted].[DocumentID] = [inserted].[DocumentID]
			INNER JOIN [FactureLine]
				ON [FactureLine].[DocumentClass] = @timeClass AND
					[FactureLine].[DocumentID] = [EntryAmount].[ID]
			INNER JOIN [Facture]
				ON [Facture].[ID] = [FactureLine].[FactureID]
		WHERE
			[Facture].[State] != 3 AND
			(
				[FactureLine].[Amount] != [inserted].[Amount] OR 
				[FactureLine].[OriginalPricePC] != [inserted].[PricePC]
			)
	)
	BEGIN
		RAISERROR('#CannotChangeEntryAmountOrPrice', 18, -1)
		ROLLBACK TRANSACTION
		RETURN
	END

	UPDATE
		[EntryAmount]
	SET
		[Amount] = [inserted].[Amount],
		[Price] = [inserted].[PricePC]
	FROM 
		[EntryAmount]
		INNER JOIN [inserted]
			ON [inserted].[DocumentClass] = @timeClass AND
				[inserted].[DocumentID] = [EntryAmount].[ID]
	WHERE
		[EntryAmount].[Amount] != [inserted].[Amount] OR
		[EntryAmount].[Price] != [inserted].[PricePC]
	
	IF @@ERROR != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN
	END
	
	EXEC adfParameterGet 'NationalCurrency', 'CommonBusiness', @value OUTPUT	
	SET @NationalCurrency = CAST(@value AS varchar(3))
	EXEC adfParameterGet 'BaseCurrency', 'CommonBusiness', @value OUTPUT	
	SET @BaseCurrency = CAST(@value AS varchar(3))
	
	DECLARE @changed TABLE ([ID] int, [ApplyVAT] bit)
	INSERT INTO @changed ([ID], [ApplyVAT])
	SELECT
		ISNULL([inserted].[InvoiceID], [deleted].[InvoiceID]),
		[Project].[ApplyVAT]
	FROM
		[inserted]
		FULL OUTER JOIN [deleted]
			ON [inserted].[ID] = [deleted].[ID]
		INNER JOIN [Invoice]
			ON 	[Invoice].[ID] = ISNULL([inserted].[InvoiceID], [deleted].[InvoiceID])
		INNER JOIN [Project]
			ON [Project].[ID] = [Invoice].[ProjectID]
	WHERE
		[Invoice].[State] != 3
		
	DECLARE 
		@ID int, 
		@ApplyVAT bit
	DECLARE 
		@total money,
		@totalwithvat money, 
		@totalPC money, 
		@totalwithvatPC money, 
		@totalBC money, 
		@totalwithvatBC money,
		@CurrencyCode TCode3,		
		@CurrencyRate decimal(18,10),
		@VAT money
	DECLARE @totals TABLE 
	(
		[ID] int, 
		[ApplyVAT] bit, 
		[Total] money,
		[TotalWithVAT] money,
		[TotalPC] money null, 
		[TotalWithVATPC] money null, 
		[TotalBC] money null, 
		[TotalWithVATBC] money NULL
	)
	DECLARE documents CURSOR FAST_FORWARD FOR SELECT [ID], [ApplyVAT] FROM @changed
	
	OPEN documents
	FETCH NEXT FROM documents INTO @ID, @ApplyVAT
	WHILE @@FETCH_STATUS = 0
	BEGIN
		SELECT
			@CurrencyCode = [CurrencyCode],
			@CurrencyRate = [CurrencyRate]
		FROM 
			[Invoice]
		WHERE 
			[ID] = @ID

		IF @CurrencyCode != @NationalCurrency
			SET @CurrencyRate = 1 / @CurrencyRate

		SELECT
			@total = ISNULL(SUM(ROUND(
			CASE [InvoiceLine].[EditedInPaymentCurrency]
				WHEN 0 THEN	
					CASE 
						WHEN [InvoiceLine].[VATIsIncluded] = 0
							THEN ROUND([InvoiceLine].[Amount] * [InvoiceLine].[PricePC] + [InvoiceLine].[VATPC],2)*@CurrencyRate - [InvoiceLine].[VAT]
						ELSE ROUND([InvoiceLine].[Amount] * [InvoiceLine].[PricePC],2)*@CurrencyRate - [InvoiceLine].[VAT]
					END
				ELSE
					CASE 
						WHEN [InvoiceLine].[VATIsIncluded] = 0
							THEN ROUND([InvoiceLine].[Amount] * [InvoiceLine].[Price],2)
						ELSE ROUND([InvoiceLine].[Amount] * [InvoiceLine].[Price],2) - [InvoiceLine].[VAT]
					END
			END, [Invoice].[Scale])), 0),		
			@totalwithvat = ISNULL(SUM(ROUND(
			CASE [InvoiceLine].[EditedInPaymentCurrency]
				WHEN 0 THEN	
					CASE 
						WHEN [InvoiceLine].[VATIsIncluded] = 0
							THEN ROUND([InvoiceLine].[Amount] * [InvoiceLine].[PricePC] + [InvoiceLine].[VATPC],2)*@CurrencyRate
						ELSE ROUND([InvoiceLine].[Amount] * [InvoiceLine].[PricePC],2)*@CurrencyRate
					END
				ELSE
					CASE 
						WHEN [InvoiceLine].[VATIsIncluded] = 0
							THEN ROUND([InvoiceLine].[Amount] * [InvoiceLine].[Price],2) + [InvoiceLine].[VAT]
						ELSE ROUND([InvoiceLine].[Amount] * [InvoiceLine].[Price],2)
					END
			END, [Invoice].[Scale])), 0),			
			@totalPC = ISNULL(SUM(ROUND(
			CASE [InvoiceLine].[EditedInPaymentCurrency]
				WHEN 0 THEN	
					CASE 
						WHEN [InvoiceLine].[VATIsIncluded] = 0
							THEN ROUND([InvoiceLine].[Amount] * [InvoiceLine].[PricePC],2)
						ELSE ROUND([InvoiceLine].[Amount] * [InvoiceLine].[PricePC],2) - [InvoiceLine].[VATPC]
					END
				ELSE
					CASE 
						WHEN [InvoiceLine].[VATIsIncluded] = 0
							THEN ROUND([InvoiceLine].[Amount] * [InvoiceLine].[Price] + [InvoiceLine].[VAT],2)/@CurrencyRate - [InvoiceLine].[VATPC]
						ELSE ROUND([InvoiceLine].[Amount] * [InvoiceLine].[Price],2)/@CurrencyRate - [InvoiceLine].[VATPC]
					END
			END, [Invoice].[Scale])), 0),
			@totalwithvatPC = ISNULL(SUM(ROUND(
			CASE [InvoiceLine].[EditedInPaymentCurrency]
				WHEN 0 THEN	
					CASE 
						WHEN [InvoiceLine].[VATIsIncluded] = 0
							THEN ROUND([InvoiceLine].[Amount] * [InvoiceLine].[PricePC],2) + [InvoiceLine].[VATPC]
						ELSE ROUND([InvoiceLine].[Amount] * [InvoiceLine].[PricePC],2)
					END
				ELSE
					CASE 
						WHEN [InvoiceLine].[VATIsIncluded] = 0
							THEN ROUND([InvoiceLine].[Amount] * [InvoiceLine].[Price] + [InvoiceLine].[VAT],2)/@CurrencyRate
						ELSE ROUND([InvoiceLine].[Amount] * [InvoiceLine].[Price],2)/@CurrencyRate
					END
			END, [Invoice].[Scale])), 0)
		FROM
			[Invoice]
			INNER JOIN [InvoiceLine]
				ON [InvoiceLine].[InvoiceID] = [Invoice].[ID]
		WHERE
			[Invoice].[ID] = @ID


		IF @ApplyVAT = 0
		BEGIN
			SET @totalwithvat = @total			
			SET @totalwithvatPC = @totalPC
		END
		
		
		INSERT INTO @totals ([ID], [ApplyVAT], [Total], [TotalWithVAT], [TotalPC], [TotalWithVATPC])
		VALUES (@ID, @ApplyVAT, @total, @totalwithvat, ISNULL(@totalPC, @total), ISNULL(@totalwithvatPC, @totalwithvat))
		FETCH NEXT FROM documents INTO @ID, @ApplyVAT
	END
	CLOSE documents
	DEALLOCATE documents


	UPDATE
		[Invoice]
	SET
		[Total] = ROUND(ISNULL([Total].[Total], 0), CASE [Project].[ApplyVAT] WHEN 0 THEN 2 ELSE [Invoice].[Scale] END),	
		[TotalWithVAT] = ROUND(ISNULL([Total].[TotalWithVAT], 0), 2),
		[TotalPC] = ROUND(ISNULL([Total].[TotalPC] ,0), CASE [Project].[ApplyVAT] WHEN 0 THEN 2 ELSE [Invoice].[Scale] END),	
		[TotalWithVATPC] = ROUND(ISNULL([Total].[TotalWithVATPC], 0), 2),
		[TotalBC]= ROUND(CASE 
						WHEN [Project].[CurrencyCode] = @BaseCurrency
							THEN ISNULL([Total].[TotalPC], 0)
						WHEN [Invoice].[CurrencyCode] = @BaseCurrency
							THEN ISNULL([Total].[Total], 0)
						WHEN [Project].[CurrencyCode] = @NationalCurrency AND [Invoice].[BaseCurrencyRate] != 0
							THEN ISNULL([Total].[TotalPC], 0) / [Invoice].[BaseCurrencyRate]
						ELSE ISNULL([Total].[TotalPC], 0) * [Invoice].[BaseCurrencyRate]
					END, 2),
		[TotalWithVATBC] = ROUND(CASE 
						WHEN [Project].[CurrencyCode] = @BaseCurrency
							THEN ISNULL([Total].[TotalWithVATPC], 0)
						WHEN [Invoice].[CurrencyCode] = @BaseCurrency
							THEN ISNULL([Total].[TotalWithVAT], 0)
						WHEN [Project].[CurrencyCode] = @NationalCurrency AND [Invoice].[BaseCurrencyRate] != 0
							THEN ISNULL([Total].[TotalWithVATPC],0) / [Invoice].[BaseCurrencyRate]
						ELSE ISNULL([Total].[TotalWithVATPC],0) * [Invoice].[BaseCurrencyRate]
					END, 2),
		[Modified] = DEFAULT,
		[ModifiedBy] = DEFAULT
	FROM
		[Invoice]
		INNER JOIN [Project]
			ON 	[Project].[ID] = [Invoice].[ProjectID]		
		INNER JOIN @totals AS [Total]
			ON 	[Invoice].[ID] = [Total].[ID]		
	WHERE
		[Invoice].[State] != 3				
	IF @@ERROR != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN
	END
END

GO
