IF EXISTS (SELECT * FROM sysobjects WHERE type = 'TR' AND name = 'pjm5trMeetingRequestUpdate')
	BEGIN
		PRINT 'Dropping Trigger pjm5trMeetingRequestUpdate'
		DROP  Trigger pjm5trMeetingRequestUpdate
	END
GO

/******************************************************************************
**		File: 
**		Name: pjm5trMeetingRequestUpdate
**		Desc: 
**
**		This template can be customized:
**              
**
**		Auth: 
**		Date: 
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:				Description:
**		--------		--------				-------------------------------------------
**    
*******************************************************************************/

PRINT 'Creating Trigger pjm5trMeetingRequestUpdate'
GO
CREATE TRIGGER pjm5trMeetingRequestUpdate ON [MeetingRequest] FOR UPDATE
AS
	IF @@rowcount = 0 
		RETURN

	SET NOCOUNT ON
	
	DECLARE @MeetingRequestID TIdentifier, @ResourceID TIdentifier, @State TState, @FromState TState,
			@result INT,
			@ReallocResources TBool
	
	DECLARE curRequest CURSOR LOCAL FORWARD_ONLY READ_ONLY FOR
		SELECT 
			[inserted].[ID], 
			[inserted].[State], 
			[deleted].[State],
			CASE
				WHEN [inserted].[FileAs] != [deleted].[FileAs] OR 
						[inserted].[StartTime] != [deleted].[StartTime] OR
						[inserted].[Duration] != [deleted].[Duration] OR
						[inserted].[PriorityID] != [deleted].[PriorityID] OR
						[inserted].[ProjectID] != [deleted].[ProjectID] OR
						[inserted].[Color] != [deleted].[Color]
					THEN 1
				ELSE 0
			END
		FROM 
			[inserted] 
			INNER JOIN [deleted] 
				ON ([inserted].[ID] = [deleted].[ID])
	
	OPEN curRequest
	
	FETCH NEXT FROM curRequest INTO @MeetingRequestID, @State, @FromState, @ReallocResources
	WHILE @@FETCH_STATUS = 0
	BEGIN

		IF @FromState != @State AND @State = 3 --  
		BEGIN
			EXEC @result = pjm5TimeEntryCreateFromMeetingRequest @MeetingRequestID
			IF @@ERROR != 0 OR @result != 0 GOTO ERROR_HANDLER
		END		
		ELSE IF EXISTS(SELECT * FROM [MeetingResource] WHERE [MeetingRequestID] = @MeetingRequestID)
		BEGIN
			DECLARE curResource CURSOR LOCAL FORWARD_ONLY READ_ONLY FOR
				SELECT [ResourceID] FROM [MeetingResource] WHERE [MeetingRequestID] = @MeetingRequestID

			OPEN curResource
			
			FETCH NEXT FROM curResource INTO @ResourceID
			WHILE @@FETCH_STATUS = 0
			BEGIN
				IF @State = 2 AND (@ReallocResources = 1 OR @FromState != 2)
				BEGIN
					EXEC @result = pjm5ResourceFree @ResourceID, @MeetingRequestID
					IF @@ERROR != 0 OR @result != 0 GOTO ERROR_HANDLER

					EXEC @result = pjm5ResourceAlloc @ResourceID, @MeetingRequestID
					IF @@ERROR != 0 OR @result != 0 GOTO ERROR_HANDLER
				END
				ELSE IF @FromState != @State AND @State = 4 --  
				BEGIN
					EXEC @result = pjm5ResourceFree @ResourceID, @MeetingRequestID
					IF @@ERROR != 0 OR @result != 0 GOTO ERROR_HANDLER
				END
				FETCH NEXT FROM curResource INTO @ResourceID
			END
				
			CLOSE curResource
			DEALLOCATE curResource
		END

		FETCH NEXT FROM curRequest INTO @MeetingRequestID, @State, @FromState, @ReallocResources
	END

	CLOSE curRequest
	DEALLOCATE curRequest
	RETURN

ERROR_HANDLER:
	ROLLBACK TRANSACTION
	CLOSE curRequest
	DEALLOCATE curRequest
	RETURN

GO  