  IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm6MsProjectUnlink]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure pjm6MsProjectUnlink'
		DROP PROCEDURE [dbo].[pjm6MsProjectUnlink]
	END
GO

PRINT 'Creating procedure pjm6MsProjectUnlink'
GO


CREATE PROCEDURE [pjm6MsProjectUnlink] @ID TIdentifier
AS
	
SET NOCOUNT ON

	DECLARE @EmployeeID TIdentifier
	SET @EmployeeID = dbo.adfGetCurrentEmployeeID();
	
	IF @EmployeeID IS NULL
	BEGIN
		RAISERROR('#accessdenied', 18, -1);
		RETURN 1;
	END
	
	--       .
	IF dbo.adfHasAccessRightByName('ManageProject') = 0
	BEGIN
		RAISERROR('#NotEnoughPermissions', 18, -1)
		RETURN 1
	END
	
	IF dbo.adfHasAccessRightByName('MsProjectSync') = 0
	BEGIN
		RAISERROR('#NotEnoughPermissions', 18, -1)
		RETURN 1
	END
	
	BEGIN TRANSACTION
	
	UPDATE [Project]
	SET [Project].[MsProjectID] = NULL
	WHERE [Project].[ID] = @ID
	IF @@ERROR !=0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN 1
	END
	
	UPDATE [Task]
	SET [Task].[MsTaskID] = NULL
	WHERE [Task].[ProjectID] = @ID
	IF @@ERROR !=0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN 1
	END
	
	UPDATE [Assignment]
	SET [Assignment].[MsResourceID] = NULL
	WHERE [Assignment].[ProjectID] = @ID
	IF @@ERROR !=0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN 1
	END
	
	DELETE [MsProject]
	FROM
		[MsProject]
			INNER JOIN [Project]
				ON [Project].[MsProjectID] = [MsProject].[ID]
	WHERE 
		[Project].[ID] = @ID
	IF @@ERROR !=0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN 1
	END
	
	DELETE [DocumentItem]
	FROM
		[DocumentItem]
			INNER JOIN [MsProject]
				ON [MsProject].[DocumentItemID] = [DocumentItem].[ID]
			INNER JOIN [Project]
				ON [Project].[MsProjectID] = [MsProject].[ID]
	WHERE 
		[Project].[ID] = @ID
	IF @@ERROR !=0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN 1
	END
COMMIT TRANSACTION
RETURN 0
GO

GRANT EXECUTE ON [pjm6MsProjectUnlink] TO PUBLIC
GO
    