IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm7ReminderSettingsGet]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure pjm7ReminderSettingsGet'
		DROP PROCEDURE [dbo].[pjm7ReminderSettingsGet]
	END
GO

PRINT 'Creating procedure pjm7ReminderSettingsGet'
GO

/******************************************************************************
**		File: pjm7ReminderSettingsGet.sql
**		Name: pjm7ReminderSettingsGet
**		Desc: 
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: Anton.Paramonov
**		Date: 02.05.2012 13:51:00
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		--------------------------------------------
**		11.12.13	SAP				    /
*******************************************************************************/
CREATE PROCEDURE [pjm7ReminderSettingsGet]
AS
	SET NOCOUNT ON
	
	DECLARE 
		@UserID TIdentifier,
		@Value	TVariant,
		@Enable	TBool
	SET @UserID = dbo.adfGetCurrentUserID()
	
	DECLARE @reminders TABLE 
	([Class] smallint, [Subtype] char(2), [DefaultState] int, [DefaultInterval] int)
	
	INSERT INTO @reminders ([Class], [Subtype], [DefaultState], [DefaultInterval])
	SELECT 0, [Subtype], [DefaultState], [DefaultInterval]
	FROM [ReminderType]
	WHERE [Subtype] = 'UR'

	IF dbo.adfHasAccessRight(dbo.adfGetRightID('AuthorJournalEntry')) = 1
	BEGIN
		INSERT INTO @reminders ([Class], [Subtype], [DefaultState], [DefaultInterval])
		SELECT [Class], [Subtype], [DefaultState], [DefaultInterval]
		FROM [ReminderType]
		WHERE [Class] = dbo.adfGetClassByName('Pjm5.TimeEntry') AND [Subtype] = 'ES'
	END
	IF dbo.adfHasAccessRight(dbo.adfGetRightID('ResolveIssue')) = 1
	BEGIN
		INSERT INTO @reminders ([Class], [Subtype], [DefaultState], [DefaultInterval])
		SELECT [Class], [Subtype], [DefaultState], [DefaultInterval]
		FROM [ReminderType]
		WHERE [Class] = dbo.adfGetClassByName('Pjm5.Issue') AND [Subtype] = 'ID'
	END
	
	EXEC adfParameterGet @Name='EnabledTasks', @Group='Pjm6', @Value = @value OUTPUT
	SET @Enable = CAST(@value as bit)

	IF dbo.adfHasAccessRight(dbo.adfGetRightID('AuthorTask')) = 1 AND @Enable = 1
	BEGIN
		INSERT INTO @reminders ([Class], [Subtype], [DefaultState], [DefaultInterval])
		SELECT [Class], [Subtype], [DefaultState], [DefaultInterval]
		FROM [ReminderType]
		WHERE [Class] = dbo.adfGetClassByName('Pjm5.Task') AND [Subtype] = 'TD'
	END
	IF dbo.adfHasAccessRight(dbo.adfGetRightID('ManageTaskRequest')) = 1
	BEGIN
		INSERT INTO @reminders ([Class], [Subtype], [DefaultState], [DefaultInterval])
		SELECT [Class], [Subtype], [DefaultState], [DefaultInterval]
		FROM [ReminderType]
		WHERE [Class] = dbo.adfGetClassByName('Pjm5.TaskRequest') AND [Subtype] = 'RD'
	END

	EXEC adfParameterGet @Name='EnabledServiceRequest', @Group='Pjm6', @Value = @value OUTPUT
	SET @Enable = CAST(@value as bit)

	IF dbo.adfHasAccessRight(dbo.adfGetRightID('AuthorServiceRequest')) = 1 AND @Enable = 1
	BEGIN
		INSERT INTO @reminders ([Class], [Subtype], [DefaultState], [DefaultInterval])
		SELECT [Class], [Subtype], [DefaultState], [DefaultInterval]
		FROM [ReminderType]
		WHERE [Class] = dbo.adfGetClassByName('Pjm5.ServiceRequest') AND [Subtype] = 'SD'
	END
	IF dbo.adfHasAccessRight(dbo.adfGetRightID('ManageInvoices')) = 1
	BEGIN
		INSERT INTO @reminders ([Class], [Subtype], [DefaultState], [DefaultInterval])
		SELECT [Class], [Subtype], [DefaultState], [DefaultInterval]
		FROM [ReminderType]
		WHERE [Class] = dbo.adfGetClassByName('Pjm5.Invoice')
	END
	IF dbo.adfHasAccessRight(dbo.adfGetRightID('ManageStatements')) = 1
	BEGIN
		INSERT INTO @reminders ([Class], [Subtype], [DefaultState], [DefaultInterval])
		SELECT [Class], [Subtype], [DefaultState], [DefaultInterval]
		FROM [ReminderType]
		WHERE [Class] = dbo.adfGetClassByName('Pjm5.Statement') AND [Subtype] = 'MD'
	END
	IF dbo.adfHasAccessRight(dbo.adfGetRightID('ManageBudgets')) = 1
	BEGIN
		INSERT INTO @reminders ([Class], [Subtype], [DefaultState], [DefaultInterval])
		SELECT [Class], [Subtype], [DefaultState], [DefaultInterval]
		FROM [ReminderType]
		WHERE [Class] = dbo.adfGetClassByName('Pjm6.Budget') AND [Subtype] = 'BC'
	END
	IF dbo.adfHasAccessRight(dbo.adfGetRightID('ManageContacts')) = 1
	BEGIN
		INSERT INTO @reminders ([Class], [Subtype], [DefaultState], [DefaultInterval])
		SELECT [Class], [Subtype], [DefaultState], [DefaultInterval]
		FROM [ReminderType]
		WHERE [Class] = dbo.adfGetClassByName('Adf.Employee') AND [Subtype] = 'CB'
	END

	SELECT [Class], [Subtype], [DefaultState], [DefaultInterval] FROM @reminders
	
	SELECT 
		(CASE WHEN [ReminderType].[Class] IS NULL THEN 0 ELSE [ReminderType].[Class] END) AS [Class],
		[ReminderSetting].[Subtype],
		[ReminderSetting].[InitialState],
		[ReminderSetting].[InitialInterval]
	FROM
		[ReminderSetting]
		INNER JOIN [ReminderType]
			ON [ReminderType].[Subtype] = [ReminderSetting].[Subtype]
	WHERE
		[UserID] = @UserID
	
	RETURN 0
GO

GRANT EXECUTE ON [pjm7ReminderSettingsGet] TO PUBLIC
GO  