IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm7TimeEntryReminderCopyInternal]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure pjm7TimeEntryReminderCopyInternal'
		DROP PROCEDURE [dbo].[pjm7TimeEntryReminderCopyInternal]
	END
GO

PRINT 'Creating procedure pjm7TimeEntryReminderCopyInternal'
GO

/******************************************************************************
**		File: pjm7TimeEntryReminderCopyInternal.sql
**		Name: pjm7TimeEntryReminderCopyInternal
**		Desc: 
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: yuriy.soldatkin
**		Date: 21.12.10
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**		09.04.13	SOV				       
*******************************************************************************/
CREATE PROCEDURE [pjm7TimeEntryReminderCopyInternal]
	@DocumentClass TIdentifier,
	@DocumentID	TIdentifier,
	@NewDocumentID TIdentifier,
	@ReminderUserID TIdentifier,
	@ReminderEventTime TDateTime,
	@IsDefaultReminder TBool
AS
	SET NOCOUNT ON

	DECLARE
		@ReminderSubtype TCode2,
		@ReminderState TState,
		@ReminderInterval TTimeSpan,
		@ReminderOldID TIdentifier,
		@ReminderDescription TName

	SELECT
		@ReminderOldID = [Reminder].[ID],
		@ReminderSubtype = [Reminder].[Subtype],
		@ReminderState = CASE
			WHEN (@IsDefaultReminder = 0)
				AND [UserReminder].[UserID] IS NOT NULL 
			THEN
				[UserReminder].[State]
			ELSE ISNULL([ReminderSetting].[InitialState], [ReminderType].[DefaultState])
		END,
		@ReminderInterval = CASE
			WHEN (@IsDefaultReminder = 0)
				AND [UserReminder].[UserID] IS NOT NULL 
			THEN
				[UserReminder].[OriginalInterval]
			ELSE ISNULL([ReminderSetting].[InitialInterval], [ReminderType].[DefaultInterval])
		END,
		@ReminderDescription = CASE
			WHEN (@IsDefaultReminder = 0)
				AND [UserReminder].[UserID] IS NOT NULL 
			THEN
				RTRIM(LTRIM([UserReminder].[Description]))
			ELSE [ReminderType].[name]
		END
	FROM
		[Reminder]
		INNER JOIN [ReminderType]
			ON ([ReminderType].[Class] = [Reminder].[DocumentClass] AND
			[ReminderType].[Subtype] = [Reminder].[Subtype])
		LEFT OUTER JOIN [UserReminder]
			ON ([Reminder].[ID] = [UserReminder].[ReminderID] AND
			[UserReminder].[UserID] = @ReminderUserID)
		LEFT OUTER JOIN [ReminderSetting]
			ON ([ReminderType].[Subtype] = [ReminderSetting].[Subtype] AND
				[ReminderSetting].[UserID] = @ReminderUserID)
	WHERE
		[Reminder].[DocumentClass] = @DocumentClass AND
		[Reminder].[DocumentID] = @DocumentID


	DECLARE @ReminderID TIdentifier, @rv int
	IF @ReminderOldID IS NOT NULL
	BEGIN	
		EXEC @rv = pjm7ReminderForUserCreateInternal @ReminderID OUTPUT,
			@DocumentClass, @NewDocumentID, @ReminderSubtype, @ReminderEventTime

		IF @rv != 0 OR @ReminderID IS NULL
		BEGIN
			RETURN 1
		END

		IF NOT EXISTS (
			SELECT * FROM [UserReminder]
			WHERE [ReminderID] = @ReminderID AND [UserID] = @ReminderUserID
		)
		BEGIN
			IF @ReminderEventTime IS NOT NULL
			BEGIN
				INSERT INTO [UserReminder] ([ReminderID], [UserID], [State],
					[OriginalInterval], [NextInterval], [Description])
				VALUES (@ReminderID, @ReminderUserID, @ReminderState, @ReminderInterval,
					@ReminderInterval, @ReminderDescription)
				IF @@error != 0
				BEGIN
					RETURN 1
				END
			END
		END
		ELSE
		BEGIN
			UPDATE [UserReminder] SET
				[State] =	CASE
								WHEN @ReminderEventTime IS NOT NULL THEN @ReminderState
								ELSE 0
							END,
				[OriginalInterval] = @ReminderInterval,
				[NextInterval] = @ReminderInterval,
				[Description] = @ReminderDescription,
				[Modified] = DEFAULT
			WHERE [ReminderID] = @ReminderID AND [UserID] = @ReminderUserID
			IF @@error != 0
			BEGIN
				RETURN 1
			END
		END
	END
	
	RETURN 0
GO

GRANT EXECUTE ON [pjm7TimeEntryReminderCopyInternal] TO PUBLIC
GO