 IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm5ProjectBrowseByCompany]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure pjm5ProjectBrowseByCompany'
		DROP PROCEDURE [dbo].[pjm5ProjectBrowseByCompany]
	END
GO

PRINT 'Creating procedure pjm5ProjectBrowseByCompany'
GO

/******************************************************************************
**		File: ContractBrowse.sql
**		Name: pjm5ProjectBrowseByCompany
**		Desc: this procedure automatically generated by Avicom.Adf.Generator
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: Andrew.Maklakov
**		Date: 01/20/2005 11:01:32
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**      20.10.10    BVY             Added the Name for Exchange to the area of SELECT
**		03.04.13	SOV				    . - 
**									     " "
**		07.05.13	SOV				  ID . -  . - 
*******************************************************************************/
CREATE PROCEDURE [pjm5ProjectBrowseByCompany]
	@CompanyID INT,
	@StateSelector INT
AS
	SET NOCOUNT ON
	
	DECLARE
		@viewAllProjects bit,
		@ViewAllFinance TBool,
		@CurrentEmployeeID TIdentifier,
		@HasManageProject TBool,
		@ViewFinance TBool
		
	SET @HasManageProject = dbo.adfHasAccessRight(dbo.adfGetRightID('ManageProject'))
	SET @CurrentEmployeeID = dbo.adfGetCurrentEmployeeID()
	SET @ViewAllFinance = dbo.adfHasAccessRight(dbo.adfGetRightID('ViewAllFinance'))
	SET @ViewFinance = dbo.adfHasAccessRight(dbo.adfGetRightID('ViewFinance'))
	SET @viewAllProjects = dbo.adfHasAccessRight(dbo.adfGetRightID('ViewAllProjects'))
	
	SELECT
		[Project].[Class],
		[Project].[ID],
		[Project].[State],
		[Project].[Flag],
		[Project].[Date],
		[Project].[Number],
		[Project].[FileAs],
		[Project].[ProjectTypeID],
		[Project].[SupplierCompanyID],
		[Project].[ProjectManagerEmployeeID],
		[Project].[CustomerCompanyID],
		[Project].[CustomerFinanceManagerID],
		[Project].[ResponsiblePersonEmployeeID],
		[Project].[PriorityID],
		[ProjectDetail].[DueDate],
		[Project].[EndDate],
		[Project].[CurrencyCode],
		[Project].[CostCenterID],
		[ProjectDetail].[PlannedManHour] / 60.0 AS [ManHour],
		CASE
			WHEN @ViewAllFinance = 1 OR (@ViewFinance = 1 AND 
				(dbo.fnPjm7HasPossibilityToProjectFinanceManagement([Project].[ID], @CurrentEmployeeID) = 1 OR
				[Project].[FinanceManagerEmployeeID] = @CurrentEmployeeID)) OR
				(@HasManageProject = 1 AND [Project].[ProjectManagerEmployeeID] = @CurrentEmployeeID)
				THEN [Project].[Budget]
			ELSE -1
		END AS [Budget],
		[ProjectDetail].[PlannedManHour],
		CASE
			WHEN @ViewAllFinance = 1 OR (@ViewFinance = 1 AND 
				(dbo.fnPjm7HasPossibilityToProjectFinanceManagement([Project].[ID], @CurrentEmployeeID) = 1 OR
				[Project].[FinanceManagerEmployeeID] = @CurrentEmployeeID)) OR
				(@HasManageProject = 1 AND [Project].[ProjectManagerEmployeeID] = @CurrentEmployeeID)
				THEN [ProjectDetail].[PlannedBudget]
			ELSE -1
		END AS [PlannedBudget],
		[Project].[Billable],
		[Project].[RoundingInterval],
		[Project].[RoundingMode],
		[Project].[ContractNumber],
		[Project].[ContractDate],
		[Project].[ContractEndDate],
		[Project].[ContractSubject],
		[Project].[ServiceLevelID],
		[Project].[ApplyVAT],
		[Project].[InvoiceExpirationPeriod],
		[Project].[InvoiceExpirationPeriodType],
		[Project].[Comments],
		[Project].[Created],
		[Project].[CreatedBy],
		[Project].[Modified],
		[Project].[ModifiedBy],
		[Project].[Timestamp],
		[Project].[ExchangeSystemName],
		[ProjectDetail].[PercentComplete],
		(CAST([ProjectDetail].[PercentComplete] * 100 as int) / 25) * 25 as PC,
		[Project].[PaymentCurrencyPoint],
		[PaymentPeriod].[InvoiceNextPaymentDate],
		[PaymentPeriod].[StatementNextPaymentDate],
		[PaymentPeriod].[CalculationNextPaymentDate],
		[Project].[IsConsignor],
		[BusinessCard].[FileAs] as 'Consignor',
		[Project].[ConsignorContract],
		CASE 
			WHEN NOT EXISTS(SELECT *FROM [Project] 
								WHERE 
										([ID] = [SubProjects].[ProjectID] AND [SubProjects].[ProjectID] IS NOT NULL) AND
										(
											@StateSelector = 0 AND [Project].[State] NOT IN (5, 6) OR 
											[Project].[State] = @StateSelector
										) AND
										(
											@CompanyID IS NULL OR 
											[Project].[SupplierCompanyID] = @CompanyID OR
											[Project].[CustomerCompanyID] = @CompanyID
										) AND
										(
											@viewAllProjects = 1 OR
											dbo.fnPjm5AllowCreateProjectEntry([Project].[ID], NULL) = 1 OR
											dbo.fnPjm5IsProjectMember([Project].[ID], @CurrentEmployeeID) = 1
										))
		THEN NULL
			ELSE [SubProjects].[ProjectID]
		END AS [ParentProjectID],
		[Project].[ManagerAssistantEmployeeID],
		[Project].[FinanceManagerEmployeeID]
	FROM
		[Project]
		INNER JOIN [PaymentPeriod]
			ON [PaymentPeriod].[ProjectID] = [Project].[ID]
		INNER JOIN [ProjectDetail]
			ON [ProjectDetail].[ID] = [Project].[ID]
		LEFT OUTER JOIN [BusinessCard]
			ON [BusinessCard].[Class] = [Project].[ConsignorClass] AND [BusinessCard].[ID] = [Project].[ConsignorID]
		LEFT OUTER JOIN fnpjm6GetSubprojectsForBrowse() AS [SubProjects]
			ON [SubProjects].[SubprojectID] = [Project].[ID]
	WHERE
		(
			@StateSelector = 0 AND [Project].[State] NOT IN (5, 6) OR 
			[Project].[State] = @StateSelector
		) AND
		(
			@CompanyID IS NULL OR 
			[Project].[SupplierCompanyID] = @CompanyID OR
			[Project].[CustomerCompanyID] = @CompanyID
		) AND
		(
			@viewAllProjects = 1 OR
			dbo.fnPjm5AllowCreateProjectEntry([Project].[ID], NULL) = 1 OR
			dbo.fnPjm5IsProjectMember([Project].[ID], @CurrentEmployeeID) = 1
		)

	RETURN 0
GO

GRANT EXECUTE ON [pjm5ProjectBrowseByCompany] TO PUBLIC
GO 
