IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'pjm6ProjectBrowseMemberActive')
	BEGIN
		PRINT 'Dropping Procedure pjm6ProjectBrowseMemberActive'
		DROP  Procedure  pjm6ProjectBrowseMemberActive
	END

GO

PRINT 'Creating Procedure pjm6ProjectBrowseMemberActive'
GO
/******************************************************************************
**		File: pjm6ProjectBrowseMemberActive.sql
**		Name: pjm6ProjectBrowseMemberActive
**		Desc:     
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**      26.03.09	ENB				 ,    
**									:     .
**									    
**		14.02.13	SOV				     
**		29.04.13	SOV				    
**		07.05.13	SOV				  ID . -  . - 
**		05.05.14	BAO				    
*******************************************************************************/
CREATE Procedure pjm6ProjectBrowseMemberActive

AS
	SET NOCOUNT ON
	
	DECLARE
		@PeriodStart TDate,
		@PeriodEnd TDate

	SELECT
		@PeriodStart = CAST(CONVERT(varchar(8), GETDATE(), 112) AS datetime),
		@PeriodEnd	 = DATEADD(day, 1, @PeriodStart)
	
--        
--	IF dbo.adfHasAccessRight(dbo.adfGetRightID('ManageProject')) = 0 BEGIN
--	    RAISERROR('#NotEnoughPermissions', 18, -1)
--		RETURN 1
--	END

	SELECT
		[Project].[Class],
		[Project].[ID],
		[Project].[State],
		[Project].[Flag],
		[Project].[Date],
		[Project].[Number],
		[Project].[FileAs],
		[Project].[ProjectTypeID],
		[Project].[SupplierCompanyID],
		[Project].[ProjectManagerEmployeeID],
		[Project].[CustomerCompanyID],
		[Project].[CustomerFinanceManagerID],
		[Project].[ResponsiblePersonEmployeeID],
		[Project].[PriorityID],
		[ProjectDetail].[DueDate],
		[Project].[EndDate],
		[Project].[CurrencyCode],
		[Project].[CostCenterID],
		[Project].[ProjectStageID],
		[Budgets].[PlannedManHour] / 60.0 AS [ManHour],
		CASE
			WHEN AP.ViewFinance = 1
			THEN [Project].[Budget]
			ELSE -1
		END AS [Budget],
		[Budgets].[PlannedManHour],
		CASE
			WHEN AP.ViewFinance = 1
			THEN [Budgets].[PlannedBudget]
			ELSE -1
		END AS [PlannedBudget],
		[Project].[Billable],
		[Project].[RoundingInterval],
		[Project].[RoundingMode],
		[Project].[ContractNumber],
		[Project].[ContractDate],
		[Project].[ContractEndDate],
		[Project].[ContractSubject],
		[Project].[ServiceLevelID],
		[Project].[ApplyVAT],
		[Project].[InvoiceExpirationPeriod],
		[Project].[InvoiceExpirationPeriodType],
		[Project].[Comments],
		[Project].[Created],
		[Project].[CreatedBy],
		[Project].[Modified],
		[Project].[ModifiedBy],
		[Project].[Timestamp],
		[ProjectDetail].[PercentComplete],
		(CAST([ProjectDetail].[PercentComplete] * 100 as int) / 25) * 25 as PC,
		[Project].[PaymentCurrencyPoint],
		[Project].[ExchangeSystemName],
		[Project].[IsConsignor],
		[BusinessCard].[FileAs] as 'Consignor',
		[Project].[ConsignorContract],
		[AP].[ParentProjectID] AS [ParentProjectID],
		[Project].[ManagerAssistantEmployeeID],
		[Project].[FinanceManagerEmployeeID]
	FROM
		[Project]
		INNER JOIN fnPjm6GetAvailableProjectsForProjectMember() AS AP
			ON [Project].[ID] = AP.ID
		INNER JOIN [ProjectDetail]
			ON [ProjectDetail].[ID] = [Project].[ID]
		LEFT OUTER JOIN [BusinessCard]
			ON [BusinessCard].[Class] = [Project].[ConsignorClass] AND [BusinessCard].[ID] = [Project].[ConsignorID]
		INNER JOIN dbo.fnPjm7GetProjectsBudgets() AS [Budgets]
			ON [Budgets].[ProjectID] = [Project].[ID]
	WHERE
		[Project].[State] = 2
		
	RETURN 0
GO

GRANT EXEC ON pjm6ProjectBrowseMemberActive TO PUBLIC
GO 

