IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm7ProjectCreateByTemplateGetParticipantsList]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure pjm7ProjectCreateByTemplateGetParticipantsList'
		DROP PROCEDURE [dbo].[pjm7ProjectCreateByTemplateGetParticipantsList]
	END
GO

PRINT 'Creating procedure pjm7ProjectCreateByTemplateGetParticipantsList'
GO

/******************************************************************************
**		File: pjm7ProjectCreateByTemplateGetParticipantsList.sql
**		Name: pjm7ProjectCreateByTemplateGetParticipantsList
**		Desc: 
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: Sergey Pelevin
**		Date: 07/06/2013
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**		01.07.13	SAP				    
**									 
*******************************************************************************/
CREATE PROCEDURE pjm7ProjectCreateByTemplateGetParticipantsList
	@StateSelector INT,
	@ProjectID TIdentifier
AS
SET NOCOUNT ON

	DECLARE 
		@ManagerID TIdentifier,
		@ProjectState TState,
		@ProjectTypeID TIdentifier


	DECLARE @Out TABLE
	(		
		AssignmentID int,
		EmployeeID int,
		QualificationID int,
		FileAs TName,
		QualificationName TName
	)


	
	SELECT 
		@ManagerID = [ProjectManagerEmployeeID],
		@ProjectState = [State],
		@ProjectTypeID = [ProjectTypeID]
	FROM 
		[Project] 
	WHERE 
		[ID] = @ProjectID
	
	DECLARE @IsFinanceEnable	bit,
			@ViewAllFinance TBool,
			@CurrentEmployeeID TIdentifier,
			@ViewFinance TBool,
			@IsMember TBool,
			@IsPM TBool,
			@IsAssignmentEditor TBool,
			@IsAssistant TBool,
			@FinanceManagement TBool
		
	SET @CurrentEmployeeID = dbo.adfGetCurrentEmployeeID()
	SET @IsMember = dbo.fnPjm5IsProjectMember(@ProjectID, @CurrentEmployeeID)		

	SET @ViewFinance = dbo.adfHasAccessRight(dbo.adfGetRightID('ViewFinance'))
	SET @ViewAllFinance = dbo.adfHasAccessRight(dbo.adfGetRightID('ViewAllFinance'))
	SET @IsAssistant = dbo.adfHasAccessRight(dbo.adfGetRightID('Assistant'))
	SET @IsPM = CASE @ManagerID WHEN @CurrentEmployeeID THEN 1 ELSE 0 END
	SET @FinanceManagement = dbo.fnPjm7HasPossibilityToProjectFinanceManagement(@ProjectID, @CurrentEmployeeID)
	
	SELECT @IsFinanceEnable = CASE
				WHEN (@CurrentEmployeeID = @ManagerID) THEN 1
				WHEN dbo.fnPjm7IsFinanceManager(@ProjectID, @CurrentEmployeeID) = 1 THEN 1
				WHEN @ProjectState IN (5,6) THEN 1
				WHEN @ViewFinance = 1 AND ((@IsMember = 1 AND @FinanceManagement = 1) OR
					(@IsAssistant = 1 AND dbo.adfHasAccessRight(dbo.adfGetRightID('EditAssignment')) = 1)) THEN 1
				ELSE @ViewAllFinance
			END
	
	INSERT INTO @Out
	SELECT
		[Assignment].[ID],		
		[Assignment].[EmployeeID],
		[Assignment].[QualificationID],
		[Assignment].[FileAs],				
		[Qualification].[FileAs]
	FROM
		[vwAssignment] AS [Assignment]
		LEFT OUTER JOIN [Employee]
			ON [Employee].[ID] = [Assignment].[EmployeeID]
		LEFT JOIN [Qualification]
			ON [Qualification].[ID] = [Assignment].[QualificationID]
	WHERE
		[Assignment].[ProjectID] = @ProjectID AND
		((@StateSelector = 0) OR (@StateSelector != 0 AND [Assignment].[State] = @StateSelector))



	SELECT * FROM @Out


RETURN 0
GO

GRANT EXEC ON pjm7ProjectCreateByTemplateGetParticipantsList TO PUBLIC
GO
