IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'ReportTimeEntryByProjects')
	BEGIN
		PRINT 'Dropping Procedure ReportTimeEntryByProjects'
		DROP  Procedure  ReportTimeEntryByProjects
	END

GO

PRINT 'Creating Procedure ReportTimeEntryByProjects'
GO

/******************************************************************************
**		File: 
**		Name: ReportWRE
**		Desc: 
**
**		This template can be customized:
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: 
**		Date: 
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**		17.07.14	BAO				 ,    
**									"  "
*******************************************************************************/

--------------------------------------------------------------------------------------
CREATE Procedure ReportTimeEntryByProjects
			@CompanyID TIdentifier,
			@DateSelector int,
			@StartDate TDate,
			@EndDate TDate,
			@DivisionSelector int,
			@DivisionID TIdentifier,
			@ProjectTypeID TIdentifier
	
 
AS
	SET NOCOUNT ON

------------------------------------------------
	

	IF @DivisionID IS NULL AND @DivisionSelector=2 
	BEGIN
		RAISERROR('#DivisionIsNotSelected', 16, -1)
		RETURN 1
	END
 
	DECLARE
		@UserID TIdentifier,
		@UserName TName,
		@CompanyFileAs TName	

		SET @UserID = dbo.adfGetCurrentUserID()
	SELECT
		@UserName = [Trustee].[DisplayName]
	FROM
		[Trustee]
	WHERE
		[Trustee].[ID] = @UserID
		
	
	IF @DateSelector = 0 --last month
		BEGIN
			SELECT
				@StartDate = CAST(CONVERT(varchar(8), GETDATE(), 112) AS datetime),
				@StartDate = DATEADD(day, 1-DATEPART(day, @StartDate), @StartDate),
				@StartDate = DATEADD(month, -1, @StartDate),
				@EndDate = DATEADD(day, -1, DATEADD(month, 1, @StartDate))
		END
		ELSE IF @DateSelector = 1 -- current month
			BEGIN
			SELECT
				@StartDate = CAST(CONVERT(varchar(8), GETDATE(), 112) AS datetime),
				@StartDate = DATEADD(day, 1-DATEPART(day, @StartDate), @StartDate),
				@EndDate = DATEADD(day, -1, DATEADD(month, 1, @StartDate))
			END
	
	SELECT
		@CompanyFileAs = 
		CASE
			WHEN @CompanyID IS NULL THEN '()'
			ELSE [FileAs]
		END
	FROM
		[Company]
	WHERE
		[ID] = @CompanyID
		OR
		@CompanyID IS NULL


	SELECT 
		@UserName AS [UserName],
		GETDATE() AS [Date],
		@StartDate AS [PeriodStart],
		@EndDate AS [PeriodEnd],
		@CompanyFileAs AS [CompanyFileAs]
	FROM 
		[Company]
	WHERE 
		[Company].[ID]= @CompanyID
		OR
		@CompanyID IS NULL	
	
	
		
	SELECT 
		[Project].[Number] AS [ProjectNumber],
		[ProjectType].[FileAs] AS [ProjectTypeFileAs],
		ISNULL([Division].[FileAs], '( )') AS [DivisionFileAs],
		[Employee].[LastName]  + ISNULL( ' ' + SUBSTRING([Employee].[FirstName] ,1 , 1) +'.','')
			+ ISNULL(SUBSTRING([Employee].[MiddleName] , 1 ,1)+'.','') 
		AS [EmployeeFileAs],
		SUM(CAST([TimeEntry].[Duration] as decimal))/60 AS [Duration],
		[ProjectType].[ID]
	FROM 
		[TimeEntry] INNER JOIN [Employee]
			ON ([TimeEntry].[EmployeeID] = [Employee].[ID])
		LEFT OUTER JOIN [Division]
			ON ([Employee].[DivisionID] = [Division].[ID])
		INNER JOIN [Project]
			ON ([TimeEntry].[ProjectID] = [Project].[ID])
		INNER JOIN [ProjectType]
			ON ([Project].[ProjectTypeID] = [ProjectType].[ID])
		
	WHERE 
		CONVERT(datetime, CONVERT(varchar(8), [TimeEntry].[StartTime], 112), 112) BETWEEN @StartDate AND @EndDate
		AND [Project].[State] NOT IN (1,5) AND [TimeEntry].[State] IN (3, 6) 
		AND 
		--[Project].[SupplierCompanyID] = @CompanyID
		(
			@CompanyID IS NULL AND [Project].[SupplierCompanyID] IN (SELECT [ID] FROM [Company] WHERE [Own] = 1)
			OR
			[Project].[SupplierCompanyID] = @CompanyID
		)
		AND 
		(
			@DivisionSelector = 0 OR 
			(@DivisionSelector = 1 AND [Employee].[DivisionID] IS NULL) OR
			(@DivisionSelector = 2 AND (@DivisionID IS NULL OR [Employee].[DivisionID] = @DivisionID ))
		)
		AND (@ProjectTypeID IS NULL OR [ProjectType].[ID] = @ProjectTypeID)
		AND [Employee].[HideInReports] = 0
	GROUP BY 
		[ProjectType].[FileAs],
		[ProjectType].[ID],
		[Employee].[FileAs],
		[Employee].[Initials],
		[Employee].[LastName],
		[Employee].[FirstName],
		[Employee].[MiddleName],
		ISNULL([Division].[FileAs], '( )'),
		[Project].[Number]
		
	RETURN 0
GO

GRANT EXEC ON ReportTimeEntryByProjects TO PUBLIC
GO  