IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'ReportCalculation')
	BEGIN
		PRINT 'Dropping Procedure ReportCalculation'
		DROP  Procedure  ReportCalculation
	END

GO

PRINT 'Creating Procedure ReportCalculation'
GO

--------------------------------------------------------------------------------------
-- Copyright (c) 2003 by Avicom
--------------------------------------------------------------------------------------
-- $Archive: $
-- $Author: $
-- $Revision: $
-- $Modtime: $
-- $Date: $
--
-- Description: this stored procedure ...........
-- Input:	.........
-- Output:      0 - success, negative number - otherwise
--
-- Notes:       no
--
--
/* $Log: $ 
   $NoKeywords: $ 
--------------------------------------------------------------------------------------*/
CREATE Procedure ReportCalculation
	@ID int,
	@Language TName = NULL
AS
	SET NOCOUNT ON
	
	DECLARE
		@timeClass TClass,
		@expenseClass TClass,
		@phoneClass TClass,
		@projectClass TClass,
		@companyClass TClass,
		@calculationClass TClass,
		@DocumentCalculationClass TClass,
		@TotalLines	decimal(18,2),
		@Total money,
		@TotalLinesVAT money,
		@VATRate decimal(18,4),
		@VATRateCount int,
		@VATIsIncluded TBool,
		@Code TName,
		@ProjectID TIdentifier,
		@SupplierID TIdentifier,
		@CustomerID TIdentifier,
		@ApplyVAT TBool,
		@RatesWithVAT TBool,
		@CurrencyCode TCode,
		@GroupTimeEntry TBool
		
	SET @Code = CASE WHEN @Language = 'en' THEN 'Calculation; ' ELSE '' END
		
	SET @timeClass = dbo.adfGetClassByName('Pjm5.TimeEntry')
	SET	@expenseClass = dbo.adfGetClassByName('Pjm5.Expense')
	SET	@phoneClass = dbo.adfGetClassByName('Pjm5.PhoneCall')
	SET	@projectClass = dbo.adfGetClassByName('Pjm5.Project')
	SET	@companyClass = dbo.adfGetClassByName('Pjm5.Company')
	SET	@calculationClass = dbo.adfGetClassByName('Pjm5.Calculation')
	
	-- TODO:
	SELECT
		@DocumentCalculationClass = [Calculation].[DocumentClass],
		@ProjectID = [Calculation].[ProjectID],
		@SupplierID = [Project].[SupplierCompanyID],
		@CustomerID = [Project].[CustomerCompanyID],
		@ApplyVAT = [Project].[ApplyVAT],
		@RatesWithVAT = [Project].[RatesWithVAT],
		@VATRate = [Calculation].[VATRate],
		@CurrencyCode = [Calculation].[CurrencyCode],
		@GroupTimeEntry = [Project].[GroupCalculationLines]
	FROM
		[Calculation]
		INNER JOIN [Project]
			ON [Project].[ID] = [Calculation].[ProjectID]
	WHERE
		[Calculation].[ID] = @ID
		
	DECLARE @CurrencyClass TClass, @CurrencyID TIdentifier, @CurrencyMale TBool
	SET @CurrencyClass = dbo.adfGetClassByName('Adf.Currency')
	SELECT @CurrencyID = [ID] FROM [Currency] WHERE [Code] = @CurrencyCode
	SET @CurrencyMale = CASE 
		WHEN dbo.adfPropertyValueGetText(@CurrencyClass, @CurrencyID, '00000001-0000-0000-0000-000000000000') = 'False'
			THEN 0
		ELSE 1
	END


	SET @VATIsIncluded = 0
	IF @DocumentCalculationClass = @timeClass
		SET @VATIsIncluded = @RatesWithVAT
	
	DECLARE @t TABLE(
		[Date] datetime,
		[Employee] nvarchar(256),
		[Description] nvarchar(max),
		[Price] money,
		[Amount] decimal(18,4),
		[Sum] money,
		[VAT] money
	)
	IF @DocumentCalculationClass = @timeClass
	BEGIN
		INSERT INTO @t
			([Date], [Employee], [Description], [Price], [Amount], [Sum], [VAT])
		SELECT
			[pjm5vwCalculationLine].[Date],
			[Employee].[FileAs] AS [Employee],
			[pjm5vwCalculationLine].[Description],
			[pjm5vwCalculationLine].[Price],
			[pjm5vwCalculationLine].[Amount],
			[pjm5vwCalculationLine].[Amount] * [pjm5vwCalculationLine].[Price],
			[pjm5vwCalculationLine].[VAT]
		FROM
			[pjm5vwCalculationLine]
			INNER JOIN [Employee]	
				ON [Employee].[ID] = [pjm5vwCalculationLine].[EmployeeID]
		WHERE 
			[pjm5vwCalculationLine].[CalculationID] = @ID
		
				
		SELECT @Total = SUM(ROUND([Sum], 2)) FROM @t				
		IF @RatesWithVAT = 0
		BEGIN
			SET @TotalLines = @Total
			SET @TotalLinesVAT = ROUND(@Total * @VATRate * @ApplyVAT, 2)
		END
		ELSE
		BEGIN
			SET @TotalLines = ROUND(@Total / (1 + @VATRate * @ApplyVAT), 2)
			SET @TotalLinesVAT = @Total - @TotalLines
		END
	END
	ELSE
	BEGIN
		INSERT INTO @t
			([Date], [Employee], [Description], [Price], [Amount], [Sum], [VAT])
		SELECT
			[pjm5vwCalculationLine].[Date] AS [Date],
			[Employee].[FileAs] AS [Employee],
			[pjm5vwCalculationLine].[Description] AS [Description],
			CASE 
				WHEN @DocumentCalculationClass != @timeClass AND [pjm5vwCalculationLine].[VATIsIncluded] = 1 AND [pjm5vwCalculationLine].[Amount] != 0
					THEN ([pjm5vwCalculationLine].[Amount] * [pjm5vwCalculationLine].[Price] - [pjm5vwCalculationLine].[VAT]) / [pjm5vwCalculationLine].[Amount]
				ELSE [pjm5vwCalculationLine].[Price]
			END AS [Price],
			[pjm5vwCalculationLine].[Amount] AS [Amount],
			(CASE 
				WHEN @DocumentCalculationClass != @timeClass AND [pjm5vwCalculationLine].[VATIsIncluded] = 1
					THEN ([pjm5vwCalculationLine].[Amount] * [pjm5vwCalculationLine].[Price] - [pjm5vwCalculationLine].[VAT])
				ELSE [pjm5vwCalculationLine].[Amount] * [pjm5vwCalculationLine].[Price]
			END) AS [Sum],
			[pjm5vwCalculationLine].[VAT]
		FROM
			[pjm5vwCalculationLine]
			INNER JOIN [Employee]	
				ON [Employee].[ID] = [pjm5vwCalculationLine].[EmployeeID]
		WHERE 
			[pjm5vwCalculationLine].[CalculationID] = @ID
			
		SELECT
			@TotalLines = SUM(ROUND([Sum], 2)),
			@TotalLinesVAT = ROUND(SUM([VAT]),2)
		FROM
			@t				
		SET @TotalLines = ISNULL(@TotalLines, 0) - CASE @VATIsIncluded WHEN 1 THEN ISNULL(@TotalLinesVAT, 0) ELSE 0 END
		SET @TotalLinesVAT = ISNULL(@TotalLinesVAT, 0)
	END
	
	DECLARE @AdvanceFlag TBool
	IF EXISTS(SELECT * FROM [CalculationAdvance] WHERE [CalculationID] = @ID)
		SET @AdvanceFlag = 1
	ELSE
		SET @AdvanceFlag = 0
	
	SELECT
		'' AS [CalculationName],
		CASE @DocumentCalculationClass
				WHEN @timeClass
					THEN '      '
				WHEN @expenseClass
					THEN '      '
				WHEN @phoneClass
					THEN '   '
				ELSE '   '	
		END AS [CalculationDescription],
		[Calculation].[Number],
		[Calculation].[Date],
		[Calculation].[FileAs],
		[Calculation].[PeriodStart],
		[Calculation].[PeriodEnd],
		[Project].[FileAs] AS [ProjectName],
		[Project].[Number] AS [ProjectNumber],
		[Project].[ContractNumber] AS [ContractNumber],
		[Project].[ContractDate] AS [ContractDate],
		[CustomerCompany].[LegalName] AS [CustomerCompany],
		[SupplierCompany].[LegalName] AS [SupplierCompany],
		COALESCE(dbo.adfPropertyValueGetText([SupplierEmployee].[Class], [SupplierEmployee].[ID], '00000002-0000-0000-0000-000000000000'),
			[SupplierEmployee].[LastName] + ISNULL(' ' + [SupplierEmployee].[FirstName], '') + ISNULL(' ' + [SupplierEmployee].[MiddleName], ''), [SupplierEmployee].[FileAs], '                            ') AS [ExecutiveName], 
		[SupplierPosition].[FileAs] AS [ExecutivePosition],
		[Currency].[FileAs] AS [Currency],
		@CurrencyMale AS [CurrencyMale],
		[Calculation].[Total] AS [TotalSum],
		CASE
			WHEN [Project].[ApplyVAT] = 1 THEN @VATIsIncluded
			ELSE 2		 
		END AS [Flag],
		[Calculation].[VAT] AS [Total2],
		[Calculation].[TotalWithVAT] AS [Total3],
		[Calculation].[VATRate] * 100 AS [VATRate],

		@TotalLines AS [TotalLines],
		@TotalLinesVAT AS [TotalLinesVAT],
		@TotalLines + @TotalLinesVAT AS [TotalLinesWithVAT],
		@AdvanceFlag AS [AdvanceFlag],
		[Calculation].[Total] - @TotalLines AS [TotalAdvance],
		[Calculation].[VAT] - @TotalLinesVAT AS [TotalAdvanceVAT],
		[Calculation].[TotalWithVAT] - @TotalLines - @TotalLinesVAT AS [TotalAdvanceWithVAT],
		[Calculation].[ID],
		[Calculation].[ProjectID],
		[Project].[SupplierCompanyID],
		[Project].[CustomerCompanyID]
	FROM
		[Calculation]
		INNER JOIN [Project]
			ON [Calculation].[ProjectID] = [Project].[ID]
		LEFT OUTER JOIN [Company] AS [CustomerCompany]	
			ON [Project].[CustomerCompanyID] = [CustomerCompany].[ID]
		LEFT OUTER JOIN [Company] AS [SupplierCompany]	
			ON [Project].[SupplierCompanyID] = [SupplierCompany].[ID]
		LEFT OUTER JOIN [Employee] AS [SupplierEmployee]
			ON [SupplierCompany].[ExecutiveEmployeeID] = [SupplierEmployee].[ID]
		LEFT OUTER JOIN [Position] AS [SupplierPosition]
			ON [SupplierEmployee].[PositionID] = [SupplierPosition].[ID]
		INNER JOIN [Currency]
			ON [Calculation].[CurrencyCode] = [Currency].[Code]
	WHERE 
		[Calculation].[ID] = @ID		
	
	IF @GroupTimeEntry = 0
		SELECT
			[Date],
			[Employee],
			[Description],
			[Price],
			[Amount],		
			[Sum]
		FROM @t
		ORDER BY 
			[Date] ASC,
			[Price]	ASC,
			[Employee] ASC
	ELSE
		SELECT
			CAST(CONVERT(varchar(8), [Date], 112) as datetime) AS [Date],
			[Employee],
			[Description],
			[Price],
			SUM([Amount]) AS [Amount],
			SUM([Sum]) AS [Sum]
		FROM @t
		GROUP BY
			CAST(CONVERT(varchar(8), [Date], 112) as datetime),
			[Employee],
			[Description],
			[Price]
		ORDER BY 
			CAST(CONVERT(varchar(8), [Date], 112) as datetime) ASC,
			[Price]	ASC,
			[Employee] ASC
			
	SELECT
		[Calculation].[Date],
		ISNULL([Calculation].[Description], [Calculation].[FileAs]) AS [Description],
		[Calculation].[TotalPC] AS [Price],
		[Calculation].[TotalWithVATPC] AS [Sum]
	FROM
		[CalculationAdvance]
		INNER JOIN [Calculation]
			ON [Calculation].[ID] = [CalculationAdvance].[AdvanceCalculationID]
	WHERE
		[CalculationAdvance].[CalculationID] = @ID
		
	DECLARE @author TName
	SELECT @author = [FileAs] FROM [Employee] WHERE [ID] = dbo.adfGetCurrentEmployeeID()
	
	SELECT
      [Calculation].[FileAs] AS [Title],
      [Project].[FileAs] AS [Subject],
      @author AS [Author],
      [Employee].[FileAs] AS [Manager],
      [Company].[FileAs] AS [Company],
      dbo.fnPjm5GetCategoryList(@ID, @calculationClass) AS [Category],
      @Code + [Project].[Number] AS [Keywords]
     FROM
		[Calculation]
		INNER JOIN [Project]
			ON [Calculation].[ProjectID] = [Project].[ID]
		INNER JOIN [Company]
			ON [Project].[SupplierCompanyID] = [Company].[ID]
		INNER JOIN [Employee]
			ON [Employee].[ID] = [Project].[ProjectManagerEmployeeID]
     WHERE
		[Calculation].[ID] = @ID

	SELECT
		[Property].[Name] as [Name],
		[PropertyValue].[Value] as [Value]
	FROM
		[Calculation]
		LEFT OUTER JOIN [PropertyValue]
			ON ([PropertyValue].[DocumentClass] = @calculationClass AND 
				[PropertyValue].[DocumentID] = [Calculation].[ID])
		LEFT OUTER JOIN [Property]
			ON [PropertyValue].[PropertyID] = [Property].[ID]
		WHERE
			[Calculation].[ID] = @ID

	SELECT 
		[Property].[Name] as [Name],
		[PropertyValue].[Value] as [Value]
	FROM
		[Project]
		LEFT OUTER JOIN [PropertyValue]
			ON ([PropertyValue].[DocumentClass] = @projectClass AND
				[PropertyValue].[DocumentID] = [Project].[ID])
		LEFT OUTER JOIN [Property]
			ON [PropertyValue].[PropertyID] = [Property].[ID]
	WHERE
		[Project].[ID] = @ProjectID
		
	SELECT 
		[Property].[Name] as [Name],
		[PropertyValue].[Value] as [Value]
	FROM
		[Company]
		LEFT OUTER JOIN [PropertyValue]
			ON ([PropertyValue].[DocumentClass] = @companyClass AND 
				[PropertyValue].[DocumentID] = [Company].[ID])
		LEFT OUTER JOIN [Property]
			ON ([PropertyValue].[PropertyID] = [Property].[ID] )
	WHERE
		[Company].[ID] = @SupplierID

	SELECT 
		[Property].[Name] as [Name],
		[PropertyValue].[Value] as [Value]
	FROM
		[Company]
		LEFT OUTER JOIN [PropertyValue]
			ON ([PropertyValue].[DocumentClass] = @companyClass AND 
				[PropertyValue].[DocumentID] = [Company].[ID])
		LEFT OUTER JOIN [Property]
			ON ([PropertyValue].[PropertyID] = [Property].[ID] )
	WHERE
		[Company].[ID] = @CustomerID
	
	RETURN 0
GO

GRANT EXEC ON ReportCalculation TO PUBLIC
GO
