IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'ReportInvoice')
	BEGIN
		PRINT 'Dropping Procedure ReportInvoice'
		DROP  Procedure  ReportInvoice
	END

GO

PRINT 'Creating Procedure ReportInvoice'
GO

--------------------------------------------------------------------------------------
-- Copyright (c) 2003 by Avicom
--------------------------------------------------------------------------------------
-- $Archive: $
-- $Author: $
-- $Revision: $
-- $Modtime: $
-- $Date: $
--
-- Description: this stored procedure ...........
-- Input:	.........
-- Output:      0 - success, negative number - otherwise
--
-- Notes:       no
--
--
/* $Log: $ 
   $NoKeywords: $ 
--------------------------------------------------------------------------------------*/
CREATE Procedure ReportInvoice
	@ID int,
	@Language TName = NULL
AS
	SET NOCOUNT ON
	DECLARE
		@TotalSum money,
		@TotalCount int,
		@TotalVAT money	,
		@VATRate decimal(18,4),
		@VATRateCount int,
		@TotalVATSum decimal(18,4),
		@AdvanceValue decimal(18,4),
		@PaymentValue decimal(18,4),
		@CurrencyCode varchar(8),
		@Currency TName,
		@Class TClass,
		@Code TName
	SET @Code = CASE WHEN @Language = 'en' THEN 'Invoice; ' ELSE ': ' END

	SELECT
		@Currency = CASE [Project].[InvoiceCurrency] 
			WHEN 0 THEN 'Project'
			WHEN 1 THEN 'Payment'
		END,
		@Class = [Invoice].[Class]
	FROM
		[Invoice]
		INNER JOIN [Project]
			ON [Invoice].[ProjectID] = [Project].[ID]
	WHERE
		[Invoice].[ID] = @ID					

	SELECT 
		@AdvanceValue = SUM(ISNULL(
			CASE
				WHEN @Currency = 'Payment'
					THEN [Invoice].[TotalWithVAT]
				WHEN @Currency = 'Project'
					THEN [Invoice].[TotalWithVATPC]
			END, 0.0))
	FROM
		[AdvanceInvoice] 
		INNER JOIN [Invoice]
			ON [Invoice].[ID] = [AdvanceInvoice].[AdvanceInvoiceID]


	WHERE
		[AdvanceInvoice].[InvoiceID] = @ID
	SET @AdvanceValue = ISNULL(@AdvanceValue, 0)

	SELECT 
		@PaymentValue = SUM(ISNULL(
			CASE
				WHEN @Currency = 'Payment'
					THEN [PaymentDetail].[PaymentValue]
				WHEN @Currency = 'Project'
					THEN [PaymentDetail].[Value]
			END, 0.0))
	FROM
		[AdvanceInvoice] 
		INNER JOIN [Invoice]
			ON [Invoice].[ID] = [AdvanceInvoice].[AdvanceInvoiceID]
		INNER JOIN [PaymentDetail]
			ON [PaymentDetail].[InvoiceID] = [Invoice].[ID]
	WHERE
		[AdvanceInvoice].[InvoiceID] = @ID
	SET @PaymentValue = ISNULL(@PaymentValue, 0)
		
	DECLARE @t TABLE(
		[Description] nvarchar(max),
		[Amount] decimal(18,4),
		[Price] money,
		[Sum] money,
		[VAT] money,
		[VATRate] decimal(18,4),
		[PriceWithVAT] money,
		[SumWithVAT] money,
		[UOM] nvarchar(64),
		[ServiceTypeName] nvarchar(256)
	)
	INSERT INTO @t
		(
		[Description],
		[Amount],
		[Price],
		[Sum],
		[VAT],
		[VATRate],
		[PriceWithVAT],
		[SumWithVAT],
		[UOM],
		[ServiceTypeName]
		)
	SELECT
	[InvoiceLine].[Description] AS [Description],
	[InvoiceLine].[Amount] AS [Amount],
	CASE 
		WHEN [InvoiceLine].[VATIsIncluded] = 1 AND @Currency = 'Payment' AND [InvoiceLine].[Amount] != 0
			THEN ROUND([InvoiceLine].[Price] * [InvoiceLine].[Amount] - [InvoiceLine].[VAT], 2) / [InvoiceLine].[Amount]
		WHEN [InvoiceLine].[VATIsIncluded] = 1 AND @Currency = 'Project' AND [InvoiceLine].[Amount] != 0
			THEN ROUND([InvoiceLine].[PricePC] * [InvoiceLine].[Amount] - [InvoiceLine].[VATPC], 2) / [InvoiceLine].[Amount]	
		WHEN [InvoiceLine].[VATIsIncluded] = 0 AND @Currency = 'Payment' 
			THEN [InvoiceLine].[Price]
		WHEN [InvoiceLine].[VATIsIncluded] = 0 AND @Currency = 'Project' 
			THEN [InvoiceLine].[PricePC] 	 
	END AS [Price],
	[InvoiceLine].[Amount] * 	
		CASE 
			WHEN [InvoiceLine].[VATIsIncluded] = 1 AND @Currency = 'Payment'  AND [InvoiceLine].[Amount] != 0
				THEN ([InvoiceLine].[Price] * [InvoiceLine].[Amount] - [InvoiceLine].[VAT]) / [InvoiceLine].[Amount] 
			WHEN [InvoiceLine].[VATIsIncluded] = 1 AND @Currency = 'Project'  AND [InvoiceLine].[Amount] != 0
				THEN ([InvoiceLine].[PricePC] * [InvoiceLine].[Amount] - [InvoiceLine].[VATPC]) / [InvoiceLine].[Amount] 	
			WHEN [InvoiceLine].[VATIsIncluded] = 0 AND @Currency = 'Payment' 
				THEN [InvoiceLine].[Price]
			WHEN [InvoiceLine].[VATIsIncluded] = 0 AND @Currency = 'Project' 
				THEN [InvoiceLine].[PricePC]
		END AS [Sum],
	CASE	
		WHEN @Currency = 'Payment' 
			THEN [InvoiceLine].[VAT]
		WHEN @Currency = 'Project' 
			THEN [InvoiceLine].[VATPC]
	END AS [VAT],			
	[InvoiceLine].[VATRate],
	CASE 
		WHEN [InvoiceLine].[VATIsIncluded] = 0 AND @Currency = 'Payment' AND [InvoiceLine].[Amount] != 0
			THEN ROUND([InvoiceLine].[Price] * [InvoiceLine].[Amount] + [InvoiceLine].[VAT], 2) / [InvoiceLine].[Amount]
		WHEN [InvoiceLine].[VATIsIncluded] = 0 AND @Currency = 'Project' AND [InvoiceLine].[Amount] != 0
			THEN ROUND([InvoiceLine].[PricePC] * [InvoiceLine].[Amount] + [InvoiceLine].[VATPC], 2) / [InvoiceLine].[Amount]	
		WHEN [InvoiceLine].[VATIsIncluded] = 1 AND @Currency = 'Payment' 
			THEN [InvoiceLine].[Price]
		WHEN [InvoiceLine].[VATIsIncluded] = 1 AND @Currency = 'Project' 
			THEN [InvoiceLine].[PricePC] 	 
	END AS [PriceWithVAT],
	[InvoiceLine].[Amount] * 	
		CASE 
			WHEN [InvoiceLine].[VATIsIncluded] = 0 AND @Currency = 'Payment'  AND [InvoiceLine].[Amount] != 0
				THEN ([InvoiceLine].[Price] * [InvoiceLine].[Amount] + [InvoiceLine].[VAT]) / [InvoiceLine].[Amount] 
			WHEN [InvoiceLine].[VATIsIncluded] = 0 AND @Currency = 'Project'  AND [InvoiceLine].[Amount] != 0
				THEN ([InvoiceLine].[PricePC] * [InvoiceLine].[Amount] - [InvoiceLine].[VATPC]) / [InvoiceLine].[Amount] 	
			WHEN [InvoiceLine].[VATIsIncluded] = 1 AND @Currency = 'Payment' 
				THEN [InvoiceLine].[Price]
			WHEN [InvoiceLine].[VATIsIncluded] = 1 AND @Currency = 'Project' 
				THEN [InvoiceLine].[PricePC]
		END AS [SumWithVAT],
		[UOM].[Code],
		[ServiceType].[FileAs]
	FROM
		[InvoiceLine]	
		LEFT OUTER JOIN [UOM]
			ON [UOM].[ID] = [InvoiceLine].[UOMID]
		LEFT OUTER JOIN [ServiceType]
			ON [InvoiceLine].[ServiceTypeID] = [ServiceType].[ID]
	WHERE 
		[InvoiceLine].[InvoiceID] = @ID	
				
		
	SELECT
		@TotalSum = SUM(ROUND([Sum], 2)),
		@TotalCount = COUNT(*),
		@TotalVAT = SUM(ROUND([VAT], 2)),
		@VATRate = MAX([VATRate]),
		@VATRateCount = COUNT(DISTINCT [VATRate])
	FROM
		@t	
		
	SELECT			
		@TotalVATSum = CASE
			WHEN [Project].[ApplyVAT] = 0 THEN ISNULL(@TotalSum, 0)
			ELSE ISNULL((@TotalSum + @TotalVAT), 0)
		END,
		@CurrencyCode = CASE
			WHEN @Currency = 'Payment' THEN [Invoice].[CurrencyCode]
			WHEN @Currency = 'Project' THEN [Project].[CurrencyCode]
		END	 
	FROM
		[Invoice]
		INNER JOIN [Project]
			ON [Invoice].[ProjectID] = [Project].[ID]
	WHERE 
		[Invoice].[ID] = @ID
					
	DECLARE @CurrencyClass TClass, @CurrencyID TIdentifier, @CurrencyMale TBool
	SET @CurrencyClass = dbo.adfGetClassByName('Adf.Currency')
	SELECT @CurrencyID = [ID] FROM [Currency] WHERE [Code] = @CurrencyCode
	SET @CurrencyMale = CASE 
		WHEN dbo.adfPropertyValueGetText(@CurrencyClass, @CurrencyID, '00000001-0000-0000-0000-000000000000') = 'False'
			THEN 0
		ELSE 1
	END
	
	SELECT
		[Invoice].[FileAs] AS [InvoiceName], -- has to be deleted
		[Invoice].[Number] AS [InvoiceNumber], -- has to be deleted
		[Invoice].[Date] AS [InvoiceDate], -- has to be deleted
		[Invoice].[Date],
		[Invoice].[Number],
		[Invoice].[FileAs],
		@CurrencyCode AS [CurencyCode],
		@CurrencyMale AS [CurrencyMale],
		[SupplierCompany].[LegalName] AS [SupplierCompany],
		CASE
		WHEN [LegalAddress].[AddressTypeID] IS NOT NULL THEN
			dbo.fnPjm5AddressAsString([LegalAddress].[Street],[LegalAddress].[City],[LegalAddress].[Region],[LegalAddress].[PostalCode],[LegalAddress].[Country])
		ELSE ''
		END AS [Address],
		[Phone].[Phone] AS [Phone],
		[SupplierCompany].[LegalCode] AS [LegalCode],
		[SupplierCompany].[KPP] AS [KPP],
		[BankAccount].[BankName] AS [BankName],
		[BankAccount].[City] AS [BankCity],
		[BankAccount].[BankCode] AS [BankCode],
		[BankAccount].[Account] AS [CAccount],
		[BankAccount].[IntermediaryAccount] AS [SAccount],
		[BankAccount].[Account],
		[BankAccount].[IntermediaryAccount],
		CASE
				WHEN @Language = 'en' THEN 
					ISNULL(dbo.adfPropertyValueGetText([CustomerCompany].[Class], [CustomerCompany].[ID], '00000001-0000-0000-0000-000000000000'), [CustomerCompany].[LegalName])
				ELSE [CustomerCompany].[LegalName]
			END AS [CustomerCompany],
		CASE
				WHEN @Language = 'en' THEN 
					ISNULL(dbo.adfPropertyValueGetText([CustomerCompany].[Class], [CustomerCompany].[ID], '00000001-0000-0000-0000-000000000000'), [CustomerCompany].[LegalName])
				ELSE [CustomerCompany].[LegalName]
			END AS [PayCustomerCompany],
		COALESCE(dbo.adfPropertyValueGetText([SupplierExecutiveEmployee].[Class], [SupplierExecutiveEmployee].[ID], '00000002-0000-0000-0000-000000000000'),
			[SupplierExecutiveEmployee].[LastName] + ISNULL(' ' + [SupplierExecutiveEmployee].[FirstName], '') + ISNULL(' ' + [SupplierExecutiveEmployee].[MiddleName], ''), [SupplierExecutiveEmployee].[FileAs], '                            ') AS [ExecutiveName], 
		[SupplierExecutivePosition].[FileAs] AS [ExecutivePosition],
		COALESCE(dbo.adfPropertyValueGetText([SupplierAccountantEmployee].[Class], [SupplierAccountantEmployee].[ID], '00000002-0000-0000-0000-000000000000'), 
			[SupplierAccountantEmployee].[LastName] + ISNULL(' ' + [SupplierAccountantEmployee].[FirstName], '') + ISNULL(' ' + [SupplierAccountantEmployee].[MiddleName], ''), [SupplierAccountantEmployee].[FileAs], '                            ') AS [AccountantName], 
		[SupplierAccountantPosition].[FileAs] AS [AccountantPosition],
		[Project].[FileAs] AS [ProjectName],
		[Project].[Number] AS [ProjectNumber],
		[Project].[ContractNumber] AS [ContractNumber],
		[Project].[ContractDate] AS [ContractDate],
		@TotalSum AS [TotalSum],
		CASE
			WHEN [Project].[ApplyVAT] = 0 THEN 0
			WHEN [Project].[ApplyVAT] = 1 AND @VATRateCount = 1 THEN (@VATRate * 100)
			ELSE NULL
		END AS [VATRate],
		CASE
			WHEN [Project].[ApplyVAT] = 1 AND @VATRateCount = 1 THEN 1
			ELSE 0
		END AS [VATFlag],
		CASE
			WHEN [Project].[ApplyVAT] = 0 THEN 0
			ELSE 1
		END	AS [VATRateFlag],
		@TotalVAT AS [VATSum],
		CASE
			WHEN [Project].[ApplyVAT] = 0 THEN ISNULL(@TotalSum, 0)
			ELSE ISNULL((@TotalSum + @TotalVAT), 0)
		END AS [TotalVATSum],
		CASE
			WHEN [Project].[ApplyVAT] = 0 THEN dbo.fnPjm5MoneyToString(@TotalSum, @CurrencyCode, 0)
			ELSE dbo.fnPjm5MoneyToString((@TotalSum + @TotalVAT), @CurrencyCode, 0)
		END AS [TotalVATSumText],
		CASE
			WHEN [Project].[ApplyVAT] = 0 THEN dbo.fnPjm5CurrencyToString(@TotalSum, @CurrencyCode)
			ELSE dbo.fnPjm5CurrencyToString((@TotalSum + @TotalVAT), @CurrencyCode)
		END AS [CurrencyCodeTotalVATSum],
		@TotalCount AS [Count],
		(CASE WHEN [Invoice].[InvoiceExpirationPeriodType] = 1 THEN
			dbo.fnPjm5GetWorkingDays([Invoice].[Date], [Invoice].[DueDate]) 
		ELSE
			DATEDIFF(day, [Invoice].[Date], [Invoice].[DueDate]) + 1
		END)  AS [InvoiceExpirationPeriod],
		[Invoice].[InvoiceExpirationPeriodType],
		CASE
			WHEN @Language = 'en' THEN dbo.fnPjm5AddressAsEnString([AddressCustomerCompanyEn].[Street],[AddressCustomerCompanyEn].[City],[AddressCustomerCompanyEn].[Region],[AddressCustomerCompanyEn].[PostalCode],[AddressCustomerCompanyEn].[Country])
			WHEN [LegalAddressCustomerCompany].[AddressTypeID] IS NOT NULL THEN
			 dbo.fnPjm5AddressAsString([AddressCustomerCompany].[Street],[LegalAddressCustomerCompany].[City],[LegalAddressCustomerCompany].[Region],[LegalAddressCustomerCompany].[PostalCode],[LegalAddressCustomerCompany].[Country]) 
		END AS [AddressCustomerCompany],
		@CurrencyCode AS [CurrencyCode],
		@AdvanceValue AS [AdvanceValue],
		@TotalVATSum - @AdvanceValue AS [Total],
		dbo.fnPjm5CurrencyToString((@AdvanceValue), @CurrencyCode) AS [AdvanceCurrency],
		dbo.fnPjm5CurrencyToString((@TotalVATSum - @AdvanceValue), @CurrencyCode) AS [TotalCurrency],
		CASE
			WHEN @AdvanceValue = 0 THEN 0
			ELSE 1 
		END	AS [AdvanceFlag],
		CASE
			WHEN [Project].[ApplyVAT] = 1 AND @VATRateCount = 1 THEN NULL
			ELSE N' .'
		END AS [VATText],
		dbo.fnPjm5MoneyToString((@TotalVATSum - @AdvanceValue), @CurrencyCode, 0) AS [TotalText]	
	FROM
		[Invoice]
		INNER JOIN [Project]
			ON [Invoice].[ProjectID] = [Project].[ID]
		LEFT OUTER JOIN [BankAccount]
			ON [Invoice].[SupplierBankAccountID] = [BankAccount].[ID]
		LEFT OUTER JOIN [Company] AS [CustomerCompany]	
			ON [Project].[CustomerCompanyID] = [CustomerCompany].[ID]
		LEFT OUTER JOIN [Company] AS [SupplierCompany]	
			ON [Project].[SupplierCompanyID] = [SupplierCompany].[ID]
		LEFT OUTER JOIN [Employee] AS [SupplierExecutiveEmployee]
			ON [SupplierCompany].[ExecutiveEmployeeID] = [SupplierExecutiveEmployee].[ID]
		LEFT OUTER JOIN [Position] AS [SupplierExecutivePosition]
			ON [SupplierExecutiveEmployee].[PositionID] = [SupplierExecutivePosition].[ID]
		LEFT OUTER JOIN [Employee] AS [SupplierAccountantEmployee]
			ON [SupplierCompany].[AccountantEmployeeID] = [SupplierAccountantEmployee].[ID]
		LEFT OUTER JOIN [Position] AS [SupplierAccountantPosition]
			ON [SupplierAccountantEmployee].[PositionID] = [SupplierAccountantPosition].[ID]
		LEFT OUTER JOIN [BusinessCard]
			ON [SupplierCompany].[ID] = [BusinessCard].[ID]	AND
			   [SupplierCompany].[Class] = [BusinessCard].[Class]
		LEFT OUTER JOIN [Address]
			ON [BusinessCard].[ID] = [Address].[BusinessCardID]	AND
			   [BusinessCard].[Class] = [Address].[BusinessCardClass] AND
			   [Address].[AddressTypeID] = 3 
		LEFT OUTER JOIN [Address] as [LegalAddress]
			ON [BusinessCard].[ID] = [LegalAddress].[BusinessCardID]	AND
			   [BusinessCard].[Class] = [LegalAddress].[BusinessCardClass] AND
			   [LegalAddress].[AddressTypeID] = 1 
		LEFT OUTER JOIN [Phone]
			ON [BusinessCard].[ID] = [Phone].[BusinessCardID]	AND
			   [BusinessCard].[Class] = [Phone].[BusinessCardClass] AND
			   [Phone].[PhoneTypeID] = 11
		LEFT OUTER JOIN [BusinessCard] AS [BusinessCardCustomerCompany]
			ON [CustomerCompany].[ID] = [BusinessCardCustomerCompany].[ID]	AND
			   [CustomerCompany].[Class] = [BusinessCardCustomerCompany].[Class]
		LEFT OUTER JOIN [Address] AS [AddressCustomerCompanyEn]
			ON [BusinessCardCustomerCompany].[ID] = [AddressCustomerCompanyEn].[BusinessCardID]	AND
			   [BusinessCardCustomerCompany].[Class] = [AddressCustomerCompanyEn].[BusinessCardClass] AND
			   [AddressCustomerCompanyEn].[AddressTypeID] = 6	   
		LEFT OUTER JOIN [Address] AS [AddressCustomerCompany]
			ON [BusinessCardCustomerCompany].[ID] = [AddressCustomerCompany].[BusinessCardID]	AND
			   [BusinessCardCustomerCompany].[Class] = [AddressCustomerCompany].[BusinessCardClass] AND
			   [AddressCustomerCompany].[AddressTypeID] = 3
		LEFT OUTER JOIN [Address] AS [LegalAddressCustomerCompany]
			ON [BusinessCardCustomerCompany].[ID] = [LegalAddressCustomerCompany].[BusinessCardID]	AND
			   [BusinessCardCustomerCompany].[Class] = [LegalAddressCustomerCompany].[BusinessCardClass] AND
			   [LegalAddressCustomerCompany].[AddressTypeID] = 1
			   
	WHERE 
		[Invoice].[ID] = @ID		
	
	SELECT
		[Description],
		[Price],
		[Amount],
		[Sum],
		[PriceWithVAT],
		[SumWithVAT],
		[UOM],
		[ServiceTypeName]
	FROM
		@t
	ORDER BY 
		[ServiceTypeName] ASC,
		[Description] ASC

	DECLARE @author TName
	SELECT @author = [FileAs] FROM [Employee] WHERE [ID] = dbo.adfGetCurrentEmployeeID()
	
	SELECT
      [Invoice].[FileAs] AS [Title],
      [Project].[FileAs] AS [Subject],
      @author AS [Author],
      [Employee].[FileAs] AS [Manager],
      [Company].[FileAs] AS [Company],
      dbo.fnPjm5GetCategoryList(@ID, @Class) AS [Category],
      @Code + [Project].[Number] AS [Keywords]
     FROM
		[Invoice]
		INNER JOIN [Project]
			ON [Invoice].[ProjectID] = [Project].[ID]
		INNER JOIN [Company]
			ON [Project].[SupplierCompanyID] = [Company].[ID]
		INNER JOIN [Employee]
			ON [Employee].[ID] = [Project].[ProjectManagerEmployeeID]
     WHERE
		[Invoice].[ID] = @ID

RETURN 0
GO

GRANT EXEC ON ReportInvoice TO PUBLIC

GO
