IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'ReportEmployeeTimeAndRevenueByProjectHeader')
	BEGIN
		PRINT 'Dropping Procedure ReportEmployeeTimeAndRevenueByProjectHeader'
		DROP  Procedure  ReportEmployeeTimeAndRevenueByProjectHeader
	END
GO

PRINT 'Creating Procedure ReportEmployeeTimeAndRevenueByProjectHeader'
GO
/******************************************************************************
**		File: ReportEmployeeTimeByProjectHeader.sql
**		Name: ReportEmployeeTimeByProjectHeader
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: MAN
**		Date: 18/11/2010 
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:		Description:
**		--------	--------	-------------------------------------------
**		18.11.2010	MAN			First Version
**		09.09.2013	BAO			   '  ' 
**								'  ""'  '   " "'
**								 '  " "'
**		15.11.13	SAP			  DeviationType    
**								   
**		31.10.14	SAP			    " "
**								  
*******************************************************************************/
CREATE PROCEDURE [dbo].[ReportEmployeeTimeAndRevenueByProjectHeader]
        @CompanyID TIdentifier,
		@CostCenterSelector INT,
        @CostCenterID TIdentifier,
        @ProjectID TIdentifier,
        @PeriodName TName,
        @PeriodStart TDateTime,
        @PeriodEnd TDateTime,
		@DeviationType TIdentifier,
		@ConvertionType TIdentifier,
		@EmployeeID TIdentifier,
		@CurrencyCode TCode3,
		@MaxValue TAmount,		
		@ScaleSelector INT,
		@Prefix nvarchar(32)
AS
SET NOCOUNT ON
DECLARE
	@CompanyName TName,
	@ProjectName TName,
	@CostCenterName TName,
	@WorkingDays	decimal(18,2),
	@UserName TName,
	@UserID TIdentifier,
	@DeviationTypeName TName,
	@ConvertionTypeName TName,
	@EmployeeName TName,
	--@Prefix	varchar(5),
	@Total float, @Rate float

SET @CompanyName = '()'

SELECT TOP 1
	@CompanyName = [Company].[FileAs]
FROM
    [Company]
WHERE 
    [Company].[ID] = @CompanyID   
   
IF @EmployeeID IS NULL
	SELECT TOP 1
		@EmployeeName = [Employee].[FileAs]
	FROM
		[Employee]
	WHERE
		[Employee].[ID] = @EmployeeID
  	
   SET DATEFIRST 7
   SET @WorkingDays = dbo.fnPjm5GetWorkingDays(@PeriodStart,DATEADD(day, -1, @PeriodEnd))
   SET DATEFIRST 1

   SET @UserID = dbo.adfGetCurrentUserID()
	
SELECT TOP 1
	@UserName = [Trustee].[DisplayName]
FROM 
	[Trustee]
WHERE 
	[Trustee].[ID] = @UserID

SET @DeviationTypeName =
	CASE @DeviationType
		WHEN 0 THEN '  ""'
		WHEN 1 THEN '  " "' 
	END

SET @ConvertionTypeName =
	CASE @ConvertionType
		WHEN 0 THEN '  '
		WHEN 1 THEN '  '
		WHEN 2 THEN ' ' 
	END

--SET @Prefix = ''

SELECT
	@ProjectName = [Project].[FileAs]
FROM
	[Project]
WHERE
	[Project].[ID] = @ProjectID

IF @CostCenterSelector = 1 AND @CostCenterID IS NULL
BEGIN
	SET @CostCenterName = '( )'
END
ELSE
BEGIN
	SELECT
		@CostCenterName = [CostCenter].[FileAs]
	FROM
		 [CostCenter]
	WHERE 
		 [CostCenter].[ID] = @CostCenterID
END
	
SELECT
     @CompanyName  AS [CompanyName],
     @ProjectName AS [ProjectName],
     @CostCenterName AS [CostCenterName],
     @WorkingDays AS [WorkingDays],
     @WorkingDays*8 as [WorkingHours],
     @UserName as [UserName],
     @PeriodName AS [PeriodName],
	 @DeviationType AS [DeviationType],
     @DeviationTypeName AS [DeviationTypeName],
     @ConvertionTypeName AS [ConvertionTypeName],
     @EmployeeName AS [EmployeeName],
     --CAST(@CurrencyCode AS nvarchar(32)) AS [CurrencyCode],
     @Prefix AS [CurrencyPrefix]

RETURN 0
GO

GRANT EXEC ON ReportEmployeeTimeAndRevenueByProjectHeader TO PUBLIC
GO