IF EXISTS (SELECT * FROM sysobjects WHERE TYPE = 'P' AND name = 'ReportPaymentsByClientsHeader')
	BEGIN
		PRINT 'Dropping Procedure ReportPaymentsByClientsHeader'
		DROP  PROCEDURE  ReportPaymentsByClientsHeader
	END
GO
PRINT 'Creating Procedure ReportPaymentsByClientsHeader'
GO
/******************************************************************************
**		File: ReportPaymentsByClientsHeader.sql
**		Name: ReportPaymentsByClientsHeader
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: Sergey Pelevin
**		Date: 14.03.2013 
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:		Description:
**		--------	--------	-------------------------------------------
**		29.08.14	SAP			    
*******************************************************************************/
CREATE PROCEDURE [dbo].[ReportPaymentsByClientsHeader]
	@OwnCompanySelector		TIdentifier, -- ID   (NULL - )
    @CompanyManagerSelector TIdentifier, --   : 0 -  , 1 -  
    @ManagerID TIdentifier, -- ID   (NULL - ,    )
    @ReportCurrency varchar(50), --    
    @PeriodName TName, --  
    @ScaleSelector int, --  : 0 - , 1 -  , 2 - , 3 -  (SmartValue)
    @Scale int, --   
    @CountSelector TIdentifier, --    : 0 - , 1 -  5, 2 -  10,  3 - 
	@Count TIdentifier,	 -- -       
	@SumByCompanyGroups bit --   
AS
SET NOCOUNT ON

DECLARE
	@OwnCompanyName TName,
	@CompanyManagerName TName,
	@UserName TName,
	@UserID TIdentifier,
	@Displayed TName

	--  	
	SELECT 
		@OwnCompanyName = [Company].[FileAs]		
	FROM
		[Company]
	WHERE 
		[Company].[ID] = @OwnCompanySelector	
	IF @OwnCompanyName IS NULL
	SET @OwnCompanyName = '()'
		
	-- 
	IF @CompanyManagerSelector = 0
		SET @CompanyManagerName = '()'
	ELSE
	BEGIN
		IF @ManagerID IS NULL
			SET @CompanyManagerName = '( )'
		ELSE
			SELECT
				@CompanyManagerName = [Employee].[FileAs]				
			FROM
				[Employee]
			WHERE
				[Employee].[ID] = @ManagerID
	END				
		
	
		
	-- 
	SET @UserID = dbo.adfGetCurrentUserID()		
	SELECT
		@UserName = [Trustee].[DisplayName]
	FROM 
		[Trustee]
	WHERE 
		[Trustee].[ID] = @UserID
	
	---  
	SELECT
		@Displayed = 
		CASE @CountSelector
			WHEN 0 THEN ' '
			WHEN 1 THEN ' 5 '
			WHEN 2 THEN ' 10 '
			WHEN 3 THEN ' ' + CAST(@Count as varchar(100)) + ' '				
		END
	
	--    
	SELECT
		@OwnCompanyName AS [OwnCompanyName],
		@CompanyManagerName AS [CompanyManagerName],
		@ReportCurrency AS [Currency],
		@PeriodName AS [PeriodName],
		@UserName AS [UserName],
		@Displayed AS [DisplayedCount],
		@SumByCompanyGroups as [SumByCompanyGroups]	

RETURN 0
GO
GRANT EXEC ON ReportPaymentsByClientsHeader TO PUBLIC
GO