IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'ReportProductivityByProject')
	BEGIN
		PRINT 'Dropping Procedure ReportProductivityByProject'
		DROP  Procedure  ReportProductivityByProject
	END

GO

PRINT 'Creating Procedure ReportProductivityByProject'
GO
/******************************************************************************
**		File: ReportProductivityByProject.sql
**		Name: ReportProductivityByProject
**
**         
**		Return values:
**
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**		22.07.2014	BAO				 ,    
**									"  "
*******************************************************************************/

CREATE Procedure ReportProductivityByProject
	@ProjectSelector int,
	@ActiveProjectID TIdentifier,
	@NotActiveProjectID TIdentifier,
	@DateSelector		int,

	@Date				TDatetime,
	@ProductivitySelector int,
	@CountSelector		int,
	@UserCount          int,
	@EmployeeTypeSelector	TIdentifier
AS
	SET NOCOUNT ON

	DECLARE
			@UserID TIdentifier,
			@UserName TName,
			@ProjectNumber TCode,
			@Count int,
			@Productivity TName,
			@TodayDate TDate,
			@Direction int,
			@ProjectID TIdentifier

	SET @ProjectID = CASE @ProjectSelector
		WHEN 0 THEN @ActiveProjectID
		WHEN 1 THEN @NotActiveProjectID
	END	
	
	IF @ProjectID IS NULL
	BEGIN
		RAISERROR('#ProjectIsNotSelected', 16, -1)
		RETURN 1
	END
	
	SELECT @TodayDate = GETDATE()
	SET @Date = CASE @DateSelector
		WHEN 0 THEN	CAST(CONVERT(varchar(8), @TodayDate, 112) AS DATETIME)
		WHEN 1 THEN	DATEADD( Day, -1, CAST(CONVERT(varchar(8), @TodayDate, 112) AS DATETIME))
		ELSE CAST(CONVERT(VARCHAR(8), @Date, 112) AS DATETIME)
	END
	SET @Productivity = CASE @ProductivitySelector
         WHEN 0 THEN '  '
         WHEN 1 THEN '  '
    END
    
    SET @Direction = CASE @ProductivitySelector
         WHEN 0 THEN 1
         WHEN 1 THEN -1
    END

	DECLARE @ProductivityByEmployeeData TABLE ([EmployeeFileAs] TName, [QualificationFileAs] TName,
                               [PlannedDuration] float, [BillableDuration] float, [UnbillableDuration] float,
							   [CommonDuration] float, [Percent] decimal(18,4), [Deviation] float,
							   [PercentDeviation] decimal(18,4))
	
	DECLARE @ProductivityByTaskData TABLE ([TaskFileAs] TName, [PlannedDuration] float, [BillableDuration] float, 
								[UnbillableDuration] float, [Duration] float,[Percent] decimal(18,4), 
								[Deviation] float, [PercentDeviation] decimal(18,4))
         
    SELECT
		@ProjectNumber = [Project].[Number]
	FROM
		[Project]
	WHERE
		[Project].[ID] = @ProjectID		
    
	SET @UserID = dbo.adfGetCurrentUserID()
	SELECT
		@UserName = [Trustee].[DisplayName]
	FROM
		[Trustee]
	WHERE
		[Trustee].[ID] = @UserID
	
	;
	WITH TimeEntryTemp ([EmployeeID], [ProjectID], [Duration], 
						[BillableDuration], [UnbillableDuration]) AS
	(
		SELECT
			[TimeEntry].[EmployeeID],
			[TimeEntry].[ProjectID],
			SUM(ISNULL([TimeEntry].[Duration], 0)),
			SUM(ISNULL([BillableTime].[Duration], 0)),
			SUM(ISNULL([UnbillableTime].[Duration], 0))
		FROM
			[TimeEntry]
				LEFT OUTER JOIN [TimeEntry] AS [BillableTime]
					ON [TimeEntry].[ID] = [BillableTime].[ID]
						AND [BillableTime].[Billable] = 1
				LEFT OUTER JOIN [TimeEntry] AS [UnbillableTime]
					ON [TimeEntry].[ID] = [UnbillableTime].[ID]
						AND [UnbillableTime].[Billable] = 0
				LEFT OUTER JOIN [Employee]
					ON [TimeEntry].[EmployeeID] = [Employee].[ID]
		WHERE
			CAST(CONVERT(VARCHAR(8), [TimeEntry].[StartTime], 112) AS DATETIME) <= @Date
			AND [TimeEntry].[State] IN (2, 3, 6)
			AND [TimeEntry].[ProjectID] = @ProjectID
			AND [Employee].[HideInReports] = 0
		GROUP BY
			[TimeEntry].[EmployeeID],
			[TimeEntry].[ProjectID]
	),
	[SummaryTask] ([ID], [SubCount]) AS
	(
		SELECT
			[Parent].[ID],
			COUNT([Child].[ID]) 
		FROM 
			[Task] AS [Parent] 
			LEFT OUTER JOIN [Task] AS [Child] 
				ON [Child].[ParentID] = [Parent].[ID]
		WHERE
			[Parent].[ProjectID] = @ProjectID
		GROUP BY
			[Parent].[ID]
	)
	--FIRST TABLE								
	INSERT INTO @ProductivityByEmployeeData 
	(	
		[EmployeeFileAs], 
		[QualificationFileAs],
	    [PlannedDuration], 
		[BillableDuration],
		[UnbillableDuration], 
		[CommonDuration],
		[Percent], 
		[Deviation],
	    [PercentDeviation]
	)
	SELECT 
		[Employee].[FileAs] AS [EmployeeFileAs],
		ISNULL([Qualification].[FileAs], '( )') AS [QualificationFileAs],
		SUM(ISNULL([BusyEntry].[Planned], 0)) / 60.0 AS [PlannedDuration],
		SUM(ISNULL([Time].[BillableDuration], 0)) / 60.0 AS [BillableDuration],
		SUM(ISNULL([Time].[UnbillableDuration], 0)) / 60.0 AS [UnbillableDuration],
		SUM(ISNULL([Time].[Duration], 0)) / 60.0 AS [CommonDuration],
		CASE 
			WHEN SUM(ISNULL([Time].[Duration], 0)) = 0 THEN null 
			ELSE SUM(ISNULL([Time].[BillableDuration], 0)) / 
					CAST(SUM(ISNULL([Time].[Duration], 0)) AS decimal(18,4))
			END AS [Percent],
		CASE 
			WHEN SUM(ISNULL([BusyEntry].[Planned], 0)) = 0 THEN null 
			ELSE (SUM(ISNULL([BusyEntry].[Planned], 0)) - SUM(ISNULL([Time].[Duration], 0))) / 60.0
			END AS [Deviation],
		CASE 
			WHEN SUM(ISNULL([BusyEntry].[Planned], 0)) = 0 THEN null 
			ELSE (SUM(ISNULL([BusyEntry].[Planned], 0)) - SUM(ISNULL([Time].[Duration], 0))) /
					CAST(SUM(ISNULL([BusyEntry].[Planned], 0)) AS decimal(18,4))
			END AS [PercentDeviation]
	FROM
		[Project]
			INNER JOIN [vwAssignment] AS [Assignment]						-->  (        )
				ON [Project].[ID] = [Assignment].[ProjectID]
			INNER JOIN [Employee]											-->    
				ON [Assignment].[EmployeeID] = [Employee].[ID]
			LEFT OUTER JOIN [Qualification]									-->    
				ON [Qualification].[ID] = [Assignment].[QualificationID]
			LEFT OUTER JOIN [TimeEntryTemp] AS [Time]
				ON [Employee].[ID] = [Time].[EmployeeID]
				AND [Project].[ID] = [Time].[ProjectID]
			LEFT OUTER JOIN 
					(SELECT
						[BusyEntry].[AssignmentID],
						SUM(ISNULL([BusyEntry].[Planned],0)) AS [Planned]
						FROM
							[Project]
							INNER JOIN [vwAssignment] AS [Assignment]
								ON [Project].[ID] = [Assignment].[ProjectID]
							LEFT OUTER JOIN [BusyEntry]
								ON [BusyEntry].[AssignmentID] = [Assignment].[ID]
										AND [BusyEntry].[Date] <= @Date
							LEFT OUTER JOIN [Task]
								ON [Task].[ID] = [BusyEntry].[TaskID]
						WHERE
							[Project].[ID] = @ProjectID
							AND [Task].[State] NOT IN (7, 8)
						GROUP BY
							[BusyEntry].[AssignmentID]	) AS [BusyEntry]
					ON [BusyEntry].[AssignmentID] = [Assignment].[ID]
	WHERE
		[Project].[ID] = @ProjectID
		AND
		(
			(
				@EmployeeTypeSelector = 0
				AND
				[Employee].[State] = 1
			)
			OR
			@EmployeeTypeSelector = 1
		)
		AND [Employee].[HideInReports] = 0
		--AND [Assignment].[State] = 1
	GROUP BY
		[Employee].[FileAs],
		[Qualification].[FileAs]
	ORDER BY (@Direction *
				CASE WHEN SUM(ISNULL([Time].[Duration], 0)) = 0 THEN 0 
				ELSE SUM(ISNULL([Time].[BillableDuration], 0)) / 
				CAST(SUM(ISNULL([Time].[Duration], 0)) AS decimal(18,4))
				END) DESC,
				[Employee].[FileAs] ASC

	;
	WITH TimeEntryTemp ([TaskID], [ProjectID], [Duration], 
						[BillableDuration], [UnbillableDuration]) AS
	(
		SELECT
			[TimeEntry].[TaskID],
			[TimeEntry].[ProjectID],
			SUM(ISNULL([TimeEntry].[Duration], 0)),
			SUM(ISNULL([BillableTime].[Duration], 0)),
			SUM(ISNULL([UnbillableTime].[Duration], 0))
		FROM
			[TimeEntry]
				LEFT OUTER JOIN [TimeEntry] AS [BillableTime]
					ON [TimeEntry].[ID] = [BillableTime].[ID]
						AND [BillableTime].[Billable] = 1
				LEFT OUTER JOIN [TimeEntry] AS [UnbillableTime]
					ON [TimeEntry].[ID] = [UnbillableTime].[ID]
						AND [UnbillableTime].[Billable] = 0
		WHERE
			CAST(CONVERT(VARCHAR(8), [TimeEntry].[StartTime], 112) AS DATETIME) <= @Date
			AND [TimeEntry].[State] IN (2, 3, 6)
			AND [TimeEntry].[ProjectID] = @ProjectID
		GROUP BY
			[TimeEntry].[TaskID],
			[TimeEntry].[ProjectID]
	),
	[SummaryTask] ([ID], [SubCount]) AS
	(
		SELECT
			[Parent].[ID],
			COUNT([Child].[ID]) 
		FROM 
			[Task] AS [Parent] 
			LEFT OUTER JOIN [Task] AS [Child] 
				ON [Child].[ParentID] = [Parent].[ID]
		WHERE
			[Parent].[ProjectID] = @ProjectID
		GROUP BY
			[Parent].[ID]
	)

	--SECOND TABLE
	INSERT INTO @ProductivityByTaskData
	(
		[TaskFileAs], 
		[PlannedDuration], 
		[BillableDuration], 
		[UnbillableDuration], 
		[Duration],
		[Percent],
		[Deviation],
		[PercentDeviation]
	)
	SELECT
		ISNULL(
			CASE WHEN
				[Task].[SubprojectID] IS NULL
				THEN
					[Task].[FileAs]
				ELSE
					[SubProject].[FileAs]
			END, '( )') AS [TaskFileAs],
		SUM(ISNULL([BusyEntry].[Planned],0)) / 60.0 AS [PlannedDuration],
		SUM(ISNULL([Time].[BillableDuration],0)) / 60.0 AS [BillableDuration] ,
		SUM(ISNULL([Time].[UnbillableDuration],0)) / 60.0 AS [UnbilladleDuration],
		SUM(ISNULL([Time].[Duration],0)) / 60.0 AS [Duration],
		CASE
			WHEN SUM(ISNULL([Time].[Duration],0)) = 0 THEN null
			ELSE SUM(ISNULL([Time].[BillableDuration],0)) / 
			CAST(SUM(ISNULL([Time].[Duration], 0)) AS decimal(18,4))
			END AS [Percent],
		CASE 
			WHEN SUM(ISNULL([BusyEntry].[Planned], 0)) = 0 THEN null 
			ELSE(SUM(ISNULL([BusyEntry].[Planned], 0)) - SUM(ISNULL([Time].[Duration], 0))) / 60.0
			END AS [Deviation],
		CASE 
			WHEN SUM(ISNULL([BusyEntry].[Planned], 0)) = 0 THEN null 
			ELSE (SUM(ISNULL([BusyEntry].[Planned], 0)) - SUM(ISNULL([Time].[Duration], 0))) /
					CAST(SUM(ISNULL([BusyEntry].[Planned], 0)) AS decimal(18,4))
			END AS [PercentDeviation]
	FROM
		[Project]
			LEFT OUTER JOIN [Task]
				ON [Task].[ProjectID] = [Project].[ID]
					AND [Task].[State] NOT IN (7, 8)
			LEFT OUTER JOIN [Project] AS [SubProject]
				ON [SubProject].[ID] = [Task].[SubprojectID]
			LEFT OUTER JOIN 
					(SELECT 
						[BusyEntry].[TaskID],
						SUM(ISNULL([BusyEntry].[Planned],0)) AS [Planned]
					FROM
						[Project]
						LEFT OUTER JOIN [Task]
							ON [Task].[ProjectID] = [Project].[ID]
						LEFT OUTER JOIN [BusyEntry]
							ON [BusyEntry].[TaskID] = [Task].[ID]
							AND [BusyEntry].[Date] <= @Date
					WHERE
						[Project].[ID] = @ProjectID
					GROUP BY
					[BusyEntry].[TaskID]) AS [BusyEntry]
				ON [BusyEntry].[TaskID] = [Task].[ID]
			LEFT OUTER JOIN [TimeEntryTemp] AS [Time]
				ON ([Time].[TaskID] = [Task].[ID]
					OR [Time].[TaskID] IS NULL AND [Task].[ID] IS NULL AND [Time].[ProjectID] = [Project].[ID])
			INNER JOIN [SummaryTask] ON
			(
				[Task].[ID] = [SummaryTask].[ID]
				AND
				[SummaryTask].[SubCount] = 0
			)
	WHERE
		[Project].[ID] = @ProjectID
	GROUP BY
		CASE WHEN
			[Task].[SubprojectID] IS NULL
			THEN
				[Task].[FileAs]
			ELSE
				[SubProject].[FileAs]
		END
	ORDER BY (@Direction*
			CASE WHEN SUM(ISNULL([Time].[Duration], 0)) = 0 THEN 0 
			ELSE SUM(ISNULL([Time].[BillableDuration], 0)) / 
			CAST(SUM(ISNULL([Time].[Duration], 0)) AS decimal(18,4))
			END) DESC,
			[TaskFileAs] ASC
	SELECT
		@UserName AS [UserName],
		@ProjectNumber AS [ProjectNamber],
		@Date AS [Date],
		(CASE WHEN @CountSelector = 3 THEN ''
			WHEN @CountSelector = 0 THEN ('5'+@Productivity)
			WHEN @CountSelector = 1 THEN ('10'+@Productivity)
			WHEN @CountSelector = 2 THEN (CAST(@UserCount AS varchar(10))+@Productivity)
			END) AS [Count]

		

IF @CountSelector = 3
BEGIN
	SELECT * 
	FROM @ProductivityByEmployeeData AS [This]
	WHERE [This].[PlannedDuration] <> 0 OR [This].[CommonDuration] <> 0

	SELECT *
	FROM @ProductivityByTaskData
END
ELSE
BEGIN
	SELECT TOP(CASE @CountSelector WHEN 0 THEN 5
								   WHEN 1 THEN 10 
								   WHEN 2 THEN @UserCount
			   END) *
	FROM @ProductivityByEmployeeData AS [This]
	WHERE [This].[PlannedDuration] <> 0 OR [This].[CommonDuration] <> 0

	SELECT TOP(CASE @CountSelector WHEN 0 THEN 5
								   WHEN 1 THEN 10 
								   WHEN 2 THEN @UserCount
			   END) *
	FROM @ProductivityByTaskData
END

RETURN 0
GO

GRANT EXEC ON ReportProductivityByProject TO PUBLIC

GO