IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'ReportProjectBudgetExecution')
	BEGIN
		PRINT 'Dropping Procedure ReportProjectBudgetExecution'
		DROP  Procedure  ReportProjectBudgetExecution
	END

GO

PRINT 'Creating Procedure ReportProjectBudgetExecution'
GO

/******************************************************************************
**		File: ReportProjectBudgetExecution.sql
**		Name: ReportProjectBudgetExecution
**
**         
**		Return values:
**
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**      14.08.2013	BAO				  [DeviationHours] 
									[DeviationMoney]   
**		22.07.2014	BAO				 ,    
**									"  "
**		26.09.2014	BAO				   
*******************************************************************************/
CREATE Procedure ReportProjectBudgetExecution
	@ProjectSelector	int,
	@ActiveProjectID	TIdentifier,
	@NotActiveProjectID TIdentifier,
	@DateSelector	int,
	@PeriodStart	TDate,
	@PeriodEnd		TDate	
AS
	SET NOCOUNT ON
	

	IF @ProjectSelector = 0 AND @ActiveProjectID IS NULL
	BEGIN
		RAISERROR('#ProjectIsNotSelected', 16, -1)
		RETURN 1
	END
	
	IF @ProjectSelector = 1 AND @NotActiveProjectID IS NULL
	BEGIN
		RAISERROR('#ProjectIsNotSelected', 16, -1)
		RETURN 1
	END
	
	DECLARE 
		@ProjectID TIdentifier		
		
	SET @ProjectID = CASE @ProjectSelector
			WHEN 0 THEN @ActiveProjectID
			WHEN 1 THEN @NotActiveProjectID
			END	
	
	DECLARE
		@DayCount		int,
		@TodayDate		datetime
	
	SET @TodayDate = CAST(CONVERT(varchar(8), GETDATE(), 112) AS DATETIME)	
	SET @DayCount = DATEPART(day, GETDATE())
	SET @PeriodStart = CASE	@DateSelector
		WHEN 0 THEN CAST(CONVERT(varchar(8), DATEADD(day, 1-@DayCount, GETDATE()), 112) AS datetime)
		WHEN 1 THEN CAST(CONVERT(varchar(8), DATEADD(month, -1, DATEADD(day, 1-@DayCount, GETDATE())), 112) AS datetime)
		ELSE CAST(CONVERT(varchar(8), @PeriodStart, 112) AS datetime)
	END
	SET @PeriodEnd = CASE @DateSelector
		WHEN 0 THEN DATEADD(day, 1, @TodayDate)
		WHEN 1 THEN DATEADD(day, -1, DATEADD(month, 1, @PeriodStart))
		ELSE CAST(CONVERT(varchar(8), @PeriodEnd, 112) AS datetime)		
	END
	
	DECLARE @time TABLE (
		[ProjectID] int,
		[AssignmentID] int,
		[EmployeeID] int,
		[Duration] decimal(18, 4),
		[Money] money
		)
	INSERT INTO @time ([ProjectID], [AssignmentID], [EmployeeID], [Duration], [Money])
	SELECT 
		@ProjectID,
		[AssignmentID],
		[EmployeeID],
		SUM([BillableDuration]) / 60.0,
		CASE
			WHEN (([Project].[RatesWithVAT] = 1) AND ([Project].[ApplyVAT] = 1))
			THEN SUM([BillableDuration] * ([Rate] / (1 + [vwTimeEntry].[VATRate])) * [vwTimeEntry].[Billable]) / 60.0
			ELSE SUM([BillableDuration] * [Rate] * [vwTimeEntry].[Billable]) / 60.0
		END AS [Money]
	FROM
		[vwTimeEntry]
		INNER JOIN [Employee]
			ON [vwTimeEntry].[EmployeeID] = [Employee].[ID]
		LEFT JOIN [Project]
			ON [Project].[ID] = [vwTimeEntry].[ProjectID]
	WHERE
		[ProjectID] = @ProjectID AND
		[vwTimeEntry].[State] IN (2, 3, 6) AND
		CAST(CONVERT(varchar(8), [StartTime], 112) AS datetime) BETWEEN @PeriodStart AND @PeriodEnd AND
		[Employee].[HideInReports] = 0
	GROUP BY
		[AssignmentID],
		[EmployeeID],
		[Project].[RatesWithVAT],
		[Project].[ApplyVAT]
		
	DECLARE @busy TABLE (
		[ProjectID] int,
		[AssignmentID] int,
		[EmployeeID] int,
		[PlanHours] decimal(18, 4),
		[PlanMoney] money
		)
	INSERT INTO @busy ([ProjectID], [AssignmentID], [EmployeeID], [PlanHours], [PlanMoney])
	SELECT
		@ProjectID,
		[BusyEntry].[AssignmentID],
		[BusyEntry].[EmployeeID],
		ROUND(ISNULL((SUM([BusyEntry].[Planned] - [BusyEntry].[Canceled]) / 60.0), 0), 1),
		ISNULL(SUM(([BusyEntry].[Planned] - [BusyEntry].[Canceled]) * [Assignment].[StandardRate]) / 60.0, 0)
	FROM
		[BusyEntry]
		INNER JOIN [Task]
			ON [Task].[ID] = [BusyEntry].[TaskID] AND [Task].[State] IN (8, 2, 3, 5)
		INNER JOIN [Assignment]
			ON [Assignment].[ID] = [BusyEntry].[AssignmentID]
		INNER JOIN [Employee]
			ON [BusyEntry].[EmployeeID] = [Employee].[ID]
	WHERE
		[BusyEntry].[ProjectID] = @ProjectID AND
		[BusyEntry].[EmployeeID] IS NOT NULL AND
		[BusyEntry].[Date] BETWEEN @PeriodStart AND @PeriodEnd AND
		[Employee].[HideInReports] = 0
	GROUP BY
		[BusyEntry].[AssignmentID],
		[BusyEntry].[EmployeeID]
	
	DECLARE @result TABLE (
		[ProjectID] int,
		[AssignmentID] int,
		[EmployeeID] int,
		[FactHours] decimal(18, 4),
		[FactMoney] money,
		[PlanHours] decimal(18, 4),
		[PlanMoney] money,
		[DeviationHours] decimal(18, 4),
		[DeviationMoney] money
		)
	INSERT INTO @result ([ProjectID], [AssignmentID], [EmployeeID], [FactHours], [FactMoney], [PlanHours], [PlanMoney], [DeviationHours], [DeviationMoney])
	SELECT [ProjectID], [AssignmentID], [EmployeeID], NULL,NULL,0,0,NULL,NULL FROM @time
	UNION
	SELECT [ProjectID], [AssignmentID], [EmployeeID], NULL,NULL,0,0,NULL,NULL FROM @busy
	
	UPDATE
		@result
	SET
		[PlanHours] = ISNULL([Busy].[PlanHours], 0),
		[PlanMoney] = ISNULL([Busy].[PlanMoney], 0)
	FROM 
		@result AS [Result]
		INNER JOIN @busy AS [Busy]
			ON ([Busy].[ProjectID] = [Result].[ProjectID] AND
				[Busy].[AssignmentID] = [Result].[AssignmentID] AND
				[Busy].[EmployeeID] = [Result].[EmployeeID])
				
	UPDATE
		@result
	SET
		[FactHours] = ROUND([Time].[Duration], 1),
		[FactMoney] = [Time].[Money]
	FROM 
		@result AS [Result]
		INNER JOIN @time AS [Time]
			ON ([Time].[ProjectID] = [Result].[ProjectID] AND
				[Time].[AssignmentID] = [Result].[AssignmentID] AND
				[Time].[EmployeeID] = [Result].[EmployeeID])

	EXECUTE ReportProjectBudgetExecutionHeader @ProjectID, @PeriodStart, @PeriodEnd, @DateSelector 
	SELECT
		[Result].[ProjectID] AS [ProjectID],
		[Employee].[FileAs] + ISNULL(' (' + [Qualification].[FileAs] +')', '') AS [AssignmentName],
		[Result].[FactHours],
		[Result].[FactMoney],
		[Result].[PlanHours],
		[Result].[PlanMoney],
		CASE 
			WHEN SUM(ISNULL([Result].[PlanHours], 0)) = 0 THEN null 
			ELSE SUM(ISNULL([Result].[FactHours], 0)) - SUM(ISNULL([Result].[PlanHours], 0))
		END AS [DeviationHours],
		CASE
			WHEN SUM(ISNULL([Result].[PlanMoney], 0)) = 0 THEN NULL
			ELSE SUM(ISNULL([Result].[FactMoney], 0)) - SUM(ISNULL([Result].[PlanMoney], 0))
		END AS [DeviationMoney]
	FROM
		@result AS [Result]
		LEFT OUTER JOIN [Employee]
			ON [Employee].[ID] = [Result].[EmployeeID]
		LEFT OUTER JOIN [Assignment]
			ON [Assignment].[ID] = [Result].[AssignmentID]
		LEFT OUTER JOIN [Qualification]
			ON [Qualification].[ID] = [Assignment].[QualificationID]
	WHERE
		[Result].[ProjectID] = @ProjectID 	
	GROUP BY
		[Result].[ProjectID],
		[Qualification].[FileAs],
		[Employee].[FileAs],
		[Result].[FactHours],
		[Result].[FactMoney],
		[Result].[PlanHours],
		[Result].[PlanMoney],
		[Result].[DeviationMoney]

RETURN 0
GO

GRANT EXEC ON ReportProjectBudgetExecution TO PUBLIC

GO