IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm5TaskBrowseTimeLineByAssignment]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
BEGIN
	PRINT 'Dropping procedure pjm5TaskBrowseTimeLineByAssignment'
	DROP PROCEDURE [dbo].[pjm5TaskBrowseTimeLineByAssignment]
END
GO

PRINT 'Creating procedure pjm5TaskBrowseTimeLineByAssignment'
GO

/******************************************************************************
**		File: pjm5TaskBrowseTimeLineByAssignment.sql
**		Name: pjm5TaskBrowseTimeLineByAssignment
**		Desc: this procedure automatically generated by Avicom.Adf.Generator
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: Andrew.Maklakov
**		Date: 01/20/2005 13:49:21
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**    
*******************************************************************************/
CREATE PROCEDURE [pjm5TaskBrowseTimeLineByAssignment]
	@PeriodStart	datetime = NULL,
	@PeriodEnd		datetime = NULL,
	@AssignmentID	TIdentifier,
	@StateSelector  int
AS
	SET NOCOUNT ON
	DECLARE
		@today datetime,
		@value TVariant,
		@p TCount,
		@ViewAllFinance TBool,
		@CurrentEmployeeID TIdentifier

	SET @today = GETDATE()
	SET @CurrentEmployeeID = dbo.adfGetCurrentEmployeeID()
	SET @ViewAllFinance = dbo.adfHasAccessRight(dbo.adfGetRightID('ViewAllFinance'))
	
	SELECT
		[Task].[Class],
		[Task].[ID],
		[Task].[State],
		[Task].[Flag],
		[Task].[FileAs],
		[Task].[ProjectID],
		[Task].[PriorityID],
		[Task].[ParentID],
		[Task].[StartDate],
		[Task].[DueDate],
		DATEADD(hour, 24, [Task].[DueDate]) as [DueDateTL],
		[Task].[EndDate],
		[Task].[Duration],
		[Task].[PercentComplete],
		[Task].[Milestone],
		[Task].[Comments],
		[Task].[Created],
		[Task].[CreatedBy],
		[Task].[Modified],
		[Task].[ModifiedBy],
		[Task].[Timestamp],
		[Project].[Number] AS [Project],
		[Priority].[FileAs] AS [Priority],
		CAST([Task].[Milestone] as tinyint) as M,
		(CAST([Task].[PercentComplete] * 100 as int) / 25) * 25 as PC,
		(SELECT COUNT([Sub].[ID]) FROM [Task] AS [Sub] WHERE [Sub].[ParentID] = [Task].[ID] ) AS [SubCount]
	FROM
		[Task]
		INNER JOIN [Project]
			ON [Task].[ProjectID] = [Project].[ID]
		INNER JOIN [Priority]
			ON [Priority].[ID] = [Task].[PriorityID]
		INNER JOIN [TaskAssignment]
			ON [TaskAssignment].[TaskID] = [Task].[ID]
		INNER JOIN [Assignment]
			ON [TaskAssignment].[AssignmentID] = [Assignment].[ID]
	WHERE
		[Assignment].[ID] = @AssignmentID 
		AND
		(@PeriodStart IS NULL OR (@PeriodStart IS NOT NULL AND [Task].[DueDate] >= @PeriodStart)) 
		AND
		(@PeriodEnd IS NULL OR (@PeriodEnd IS NOT NULL AND [Task].[StartDate] < @PeriodEnd)) 
		AND
		([Task].[State] <> 7) 
		AND
		(
			@StateSelector = 0 OR (@StateSelector = 1 AND [Task].[State] IN (1,2,8))
		)

	RETURN 0
GO

GRANT EXECUTE ON [pjm5TaskBrowseTimeLineByAssignment] TO PUBLIC
GO

IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm5TaskBrowseTimeLineByEmployee]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
BEGIN
	PRINT 'Dropping procedure pjm5TaskBrowseTimeLineByEmployee'
	DROP PROCEDURE [dbo].[pjm5TaskBrowseTimeLineByEmployee]
END
GO

PRINT 'Creating procedure pjm5TaskBrowseTimeLineByEmployee'
GO

/******************************************************************************
**		File: pjm5TaskBrowseTimeLineByEmployee.sql
**		Name: pjm5TaskBrowseTimeLineByEmployee
**		Desc: this procedure automatically generated by Avicom.Adf.Generator
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: Andrew.Maklakov
**		Date: 01/20/2005 13:49:21
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**    
*******************************************************************************/
CREATE PROCEDURE [pjm5TaskBrowseTimeLineByEmployee]
	@PeriodStart	datetime = NULL,
	@PeriodEnd		datetime = NULL,
	@EmployeeID		TIdentifier,
	@StateSelector  int
AS
	SET NOCOUNT ON
	DECLARE
		@ViewAllTasks bit,
		@today datetime,
		@ViewAllFinance TBool,
		@CurrentEmployeeID TIdentifier
		
	SET @today = GETDATE()
	SET @CurrentEmployeeID = dbo.adfGetCurrentEmployeeID()
	SET @ViewAllFinance = dbo.adfHasAccessRight(dbo.adfGetRightID('ViewAllFinance'))
	SET @ViewAllTasks = dbo.adfHasAccessRight(dbo.adfGetRightID('ViewAllTasks'))
	
	SELECT
		[Task].[Class],
		[Task].[ID],
		[Task].[State],
		[Task].[Flag],
		[Task].[FileAs],
		[Task].[ProjectID],
		[Task].[PriorityID],
		[Task].[ParentID],
		[Task].[StartDate],
		[Task].[DueDate],
		DATEADD(hour, 24, [Task].[DueDate]) as [DueDateTL],
		[Task].[EndDate],
		[Task].[Duration],
		[Task].[PercentComplete],
		[Task].[Milestone],
		[Task].[Comments],
		[Task].[Created],
		[Task].[CreatedBy],
		[Task].[Modified],
		[Task].[ModifiedBy],
		[Task].[Timestamp],
		[Project].[Number] AS [Project],
		[Priority].[FileAs] AS [Priority],
		CAST([Task].[Milestone] as tinyint) as M,
		(CAST([Task].[PercentComplete] * 100 as int) / 25) * 25 as PC,
		(SELECT COUNT([Sub].[ID]) FROM [Task] AS [Sub] WHERE [Sub].[ParentID] = [Task].[ID] ) AS [SubCount]
	FROM
		[Task]
		INNER JOIN [Project]
			ON [Task].[ProjectID] = [Project].[ID]
		INNER JOIN [Priority]
			ON [Priority].[ID] = [Task].[PriorityID]
	WHERE
		(@PeriodStart IS NULL OR (@PeriodStart IS NOT NULL AND [Task].[DueDate] >= @PeriodStart)) 
		AND
		(@PeriodEnd IS NULL OR (@PeriodEnd IS NOT NULL AND [Task].[StartDate] < @PeriodEnd)) 
		AND
		([Task].[State] <>7) AND
		(
			@StateSelector = 0 OR
			(@StateSelector = 1 AND [Task].[State] IN (1,2,8))
		) AND
		(
		EXISTS (
			SELECT * 
			FROM
				[TaskAssignment]
				INNER JOIN [vwAssignment] AS [Assignment]
					ON [TaskAssignment].[AssignmentID] = [Assignment].[ID]
			WHERE
				[TaskAssignment].[TaskID] = [Task].[ID] AND
				[Assignment].[EmployeeID] = @EmployeeID
			)
		) AND
		(
			@ViewAllTasks = 1 OR
			[Project].[ProjectManagerEmployeeID] = @CurrentEmployeeID OR
			dbo.fnPjm5IsProjectMember([Task].[ProjectID], @CurrentEmployeeID) = 1
		)

	RETURN 0
GO

GRANT EXECUTE ON [pjm5TaskBrowseTimeLineByEmployee] TO PUBLIC
GO

IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm5TaskBrowseTimeLineByProject]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
BEGIN
	PRINT 'Dropping procedure pjm5TaskBrowseTimeLineByProject'
	DROP PROCEDURE [dbo].[pjm5TaskBrowseTimeLineByProject]
END
GO

PRINT 'Creating procedure pjm5TaskBrowseTimeLineByProject'
GO

/******************************************************************************
**		File: pjm5TaskBrowseTimeLineByProject.sql
**		Name: pjm5TaskBrowseTimeLineByProject
**		Desc: this procedure automatically generated by Avicom.Adf.Generator
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: Andrew.Maklakov
**		Date: 01/20/2005 13:49:21
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**    
*******************************************************************************/
CREATE PROCEDURE [pjm5TaskBrowseTimeLineByProject]
	@PeriodStart	datetime = NULL,
	@PeriodEnd		datetime = NULL,
	@StateSelector  int,
	@ProjectID		TIdentifier,
	@Milestone		int
AS
	SET NOCOUNT ON
	
	DECLARE @today datetime,
		@ViewAllFinance TBool,
		@CurrentEmployeeID TIdentifier
		
	SET @today = GETDATE()
	SET @CurrentEmployeeID = dbo.adfGetCurrentEmployeeID()
	SET @ViewAllFinance = dbo.adfHasAccessRight(dbo.adfGetRightID('ViewAllFinance'))

	SELECT
		[Task].[Class],
		[Task].[ID],
		[Task].[State],
		[Task].[Flag],
		[Task].[FileAs],
		[Task].[ProjectID],
		[Task].[PriorityID],
		[Task].[ParentID],
		[Task].[StartDate],
		[Task].[DueDate],
		DATEADD(hour, 24, [Task].[DueDate]) as [DueDateTL],
		[Task].[EndDate],
		[Task].[Duration],
		[Task].[PercentComplete],
		[Task].[Milestone],
		[Task].[Comments],
		[Task].[Created],
		[Task].[CreatedBy],
		[Task].[Modified],
		[Task].[ModifiedBy],
		[Task].[Timestamp],
		[Project].[FileAs] AS [Project],
		[Priority].[FileAs] AS [Priority],
		CAST([Task].[Milestone] as tinyint) as M,
		(CAST([Task].[PercentComplete] * 100 as int) / 25) * 25 as PC,
		[Class].[Guid],
		(SELECT COUNT([Sub].[ID]) FROM [Task] AS [Sub] WHERE [Sub].[ParentID] = [Task].[ID] ) AS [SubCount]
	FROM
		[Task]
		INNER JOIN [Project]
			ON [Task].[ProjectID] = [Project].[ID]
		INNER JOIN [Priority]
			ON [Priority].[ID] = [Task].[PriorityID]
		INNER JOIN [Class]
			ON [Task].[Class] = [Class].[Class]
	WHERE
		(@PeriodStart IS NULL OR (@PeriodStart IS NOT NULL AND [Task].[DueDate] >= @PeriodStart)) 
		AND
		(@PeriodEnd IS NULL OR (@PeriodEnd IS NOT NULL AND [Task].[StartDate] < @PeriodEnd)) 
		AND
		([Project].[ID] = @ProjectID) 
		AND
		(
			@StateSelector = 0 OR (@StateSelector = 1 AND [Task].[State] IN (1,2,8))
		) 
		AND
		(
			ISNULL(@Milestone, 0) != 1 OR [Task].[Milestone] = 1
		)AND [Task].[SubprojectID] IS NULL
		UNION ALL
		SELECT
			[Project].[Class],
			[Project].[ID],
			[Project].[State],
			[Project].[Flag],
			[Project].[FileAs],
			[Project].[ID],
			[Project].[PriorityID],
			[Task].[ProjectID],
			[Project].[Date],
			[ProjectDetail].[DueDate],
			DATEADD(hour, 24, [ProjectDetail].[DueDate]) as [DueDateTL],
			[Project].[EndDate],
			dbo.fnPjm5GetWorkingDays([Project].[Date],[ProjectDetail].[DueDate]) AS [Duration],
			[ProjectDetail].[PercentComplete],
			0,--[Task].[Milestone],
			[Project].[Comments],
			[Project].[Created],
			[Project].[CreatedBy],
			[Project].[Modified],
			[Project].[ModifiedBy],
			[Project].[Timestamp],
			[Project].[FileAs] AS [Project],
			[Priority].[FileAs] AS [Priority],
			CAST(0 as tinyint) as M,
			(CAST([ProjectDetail].[PercentComplete] * 100 as int) / 25) * 25 as PC,
			[Class].[Guid],
			0 AS [SubCount]
		FROM 
			[Project]
			INNER JOIN [ProjectDetail]
				ON [ProjectDetail].[ID] = [Project].[ID]
			INNER JOIN [Priority]
				ON [Priority].[ID] = [Project].[PriorityID]
			INNER JOIN [Class]
				ON [Class].[Class] = [Project].[Class]
			INNER JOIN [Task]
				ON [Task].[SubprojectID] = [Project].[ID]
		WHERE 
			[Task].[ProjectID] = @ProjectID AND
			(@PeriodStart IS NULL OR 
			(@PeriodStart IS NOT NULL AND [ProjectDetail].[DueDate] >= @PeriodStart)) 
			AND
			(@PeriodEnd IS NULL OR (@PeriodEnd IS NOT NULL AND [Project].[Date] < @PeriodEnd)) AND
			(
				@StateSelector = 0 OR (@StateSelector = 1 AND [Project].[State] IN (1,2))
			) 
			AND
			(
				ISNULL(@Milestone, 0) != 1
			)

	RETURN 0
GO

GRANT EXECUTE ON [pjm5TaskBrowseTimeLineByProject] TO PUBLIC
GO


IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm5TaskBrowseTimeLine]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure pjm5TaskBrowseTimeLine'
		DROP PROCEDURE [dbo].[pjm5TaskBrowseTimeLine]
	END
GO

PRINT 'Creating procedure pjm5TaskBrowseTimeLine'
GO

/******************************************************************************
**		File: pjm5TaskBrowseTimeLine.sql
**		Name: pjm5TaskBrowseTimeLine
**		Desc: this procedure automatically generated by Avicom.Adf.Generator
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: Andrew.Maklakov
**		Date: 01/20/2005 13:49:21
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**    
*******************************************************************************/
CREATE PROCEDURE [pjm5TaskBrowseTimeLine]
	@StateSelector	INT,
	@PeriodStart	datetime = NULL,
	@PeriodEnd		datetime = NULL,
	@Milestone		int
AS
	SET NOCOUNT ON
	DECLARE
		@ViewAllTasks bit,
		@today datetime,
		@ViewAllFinance TBool,
		@CurrentEmployeeID TIdentifier
		
	SET @today = GETDATE()
	SET @CurrentEmployeeID = dbo.adfGetCurrentEmployeeID()
	SET @ViewAllFinance = dbo.adfHasAccessRight(dbo.adfGetRightID('ViewAllFinance'))
	SET @ViewAllTasks = dbo.adfHasAccessRight(dbo.adfGetRightID('ViewAllTasks'))

	SELECT
		[Task].[Class],
		[Task].[ID],
		[Task].[State],
		[Task].[Flag],
		[Task].[FileAs],
		[Task].[ProjectID],
		[Task].[PriorityID],
		[Task].[ParentID],
		[Task].[StartDate],
		[Task].[DueDate],
		DATEADD(hour, 24, [Task].[DueDate]) as [DueDateTL],
		[Task].[EndDate],
		[Task].[Duration],
		[Task].[PercentComplete],
		[Task].[Milestone],
		[Task].[Comments],
		[Task].[Created],
		[Task].[CreatedBy],
		[Task].[Modified],
		[Task].[ModifiedBy],
		[Task].[Timestamp],
		[Project].[Number] AS [Project],
		[Priority].[FileAs] AS [Priority],
		CAST([Task].[Milestone] as tinyint) as M,
		(CAST([Task].[PercentComplete] * 100 as int) / 25) * 25 as PC,
		(SELECT COUNT([Sub].[ID]) FROM [Task] AS [Sub] WHERE [Sub].[ParentID] = [Task].[ID] ) AS [SubCount]
	FROM
		[Task]
		INNER JOIN [Project]
			ON [Task].[ProjectID] = [Project].[ID]
		INNER JOIN [Priority]
			ON [Priority].[ID] = [Task].[PriorityID]
	WHERE
		(@PeriodStart IS NULL OR (@PeriodStart IS NOT NULL AND [Task].[DueDate] >= @PeriodStart)) 
		AND
		(@PeriodEnd IS NULL OR (@PeriodEnd IS NOT NULL AND [Task].[StartDate] < @PeriodEnd)) 
		AND
		([Task].[State] <>7) 
		AND
		(
			@StateSelector = 0 OR (@StateSelector = 1 AND [Task].[State] IN (1, 2, 8))
		) 
		AND
		(
			ISNULL(@Milestone, 0) != 1 OR [Task].[Milestone] = 1
		) 
		AND
		(
			@ViewAllTasks = 1 OR 
			[Project].[ProjectManagerEmployeeID] = @CurrentEmployeeID OR
			dbo.fnPjm5IsProjectMember([Project].[ID], @CurrentEmployeeID) = 1		
		)
	RETURN 0
GO

GRANT EXECUTE ON [pjm5TaskBrowseTimeLine] TO PUBLIC
GO
