IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm6TaskConvertToTaskRequest]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure pjm6TaskConvertToTaskRequest'
		DROP PROCEDURE [dbo].[pjm6TaskConvertToTaskRequest]
	END
GO

PRINT 'Creating procedure pjm6TaskConvertToTaskRequest'
GO

/******************************************************************************
**		File: pjm6TaskConvertToTaskRequest.sql
**		Name: pjm6TaskConvertToTaskRequest
**		Desc: 
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: Olga.Kuznetsova
**		Date: 29/03/2010 
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**
**		--------	--------		-------------------------------------------
**		30.03.2010	KOV				  , ,
**									,    
**		31.03.2010	KOV				   
**		01.04.2010	KOV				   ,  
**
*******************************************************************************/

CREATE PROCEDURE [pjm6TaskConvertToTaskRequest] WITH EXECUTE AS OWNER
AS
BEGIN
	DECLARE 
		@TaskID TIdentifier,
		@TaskRequestID TIdentifier,
		@Percent TPercent,
		@FlagValue TBool,
		@value TVariant,
		@State TState,
		@TaskClass TClass,
		@TaskRequestClass TClass,
		@TaskComments TNotes,
		@ManHour TCount,
		@ActualManHour TCount,
		@Hour TCount,
		@Budget TMoney,
		@ActualBudget TMoney,
		@EmployeeID TIdentifier,
		@TextNote TNotes
	SET @FlagValue = 1
	SET @Percent = 100

	--    MS Project
	IF EXISTS (SELECT [Project].[MSProjectID] FROM [Project] WHERE [Project].[MSProjectID] IS NOT NULL)
	BEGIN
		RAISERROR('#MSProjectIntegrationDetected', 18, -1)
		RETURN 1
	END
	
	--        
	EXEC adfParameterGet @Name='AdvancedTimeExpensesForm', @Group='Pjm5', @Value = @value OUTPUT
	IF (@Value <> @FlagValue)
	BEGIN
		RAISERROR('#TfaIsTurnedOff', 18, -1)
		RETURN 1
	END
	
	DECLARE TaskCursor CURSOR FOR
		SELECT
			[Task].[ID]
		FROM [Task]
		WHERE [Task].[State] IN (2,5,6,8)

	OPEN TaskCursor 


	--   
	SET @TaskRequestClass = dbo.adfGetClassByName('Pjm5.TaskRequest');
	SET @TaskClass = dbo.adfGetClassByName('Pjm5.Task');
	
	FETCH NEXT FROM TaskCursor INTO @TaskID

	WHILE @@FETCH_STATUS = 0
	BEGIN
		DECLARE @p1 XML
			SET @p1 =
				(SELECT 
					(SELECT 
						'-1' AS [ID],
						'1' AS [State],
						[Task].[Flag], 
						[Task].[FileAs], 
						[Task].[ProjectID], 
						[Task].[PriorityID],
						[Project].[ProjectManagerEmployeeID] AS [EmployeeID],
						[Task].[DueDate] AS [DueTime], 
						[Task].[StartDate] AS [StartTime], 
						[Task].[SendStatusReport],
						'1' AS [TaskRequestStatusID], 
						CAST((([Task].[PercentComplete])*@Percent) AS int) AS [PercentComplete],
						'false' AS [DocumentEditAccess],
						[Task].[Comments],
						(SELECT TOP (1) [Task].[Created] FROM [Task] WHERE [Task].[ID] = @TaskID) AS [Created],
						(SELECT TOP (1) [Task].[CreatedBy] FROM [Task] WHERE [Task].[ID] = @TaskID) AS[CreatedBy],
						'true' AS [ReminderState],
						'60' AS [ReminderInterval],
						'87a91fee-cef2-4262-9019-30f8c6effd9d' AS [Guid],
						'0' AS [ManHour], 
						'0.00' AS [ActualBudget],
						'0.00' AS [Budget],
						'0' AS [ActualManHour]
					FROM 
						[Task] 
						INNER JOIN [Project] ON [Task].[ProjectID]=[Project].[ID]
					WHERE [Task].[ID]=@TaskID
						FOR XML PATH('TaskRequest'),TYPE),
					
					(SELECT
						[vwAssignment].[EmployeeID] AS [EmployeeID],
						(SELECT
							CAST ((([Task].[PercentComplete])*@Percent) AS int)
						FROM 
							[Task] 
						WHERE 
							[Task].[ID]=@TaskID) 
						AS [PercentComplete],
						'false' AS [Accepted]
					FROM [vwAssignment]  
						INNER JOIN [TaskAssignment] ON [TaskAssignment].[AssignmentID] = [vwAssignment].[ID] 
					WHERE [TaskAssignment].[TaskID] = @TaskID
					FOR XML PATH('TaskRequestAssignment'),TYPE)
						
				FOR XML PATH('pjm5TaskRequestGet'),TYPE)
		
						
		--  xml     
		EXECUTE [pjm5TaskRequestCreate] @Xml=@p1;

		--  id  
		SET @TaskRequestID = IDENT_CURRENT('[TaskRequest]');
		
		IF ((select COUNT(*) from [TaskAssignment] WHERE [TaskAssignment].[TaskID] = @TaskID)!=0)
		BEGIN		
			SET @State = (SELECT TOP (1) [Task].[State] FROM [Task] WHERE [Task].[ID] = @TaskID)
	--		IF (@State = 8)
	--			EXECUTE [pjm5TaskRequestChangeState] @TaskRequestID, 1
			IF (@State = 2)
				EXECUTE [pjm5TaskRequestChangeState] @TaskRequestID, @State
			IF ((@State = 5) OR (@State = 6)) 
			BEGIN
				EXEC [pjm5TaskRequestChangeState] @TaskRequestID, 2;
				EXEC [pjm5TaskRequestChangeState] @TaskRequestID, 4;
			END
		END
		
	
		-- 
		DECLARE @p2 XML
			SET @p2 = 
				(SELECT 
					(SELECT 
						[DocumentContact].[BusinessCardID] AS [ID],
						[DocumentContact].[BusinessCardClass] AS [Class]
					FROM [DocumentContact]
					WHERE ([DocumentContact].[DocumentID] = @TaskID AND [DocumentContact].[DocumentClass] = @TaskClass)
					FOR XML PATH ('Item'),TYPE)
				FOR XML PATH ('List'),TYPE)
		EXECUTE [adfDocumentContactUpdate] @TaskRequestID, @TaskRequestClass, @XML = @p2
							
		--  
		DECLARE @NoteTable TABLE ([Text] TNotes, [DocumentID] TIdentifier)

		INSERT INTO @NoteTable (Text, DocumentID)
			SELECT
				[Note].[Text], @TaskRequestID
			FROM [Note]
			WHERE [Note].[DocumentID] = @TaskID AND [Note].[DocumentClass] = @TaskClass

		--    
		EXECUTE [adfNoteCreate] @TaskRequestClass, @TaskRequestID, '      '
				
			
		--     
		ALTER TABLE [TimeEntry] DISABLE TRIGGER ALL
		UPDATE [TimeEntry]
		SET  [TimeEntry].[TaskID] = NULL,
			 [TimeEntry].[DocumentID] = @TaskRequestID,
			 [TimeEntry].[DocumentClass] = @TaskRequestClass
		WHERE [TimeEntry].[TaskID]=@TaskID;
		ALTER TABLE [TimeEntry] ENABLE TRIGGER ALL

		--     
		ALTER TABLE [Expense] DISABLE TRIGGER ALL
		UPDATE [Expense]
		SET [Expense].[TaskID] = NULL,
			[Expense].[DocumentID] = @TaskRequestID,
			[Expense].[DocumentClass] = @TaskRequestClass
		WHERE [Expense].[TaskID]=@TaskID;
		ALTER TABLE [Expense] ENABLE TRIGGER ALL

		-- 
		INSERT INTO [Attachment]([DocumentClass], [DocumentID], [Name], [Value], [AttachmentTypeID])
		SELECT @TaskRequestClass, @TaskRequestID, [Attachment].[Name], [Attachment].[Value], [Attachment].[AttachmentTypeID]
		FROM [Attachment] 
		WHERE (([Attachment].[DocumentClass] = @TaskClass) AND ([Attachment].[DocumentID] = @TaskID))

		--  
		INSERT INTO [Attachment]
			(
			[DocumentClass], [DocumentID], [Name],
			[LinkDocumentClass], [LinkDocumentID], [AttachmentTypeID]
			)
		VALUES
			(
			@TaskRequestClass, @TaskRequestID, '',
			@TaskClass, @TaskID, 2	
			)
		--  
		INSERT INTO [Attachment]
			([DocumentClass], [DocumentID], [Name],[LinkDocumentClass], [LinkDocumentID], [AttachmentTypeID])
		VALUES
			(@TaskClass, @TaskID, '',@TaskRequestClass, @TaskRequestID, 2)
		

		--   
	
		SET @ActualManHour = 
		((SELECT SUM(Duration) 
		FROM [TimeEntry]
		WHERE (([TimeEntry].[DocumentID] = @TaskRequestID) AND ([TimeEntry].[DocumentClass] = @TaskRequestClass)AND ([TimeEntry].[State] != 1))
		GROUP BY [TimeEntry].[DocumentID]))
		
		SET @ActualBudget = 
			((SELECT 
				SUM([TimeEntry].[Rate]*[TimeEntry].[Duration]*[TimeEntry].[Billable])
			FROM
				[TimeEntry]
			WHERE
				(([TimeEntry].[DocumentClass] = @TaskRequestClass) AND ([TimeEntry].[DocumentID] = @TaskRequestID) AND ([TimeEntry].[State] != 1))
			GROUP BY
				[TimeEntry].[DocumentID])/60.0)
		IF (@ActualManHour IS NOT NULL) 
		BEGIN
		UPDATE
			[TaskRequest]
			SET	[TaskRequest].[ActualManHour] = @ActualManHour
		FROM [TaskRequest]
		WHERE [TaskRequest].[ID] = @TaskRequestID
		END
		IF (@ActualBudget IS NOT NULL)
		BEGIN
		UPDATE
			[TaskRequest]
			SET	[TaskRequest].[ActualBudget] = @ActualBudget
		FROM [TaskRequest]
		WHERE [TaskRequest].[ID] = @TaskRequestID
		END

		--  
		SET @ManHour = 
			(SELECT SUM([TaskAssignment].[Work]) 
			FROM [TaskAssignment] 
			WHERE [TaskAssignment].[TaskID] = @TaskID)
		IF (@ManHour IS NOT NULL)
		BEGIN
		UPDATE
			[TaskRequest]
			SET	[TaskRequest].[ManHour] = @ManHour
		FROM [TaskRequest]
		WHERE [TaskRequest].[ID] = @TaskRequestID
		END
		
		--SET @Hour = (SELECT [Task].[Duration] FROM [Task] WHERE [Task].[ID] = @TaskID)
		SET @Budget = 
		(SELECT SUM([TaskAssignment].[Work]*[Assignment].[StandardRate]/60.0)
		FROM [TaskAssignment] 
			INNER JOIN [Assignment] ON [TaskAssignment].[AssignmentID] = [Assignment].[ID]
		WHERE [TaskAssignment].[TaskID] = @TaskID)
	
		IF (@Budget IS NOT NULL)
		BEGIN
		UPDATE
			[TaskRequest]
			SET	[TaskRequest].[Budget] = @Budget
		FROM [TaskRequest]
		WHERE [TaskRequest].[ID] = @TaskRequestID
		END

		
		--  	
		SET @State = (SELECT [Task].[State] FROM [Task] WHERE [Task].[ID] = @TaskID)
		IF @State = 2
			EXEC [pjm5TaskChangeState] @TaskID, 3
		ELSE 
		BEGIN 
			EXEC [pjm5TaskChangeState] @TaskID, 2
			EXEC [pjm5TaskChangeState] @TaskID, 3
		END
				
		--    ( ,    (->)

		
		UPDATE [Task]
			SET [Task].[ModifiedBy] = (SELECT TOP (1) [Task].[CreatedBy] FROM [Task] WHERE [Task].[ID] = @TaskID AND [Task].[Class] = @TaskClass)
		FROM [Task]
		WHERE [Task].[ID] = @TaskID
		
		UPDATE
			[Document]
			SET [Document].[CreatedBy] = (SELECT TOP (1) [Task].[CreatedBy] FROM [Task] WHERE [Task].[ID] = @TaskID AND [Task].[Class] = @TaskClass),
				[Document].[ModifiedBy] = (SELECT TOP (1) [Task].[CreatedBy] FROM [Task] WHERE [Task].[ID] = @TaskID AND [Task].[Class] = @TaskClass)
		FROM [Document]
		WHERE (([Document].[ID] = @TaskRequestID AND [Document].[Class] = @TaskRequestClass) OR ([Document].[ID] = @TaskID AND [Document].[Class] = @TaskClass))
		
		
		UPDATE [TaskRequest]
			SET [TaskRequest].[CreatedBy] = (SELECT TOP (1) [Task].[CreatedBy] FROM [Task] WHERE [Task].[ID] = @TaskID AND [Task].[Class] = @TaskClass),
			[TaskRequest].[ModifiedBy] = (SELECT TOP (1) [Task].[CreatedBy] FROM [Task] WHERE [Task].[ID] = @TaskID AND [Task].[Class] = @TaskClass)
		FROM [TaskRequest]
		WHERE [TaskRequest].[ID] = @TaskRequestID
		
		UPDATE [transition]
			SET [transition].[UserID] = (SELECT TOP (1) [task].[createdBy] FROM [task] WHERE [task].[id] = @TaskID )
		FROM [transition]
		WHERE (([transition].[class] = @TaskClass and [transition].[documentid] = @TaskID) or([transition].[class] = @TaskRequestClass and [transition].[documentid] = @TaskRequestID))

				
		FETCH NEXT FROM TaskCursor INTO @TaskID

	END

	CLOSE TaskCursor

	DEALLOCATE TaskCursor
	
	--     
	DECLARE @RequestID TIdentifier
	DECLARE NoteCursor CURSOR FOR
		SELECT [Text], [DocumentID] FROM @NoteTable
	OPEN NoteCursor 
	FETCH NEXT FROM NoteCursor INTO @TextNote, @RequestID
	WHILE @@FETCH_STATUS = 0
	BEGIN
		EXECUTE [adfNoteCreate] @TaskRequestClass, @RequestID, @TextNote
		FETCH NEXT FROM NoteCursor INTO @TextNote, @RequestID
	END
	CLOSE NoteCursor
	DEALLOCATE NoteCursor


	--      	
	UPDATE
		[TransitionTemplate]
	SET 
		[TransitionTemplate].[RightID] = (SELECT [Right].[ID] FROM [Right] WHERE [Name]='NotUsed')
	WHERE 
		(([TransitionTemplate].[Class] = @TaskClass) AND
		([TransitionTemplate].[FromState] IS NULL) AND
		([TransitionTemplate].[ToState] = 8))
RETURN 

END	
		

GO

--GRANT EXECUTE ON pjm6TaskConvertToTaskRequest TO PUBLIC
--GO
--     
--EXEC [pjm6TaskConvertToTaskRequest]

