IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'TimeEntryOwnInDrafts')
	BEGIN
		PRINT 'Dropping Procedure TimeEntryOwnInDrafts'
		DROP  Procedure  TimeEntryOwnInDrafts
	END

GO

PRINT 'Creating Procedure TimeEntryOwnInDrafts'
GO
/******************************************************************************
**		File: 
**		Name: TimeEntryOwnInDrafts
**		Desc: 
**
**		This template can be customized:
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth:	Nikita.Golyshev
**		Date:	03.10.2014
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
*******************************************************************************/
CREATE Procedure TimeEntryOwnInDrafts
AS
	SET NOCOUNT ON
	DECLARE
		@CurrentEmployeeID TIdentifier

	SET @CurrentEmployeeID = dbo.adfGetCurrentEmployeeID()

	DECLARE
		@ParameterValue sql_variant,
		@BillableHoursStyle int
				
	EXEC dbo.[adfParameterGet] @Name='BillableHoursStyle', @Group='Pjm7', @Value=@ParameterValue OUTPUT
	SET @BillableHoursStyle = 
		CASE
			WHEN @ParameterValue IS NULL OR @ParameterValue = 0 THEN 0
			ELSE 1
		END

	SELECT
		[TimeEntry].[Class],
		[TimeEntry].[ID],
		[TimeEntry].[State],
		[TimeEntry].[Flag],
		[TimeEntry].[FileAs],
		[TimeEntry].[ActivityTypeID],
		[TimeEntry].[EmployeeID],
		[TimeEntry].[ProjectID],
		[TimeEntry].[TaskID],
		[TimeEntry].[StartTime],
		[TimeEntry].[Duration],
		[TimeEntry].[RoundedDuration],
		[TimeEntry].[Billable],
		[TimeEntry].[Overtime],
		[TimeEntry].[CurrencyCode],
		[TimeEntry].[VATRate],
		[TimeEntry].[Color],
		[TimeEntry].[Comments],
		[TimeEntry].[Created],
		[TimeEntry].[CreatedBy],
		[TimeEntry].[Modified],
		[TimeEntry].[ModifiedBy],
		[TimeEntry].[Timestamp],
		CASE
			WHEN [TimeEntry].[TaskID] IS NULL
				THEN (SELECT TOP(1) [DocumentClassName] FROM adfGetDocumentIdentity([TimeEntry].[DocumentID], [TimeEntry].[DocumentClass]))
				ELSE (SELECT dbo.adfGetDocumentClassNameByTable('Task'))
		END AS [DocumentClassName],
		CASE
			WHEN [TimeEntry].[TaskID] IS NULL
				THEN (SELECT TOP(1) [DocumentName] FROM adfGetDocumentIdentity([TimeEntry].[DocumentID], [TimeEntry].[DocumentClass]))
				ELSE (SELECT [Task].[FileAs] FROM [Task] WHERE [Task].[ID] = [TimeEntry].[TaskID])
		END AS [DocumentName]
	FROM
		[vwTimeEntry] as [TimeEntry]
		LEFT OUTER JOIN [Task]
			ON [TimeEntry].[TaskID] = [Task].[ID]
	WHERE
		[TimeEntry].[EmployeeID] = @CurrentEmployeeID AND
		[TimeEntry].[State] IN (1, 5) AND	-- / 
		DATEADD(MINUTE,[TimeEntry].[Duration],[TimeEntry].[StartTime]) <= GETDATE()
	
	RETURN 0
GO

GRANT EXEC ON TimeEntryOwnInDrafts TO PUBLIC
GO
