IF EXISTS (SELECT * FROM sysobjects WHERE type = 'TR' AND name = 'pjm5trTimeEntryInsert')
	BEGIN
		PRINT 'Dropping Trigger pjm5trTimeEntryInsert'
		DROP  Trigger pjm5trTimeEntryInsert
	END
GO

/******************************************************************************
**		File: 
**		Name: pjm5trTimeEntryInsert
**		Desc: 
**
**		This template can be customized:
**              
**
**		Auth: 
**		Date: 
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:				Description:
**		--------	--------			-------------------------------------------
**      25.10.10    BVY                 Edited [Duration] on [Duration] - 1 in #dayboundsexceeded
**      16.10.13    SOV                      [AmountBeforeFinanceDocumentInsert]
**										  [Amount]
**		25.02.15	DAL					         
**										  
*******************************************************************************/

PRINT 'Creating Trigger pjm5trTimeEntryInsert'
GO
CREATE Trigger pjm5trTimeEntryInsert 
ON [TimeEntry] FOR INSERT
AS
BEGIN
    IF @@rowcount = 0
       RETURN

	DECLARE 
		@true bit = 1,
		@false bit = 0,
		@PeriodeCloseDate date,
		@TimeEntryStartTime date

	EXEC pjm7GetPeriodClosedDate @Result = @PeriodeCloseDate OUTPUT

	IF @PeriodeCloseDate IS NOT NULL
	BEGIN
		SELECT 
			@TimeEntryStartTime =  [StartTime] 
		FROM 
			[inserted]

		IF @TimeEntryStartTime <= @PeriodeCloseDate
		BEGIN			
			DECLARE
				@CanCreate bit = @false,
				@ProjectID INT
			
			SELECT 
				@ProjectID = [ProjectID] 
			FROM 
				[inserted]

			SET @CanCreate = [dbo].[fnPjm7CanModifyDocumentInClosedPeriod](@ProjectID, NULL)
			
			IF @CanCreate = @false
			BEGIN
				RAISERROR('#CannotInsertBecauseOfPeriod', 18, -1)
				ROLLBACK TRANSACTION
				RETURN
			END
		END
	END
	
	IF EXISTS(SELECT * FROM inserted WHERE 
		CONVERT(datetime, CONVERT(varchar(8), DATEADD(minute, [Duration] - 1, [StartTime]), 112), 112) >
		CONVERT(datetime, CONVERT(varchar(8), [StartTime], 112), 112))
	BEGIN
		RAISERROR('#dayboundsexceeded', 18, -1)
		ROLLBACK TRANSACTION
		RETURN
	END

	INSERT INTO [EntryAmount] 
		([ID], [Amount], [Price], [AmountBeforeFinanceDocumentInsert])
	SELECT
		[ID], ROUND([RoundedDuration] / 60.0, 2), ISNULL([Rate], 0), ROUND([RoundedDuration] / 60.0, 2)
	FROM
		[inserted]
	IF @@error != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN
	END
	
	DECLARE 
		@working TCount,
		@value TVariant
			
	EXEC adfParameterGet @Name='WorkTime', @Group='Pjm5', @Value = @value OUTPUT
	SET @working = CAST(@value as int)

	INSERT INTO [EmployeeCalendar]
		([EmployeeID], [Date], [Working], [Planned], [Actual], [Approved])
	SELECT DISTINCT
		[EmployeeID], 
		CONVERT(datetime, CONVERT(varchar(8), [StartTime], 112), 112) as [Date],
		CASE 
			WHEN dbo.fnPjm5IsWorkingDay([StartTime]) = 1 THEN @working
			ELSE 0
		END,
		0,
		0,
		0
	FROM 
		[inserted]
	WHERE
		NOT EXISTS(SELECT * FROM [EmployeeCalendar] 
			WHERE [EmployeeID] = [inserted].[EmployeeID] AND [Date] = CONVERT(datetime, CONVERT(varchar(8), [inserted].[StartTime], 112), 112))

	IF @@error != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN
	END
	
	UPDATE [EmployeeCalendar]
	SET
		[Actual] = [Actual] + [I].[Duration]
	FROM
		EmployeeCalendar INNER JOIN (
			SELECT 
				[EmployeeID], 
				CONVERT(datetime, CONVERT(varchar(8), [StartTime], 112), 112) as [Date],
				SUM([Duration]) as [Duration]
			FROM 
				[inserted]
			WHERE
				[inserted].[State] != 4
			GROUP BY
				[EmployeeID], 
				CONVERT(datetime, CONVERT(varchar(8), [StartTime], 112), 112)) as [I]
			ON ([EmployeeCalendar].[EmployeeID] = [I].[EmployeeID] AND
				[EmployeeCalendar].[Date] = [I].[Date])

	IF @@error != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN
	END

END
GO