﻿IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm7TimeEntryBrowseByMeeting]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure pjm7TimeEntryBrowseByMeeting'
		DROP PROCEDURE [dbo].[pjm7TimeEntryBrowseByMeeting]
	END
GO

PRINT 'Creating procedure pjm7TimeEntryBrowseByMeeting'
GO

/******************************************************************************
**		File: pjm7TimeEntryBrowseByMeeting.sql
**		Name: pjm7TimeEntryBrowseByMeeting
**		Desc: Процедура получает созданные записи о времени после завершения встречи
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: avgusta.bekhtina
**		Date: 04.09.2013 11:14:01
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**		05.09.13	SOV				Апрувер видит время к оплате
*******************************************************************************/
CREATE PROCEDURE [pjm7TimeEntryBrowseByMeeting]
	@MeetingRequestID TIdentifier
AS
	SET NOCOUNT ON
	
	DECLARE
		@ParameterValue sql_variant,
		@BillableHoursStyle int,
		@EmployeeID TIdentifier

	SET @EmployeeID = dbo.adfGetCurrentEmployeeID()
	
	EXEC dbo.[adfParameterGet] @Name='BillableHoursStyle', @Group='Pjm7', @Value=@ParameterValue OUTPUT
	SET @BillableHoursStyle = 
		CASE
			WHEN @ParameterValue IS NULL OR @ParameterValue = 0 THEN 0
			ELSE 1
		END
	
	SELECT
		[TimeEntry].[Class],
		[TimeEntry].[ID],
		[TimeEntry].[State],
		[TimeEntry].[Flag],
		[TimeEntry].[FileAs],
		[TimeEntry].[ActivityTypeID],
		[TimeEntry].[EmployeeID],
		[TimeEntry].[ProjectID],
		[TimeEntry].[StartTime],
		[TimeEntry].[Duration],
		[TimeEntry].[RoundedDuration],
		[TimeEntry].[Billable],
		CASE
			WHEN [Project].[ViewFinance] = 1 OR [Project].[ViewBillableHour]=1 OR
				(@BillableHoursStyle=1 AND [TimeEntry].[EmployeeID] = @EmployeeID)
				THEN [TimeEntry].[BillableDuration]
			ELSE -60
		END AS BillableDuration,
		[TimeEntry].[Overtime],
		[TimeEntry].[Rate],
		[TimeEntry].[CurrencyCode],
		[TimeEntry].[VATRate],
		CASE 
			WHEN [Project].[ViewFinance] = 0
				THEN -1
			ELSE CAST([TimeEntry].[Billable] AS int) * [TimeEntry].[Rate] * [TimeEntry].[BillableHour]
		END AS [Sum],
		[TimeEntry].[Color],
		[TimeEntry].[Comments],
		[TimeEntry].[Created],
		[TimeEntry].[CreatedBy],
		[TimeEntry].[Modified],
		[TimeEntry].[ModifiedBy],
		[TimeEntry].[Timestamp],
		CASE
			WHEN [TimeEntry].[TaskID] IS NULL
				THEN (SELECT TOP(1) [DocumentClassName] FROM dbo.adfGetDocumentIdentity([TimeEntry].[DocumentID], [TimeEntry].[DocumentClass]))
				ELSE (SELECT dbo.adfGetDocumentClassNameByTable('Task'))
		END AS [DocumentClassName],
		CASE
			WHEN [TimeEntry].[TaskID] IS NULL
				THEN (SELECT TOP(1) [DocumentName] FROM dbo.adfGetDocumentIdentity([TimeEntry].[DocumentID], [TimeEntry].[DocumentClass]))
				ELSE (SELECT [Task].[FileAs] FROM dbo.[Task] WHERE [Task].[ID] = [TimeEntry].[TaskID])
		END AS [DocumentName]
	FROM
		dbo.[vwTimeEntry] as [TimeEntry]
		INNER JOIN 
		dbo.fnPjm6GetAvailableProjectsForTimeBrowse (
			0,
			0,
			0)
			AS [Project]
			ON [Project].[ID] = ISNULL([TimeEntry].[ProjectID], -1)
	WHERE
		(
			([TimeEntry].[MeetingRequestID] = @MeetingRequestID)
		) 
		
	RETURN 0
GO

GRANT EXECUTE ON [pjm7TimeEntryBrowseByMeeting] TO PUBLIC
GO