 IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm5vwTask]') and OBJECTPROPERTY(id, N'IsView') = 1)
	BEGIN
		PRINT 'Dropping view pjm5vwTask'
		DROP VIEW [dbo].[pjm5vwTask]
	END
GO

PRINT 'Creating view pjm5vwTask'
GO

CREATE VIEW [pjm5vwTask]
AS
	SELECT
		[Task].[Class],
		[Task].[ID],
		[Task].[State],
		[Task].[Flag],
		[Task].[FileAs],
		[Task].[ProjectID],
		[Task].[PriorityID],
		[Task].[ParentID],
		[Task].[StartDate],
		[Task].[DueDate],
		[Task].[EndDate],
		[Task].[Duration],
		[Task].[PercentComplete],
		[Task].[Milestone],
		CAST([Task].[ManHour] AS decimal(18,4)) AS [ManHour],
		[Task].[Budget],
		ISNULL([TimeEntryBudget].[TimeEntryDuration], 0) AS [RealManHour],
		([TimeEntryBudget].[TimeEntryDuration]) AS [RealManHourNullable],
		ISNULL([TimeEntryBudget].[TimeEntryBudget], 0) AS [TimeRealBudget],
		ISNULL([ExpenseBudget].[ExpenseBudget], 0) AS [ExpenseRealBudget],
		CASE
			WHEN [Task].[DueDate] <= GETDATE() THEN 1
			WHEN [Task].[Duration] != 0 AND [Task].[StartDate] <= GETDATE() THEN
				1.0 - CAST((dbo.fnPjm5GetWorkingDays(GETDATE(), [Task].[DueDate])-1) as decimal(18,2))/[Task].[Duration]
			ELSE 0
		END AS [PlanPercent],
		[BusyEntry].[PlannedManHour] / 60.0 AS [PlannedManHour],
		[BusyEntry].[PlannedBudget] AS [PlannedBudget],
		[Task].[SendStatusReport],
		[Task].[Comments],
		[Task].[Created],
		[Task].[CreatedBy],
		[Task].[Modified],
		[Task].[ModifiedBy],
		[Task].[Timestamp],
		[Task].[SubprojectID]
	FROM
		[Task]
		LEFT OUTER JOIN 
			(
			SELECT 
				[Expense].[TaskID],
				SUM([Expense].[Billable] * ISNULL(
					CASE 
						WHEN [Project].[RatesWithVAT] = 0
							THEN [Expense].[TotalPC]
						ELSE [Expense].[TotalWithVATPC]
					END, 0)) AS [ExpenseBudget]
			FROM [Expense]
				INNER JOIN [Project]
					ON [Project].[ID] = [Expense].[ProjectID]
			WHERE
				[Expense].[TaskID] IS NOT NULL AND
				[Expense].[State] IN (2,3,6)
			GROUP BY 
				[Expense].[TaskID]
			) AS [ExpenseBudget]
			ON [ExpenseBudget].[TaskID] = [Task].[ID]
		LEFT OUTER JOIN 
			(
			SELECT 
				[TimeEntry].[TaskID],
				SUM([EntryAmount].[Amount]) AS [TimeEntryDuration],
				SUM([TimeEntry].[Billable] * [EntryAmount].[Amount] * [TimeEntry].[Rate]) AS [TimeEntryBudget]
			FROM 
				[TimeEntry]
				INNER JOIN [EntryAmount]
					ON [TimeEntry].[ID] = [EntryAmount].[ID]
			WHERE
				[TimeEntry].[TaskID] IS NOT NULL AND
				[TimeEntry].[State] IN (2,3,6)
			GROUP BY 
				[TimeEntry].[TaskID]
			) AS [TimeEntryBudget]
			ON [TimeEntryBudget].[TaskID] = [Task].[ID]
		LEFT OUTER JOIN (
			SELECT
				[BusyEntry].[TaskID],
				ISNULL(SUM(
					CASE 
						WHEN [BusyEntry].[Date] <= GETDATE() THEN [Planned]
						ELSE 0
					END
					) / 1, 0)  AS [PlannedManHour],
				ISNULL(SUM(
					CASE 
						WHEN [BusyEntry].[Date] <= GETDATE() THEN [BusyEntry].[Planned] * [Assignment].[StandardRate]
						ELSE 0
					END
					), 0) / 60.0  AS [PlannedBudget]
			FROM
				[BusyEntry]
				LEFT OUTER JOIN [Assignment]
					ON [BusyEntry].[AssignmentID] = [Assignment].[ID]
				LEFT OUTER JOIN [TaskAssignment]
					ON ([TaskAssignment].[TaskID] = [BusyEntry].[TaskID] AND [TaskAssignment].[AssignmentID] = [Assignment].[ID])
			GROUP BY
				[BusyEntry].[TaskID]
			) AS [BusyEntry]
			ON ([BusyEntry].[TaskID] = [Task].[ID])
GO
 